-- migrate oracle from version 100 to version 101

-- create security systems
-- multiply the id with 10 because we have two reserved entries (0=system, 1=default)
INSERT INTO IWA_SecuritySystem (SecuritySystemId, Name, SecurityDescriptorId)
SELECT ApplicationId * 10, Name, SecurityDescriptorId
FROM IWA_Application;

-- fill up data
UPDATE IWA_SecurityMember SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_User SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_Role SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_Case SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_Task SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_WorkflowEvent SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_IntermediateEvent SET SecuritySystemId = ApplicationId * 10;
UPDATE IWA_SignalEvent SET SecuritySystemId = ApplicationId * 10;

-- not null
ALTER TABLE IWA_SecurityMember MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_User MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_Role MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_Case MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_Task MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_WorkflowEvent MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_IntermediateEvent MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_SignalEvent MODIFY SecuritySystemId NOT NULL;
ALTER TABLE IWA_SecuritySystem MODIFY SecurityDescriptorId NOT NULL;

-- unique keys
ALTER TABLE IWA_User ADD UNIQUE (SecuritySystemId, Name);
ALTER TABLE IWA_Role DROP UNIQUE (ApplicationId, Name) DROP INDEX;
ALTER TABLE IWA_Role ADD UNIQUE (SecuritySystemId, ApplicationId, Name);

-- drop columns
ALTER TABLE IWA_SecurityMember DROP COLUMN ApplicationId;
ALTER TABLE IWA_Application DROP COLUMN SecurityDescriptorId;
ALTER TABLE IWA_User DROP COLUMN ApplicationId;

-- add indexes
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_ExternalIdIndex on IWA_User (SecuritySystemId, ExternalId) TABLESPACE ${tablespaceName}';   
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN 
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_ExternalSecurityNameIndex ON IWA_User (SecuritySystemId, ExternalSecurityName) TABLESPACE ${tablespaceName}';   
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN 
  NULL;
END;
;

-- create views
CREATE VIEW IWA_SignalEventQuery
(
  SignalEventId,
  SecuritySystemId,
  ApplicationId,
  SignalCode,
  SentTimestamp,
  SentById,
  SentByUserName,
  SentByUserId,
  SentByTaskId,
  SentByProcessElementPid
)
AS
  SELECT
    IWA_SignalEvent.SignalEventId,
    IWA_SignalEvent.SecuritySystemId,
    IWA_SignalEvent.ApplicationId,
    IWA_SignalEvent.SignalCode,
    IWA_SignalEvent.SentTimestamp,
    IWA_SignalEvent.SentById,
    IWA_SecurityMember.Name,
    IWA_User.UserId,
    IWA_SignalEvent.SentByTaskId,
    IWA_SignalEvent.SentByProcessElementPid
  FROM IWA_SignalEvent
    LEFT OUTER JOIN IWA_SecurityMember ON IWA_SignalEvent.SentById = IWA_SecurityMember.SecurityMemberId
    LEFT OUTER JOIN IWA_User ON IWA_SecurityMember.SecurityMemberId = IWA_User.SecurityMemberId;

CREATE VIEW IWA_TaskQuery
(
  TaskId,
  CaseId,
  BusinessCaseId,
  ProcessModelId,
  SecuritySystemId,
  ApplicationId,
  StartTaskSwitchEventId,
  EndTaskSwitchEventId,
  TaskStartId,
  TaskEndId,
  WorkerId,
  WorkerUserName,
  WorkerUserDisplayName,
  WorkerSessionId,
  ActivatorId,
  OriginalActivatorId,
  OriginalActivatorName,
  OriginalActivatorDisplayName,
  ActivatorAvailable,
  ExpiryActivatorId,
  ExpiryActivatorName,
  ExpiryActivatorDisplayName,
  ExpiryPriority,
  ExpiryTimestamp,
  ExpiryTaskStartElementPid,
  IsExpired,
  ExpiredCreatorTaskId,
  TimeoutedCreatorIntrmdtEventId,
  DelayTimestamp,
  State,
  RequestPath,
  DisplayNameTemplate,
  Name,
  DisplayDescriptionTemplate,
  Description,
  Priority,
  OriginalPriority,
  StartTimestamp,
  EndTimestamp,
  BusinessCalendar,
  WorkingTime,
  BusinessRuntime,
  FailedTimeoutTimestamp,
  NumberOfFailures,
  NumberOfResumes,
  Category,
  IsUpdatedOnStart,
  IsOffline,
  ActivatorName,
  ActivatorDisplayName
)
AS
  SELECT
    IWA_Task.TaskId,
    IWA_Task.CaseId,
    IWA_Task.BusinessCaseId,
    IWA_Task.ProcessModelId,
    IWA_Task.SecuritySystemId,
    IWA_Task.ApplicationId,
    IWA_Task.StartTaskSwitchEventId,
    IWA_Task.EndTaskSwitchEventId,
    IWA_Task.TaskStartId,
    IWA_Task.TaskEndId,
    IWA_Task.WorkerId,
    Worker.Name,
    Worker.DisplayName,
    IWA_Task.WorkerSessionId,
    IWA_Task.ActivatorId,
    IWA_Task.OriginalActivatorId,
    OriginalActivator.MemberName,
    OriginalActivator.DisplayName,
    Activator.Enabled,
    IWA_Task.ExpiryActivatorId,
    ExpiryActivator.MemberName,
    ExpiryActivator.DisplayName,
    IWA_Task.ExpiryPriority,
    IWA_Task.ExpiryTimestamp,
    IWA_Task.ExpiryTaskStartElementPid,
    IWA_Task.IsExpired,
    IWA_Task.ExpiredCreatorTaskId,
    IWA_Task.TimeoutedCreatorIntrmdtEventId,
    IWA_Task.DelayTimestamp,
    IWA_Task.State,
    IWA_Task.RequestPath,
    IWA_Task.DisplayNameTemplate,
    IWA_Task.Name,
    IWA_Task.DisplayDescriptionTemplate,
    IWA_Task.Description,
    IWA_Task.Priority,
    IWA_Task.OriginalPriority,
    IWA_Task.StartTimestamp,
    IWA_Task.EndTimestamp,
    IWA_Task.BusinessCalendar,
    IWA_Task.WorkingTime,
    IWA_Task.BusinessRuntime,
    IWA_Task.FailedTimeoutTimestamp,
    IWA_Task.NumberOfFailures,
    IWA_Task.NumberOfResumes,
    IWA_Task.Category,
    IWA_Task.IsUpdatedOnStart,
    IWA_Task.IsOffline,
    Activator.MemberName,
    Activator.DisplayName
  FROM IWA_Task
    LEFT OUTER JOIN IWA_SecurityMember Activator ON IWA_Task.ActivatorId = Activator.SecurityMemberId
    LEFT OUTER JOIN IWA_SecurityMember OriginalActivator ON IWA_Task.OriginalActivatorId = OriginalActivator.SecurityMemberId
    LEFT OUTER JOIN IWA_SecurityMember ExpiryActivator ON IWA_Task.ExpiryActivatorId = ExpiryActivator.SecurityMemberId
    LEFT OUTER JOIN IWA_SecurityMember Worker ON IWA_Task.WorkerId = Worker.SecurityMemberId;

CREATE VIEW IWA_CaseQuery
(
  CaseId,
  BusinessCaseId,
  Kind,
  SecuritySystemId,
  ApplicationId,
  ProcessModelId,
  TaskStartId,
  ActivatorId,
  CreatorId,
  CreatorUserName,
  CreatorUserDisplayName,
  CreatorTaskId,
  Environment,
  DisplayNameTemplate,
  Name,
  DisplayDescriptionTemplate,
  Description,
  StartTimestamp,
  EndTimestamp,
  BusinessCalendar,
  WorkingTime,
  BusinessRuntime,
  State,
  Priority,
  Stage,
  OwnerId,
  OwnerName,
  OwnerDisplayName,
  Category
)
AS
  SELECT
    IWA_Case.CaseId,
    IWA_Case.BusinessCaseId,
    IWA_Case.Kind,
    IWA_Case.SecuritySystemId,
    IWA_Case.ApplicationId,
    IWA_Case.ProcessModelId,
    IWA_Case.TaskStartId,
    IWA_Case.ActivatorId,
    IWA_Case.CreatorId,
    Creator.Name,
    Creator.DisplayName,
    IWA_Case.CreatorTaskId,
    IWA_Case.Environment,
    IWA_Case.DisplayNameTemplate,
    IWA_Case.Name,
    IWA_Case.DisplayDescriptionTemplate,
    IWA_Case.Description,
    IWA_Case.StartTimestamp,
    IWA_Case.EndTimestamp,
    IWA_Case.BusinessCalendar,
    IWA_Case.WorkingTime,
    IWA_Case.BusinessRuntime,
    IWA_Case.State,
    IWA_Case.Priority,
    IWA_Case.Stage,
    IWA_Case.OwnerId,
    Owner.MemberName,
    Owner.DisplayName,
    IWA_Case.Category
  FROM IWA_Case
    LEFT OUTER JOIN IWA_SecurityMember Creator ON IWA_Case.CreatorId = Creator.SecurityMemberId
    LEFT OUTER JOIN IWA_SecurityMember Owner ON IWA_Case.OwnerId = Owner.SecurityMemberId;

-- update version
UPDATE IWA_Version SET Version=101;
