-- SQL script to create database for Microsoft SQL Server

SET IMPLICIT_TRANSACTIONS OFF
GO
ALTER DATABASE [${databaseName}] SET ALLOW_SNAPSHOT_ISOLATION ON
GO
ALTER DATABASE [${databaseName}] SET READ_COMMITTED_SNAPSHOT ON
GO
ALTER DATABASE [${databaseName}] SET RECURSIVE_TRIGGERS ON
GO
SET IMPLICIT_TRANSACTIONS ON
GO

CREATE TABLE IWA_Version
(
  Version INTEGER NOT NULL
)
GO

CREATE TABLE IWA_Identifier
(
  IdentifierName VARCHAR(200) NOT NULL,
  IdentifierValue BIGINT NOT NULL,
  PRIMARY KEY (IdentifierName)
)
GO

CREATE TABLE IWA_SystemProperty
(
  PropertyName VARCHAR(200) NOT NULL,
  PropertyValue VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (PropertyName)
)
GO

CREATE TABLE IWA_AsyncProcessCaseData
(
  CaseId BIGINT NOT NULL,
  EventId VARCHAR(100) NOT NULL,
  CaseData VARBINARY(MAX) NOT NULL,
  PRIMARY KEY (CaseId, EventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_AsyncProcessCaseData') AND name='IWA_AsyncProcessCaseData_CaseIdIndex')
  CREATE INDEX IWA_AsyncProcessCaseData_CaseIdIndex ON IWA_AsyncProcessCaseData (CaseId)
GO

CREATE TABLE IWA_Application
(
  ApplicationId BIGINT NOT NULL,
  Name VARCHAR(160) NOT NULL,
  "State" INTEGER NOT NULL,
  SecuritySystemId BIGINT NOT NULL,
  PRIMARY KEY (ApplicationId),
  UNIQUE (Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Application') AND name='IWA_Application_SecuritySystemIdIndex')
  CREATE INDEX IWA_Application_SecuritySystemIdIndex ON IWA_Application (SecuritySystemId)
GO

CREATE TABLE IWA_ProcessModel
(
  ProcessModelId BIGINT NOT NULL,
  Name VARCHAR(160) NOT NULL,
  "State" INTEGER NOT NULL,
  ApplicationId BIGINT NOT NULL,
  PRIMARY KEY (ProcessModelId),
  UNIQUE (ApplicationId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_ProcessModel') AND name='IWA_ProcessModel_ApplicationIdIndex')
  CREATE INDEX IWA_ProcessModel_ApplicationIdIndex ON IWA_ProcessModel (ApplicationId)
GO

CREATE TABLE IWA_ProcessModelVersion
(
  ProcessModelVersionId BIGINT NOT NULL,
  ProcessModelId BIGINT NOT NULL,
  VersionNumber INTEGER NOT NULL,
  "State" INTEGER NOT NULL,
  ReleaseState INTEGER NOT NULL,
  ReleaseTimestamp DATETIME2(3) NULL,
  ProjectDirectory VARCHAR(2000) NULL,
  ProjectName VARCHAR(800) NOT NULL,
  ProjectHash VARCHAR(128) NULL,
  Changed DATETIME2(3) NOT NULL,
  PRIMARY KEY (ProcessModelVersionId),
  UNIQUE (ProcessModelId, VersionNumber)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_ProcessModelVersion') AND name='IWA_ProcessModelVersion_ProcessModelIdIndex')
  CREATE INDEX IWA_ProcessModelVersion_ProcessModelIdIndex ON IWA_ProcessModelVersion (ProcessModelId)
GO

CREATE TABLE IWA_Library
(
  LibraryId BIGINT NOT NULL,
  ProcessModelVersionId BIGINT NOT NULL REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE CASCADE,
  ApplicationId BIGINT NOT NULL REFERENCES IWA_Application(ApplicationId) ON DELETE CASCADE,
  Id VARCHAR(200) NOT NULL,
  Version VARCHAR(200) NOT NULL DEFAULT '',
  Provider VARCHAR(800) NOT NULL,
  Name VARCHAR(800) NOT NULL,
  Description VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (LibraryId),
  UNIQUE (ApplicationId, Id, Version),
  UNIQUE (ProcessModelVersionId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Library') AND name='IWA_Library_ApplicationIdIndex')
  CREATE INDEX IWA_Library_ApplicationIdIndex ON IWA_Library (ApplicationId)
GO

CREATE TABLE IWA_LibrarySpecification
(
  LibrarySpecificationId BIGINT NOT NULL,
  LibraryId BIGINT NOT NULL REFERENCES IWA_Library(LibraryId) ON DELETE CASCADE,
  Id VARCHAR(200) NOT NULL,
  ResolvedLibraryId BIGINT NULL,
  "Position" INTEGER NOT NULL,
  PRIMARY KEY (LibrarySpecificationId),
  UNIQUE (LibraryId, Id)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_LibrarySpecification') AND name='IWA_LibrarySpecification_LibraryIdIndex')
  CREATE INDEX IWA_LibrarySpecification_LibraryIdIndex ON IWA_LibrarySpecification (LibraryId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_LibrarySpecification') AND name='LibrarySpecification_ResolvedLibraryId')
  CREATE INDEX LibrarySpecification_ResolvedLibraryId ON IWA_LibrarySpecification (ResolvedLibraryId)
GO

CREATE TABLE IWA_LibraryVersionSpec
(
  LibraryVersionSpecId BIGINT NOT NULL,
  LibrarySpecificationId BIGINT NOT NULL REFERENCES IWA_LibrarySpecification(LibrarySpecificationId) ON DELETE CASCADE,
  Version VARCHAR(50) NOT NULL DEFAULT '',
  Inclusive BIT NOT NULL,
  Minimum BIT NOT NULL,
  PRIMARY KEY (LibraryVersionSpecId),
  UNIQUE (LibrarySpecificationId, Minimum)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_LibraryVersionSpec') AND name='IWA_LibraryVersionSpec_LibrarySpecificationIdIndex')
  CREATE INDEX IWA_LibraryVersionSpec_LibrarySpecificationIdIndex ON IWA_LibraryVersionSpec (LibrarySpecificationId)
GO

CREATE TABLE IWA_CaseMap
(
  CaseMapId BIGINT NOT NULL,
  ProcessModelVersionId BIGINT NOT NULL REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE CASCADE,
  ApplicationId BIGINT NOT NULL REFERENCES IWA_Application(ApplicationId) ON DELETE CASCADE,
  UUID VARCHAR(144) NOT NULL,
  Name VARCHAR(800) NOT NULL,
  Model VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (CaseMapId),
  UNIQUE (ProcessModelVersionId, UUID)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMap') AND name='IWA_CaseMap_ProcessModelVersionIdIndex')
  CREATE INDEX IWA_CaseMap_ProcessModelVersionIdIndex ON IWA_CaseMap (ProcessModelVersionId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMap') AND name='IWA_CaseMap_ApplicationIdIndex')
  CREATE INDEX IWA_CaseMap_ApplicationIdIndex ON IWA_CaseMap (ApplicationId)
GO

CREATE TABLE IWA_SecurityMember
(
  SecurityMemberId VARCHAR(210) NOT NULL,
  Name VARCHAR(800) NOT NULL,
  MemberName VARCHAR(804) NOT NULL,
  DisplayName VARCHAR(800) NULL,
  SecuritySystemId BIGINT NOT NULL,
  Enabled BIT NOT NULL DEFAULT 0,
  "Type" INTEGER NOT NULL,
  PRIMARY KEY (SecurityMemberId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityMember') AND name='IWA_SecurityMemberNameIdx')
  CREATE INDEX IWA_SecurityMemberNameIdx ON IWA_SecurityMember (Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityMember') AND name='IWA_SecurityMemberMemberNameIdx')
  CREATE INDEX IWA_SecurityMemberMemberNameIdx ON IWA_SecurityMember (MemberName)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityMember') AND name='IWA_SecurityMemberDisplayNameIdx')
  CREATE INDEX IWA_SecurityMemberDisplayNameIdx ON IWA_SecurityMember (DisplayName)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityMember') AND name='IWA_SecurityMemberEnabledIdx')
  CREATE INDEX IWA_SecurityMemberEnabledIdx ON IWA_SecurityMember (Enabled)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityMember') AND name='IWA_SecurityMemberTypeIdx')
  CREATE INDEX IWA_SecurityMemberTypeIdx ON IWA_SecurityMember ("Type")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityMember') AND name='IWA_SecurityMember_SecuritySystemIdIndex')
  CREATE INDEX IWA_SecurityMember_SecuritySystemIdIndex ON IWA_SecurityMember (SecuritySystemId)
GO

CREATE TABLE IWA_Role
(
  RoleId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  DisplayNameTemplate VARCHAR(800) NULL,
  DisplayDescriptionTemplate VARCHAR(800) NULL DEFAULT '',
  ParentSecurityMemberId VARCHAR(210) NULL,
  SecuritySystemId BIGINT NOT NULL,
  IsDynamic BIT NOT NULL,
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  PRIMARY KEY (SecurityMemberId),
  UNIQUE (RoleId),
  UNIQUE (SecuritySystemId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Role') AND name='IWA_Role_ParentSecurityMemberIdIndex')
  CREATE INDEX IWA_Role_ParentSecurityMemberIdIndex ON IWA_Role (ParentSecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Role') AND name='IWA_Role_SecuritySystemIdIndex')
  CREATE INDEX IWA_Role_SecuritySystemIdIndex ON IWA_Role (SecuritySystemId)
GO

CREATE TABLE IWA_RoleProperty
(
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  RolePropertyId BIGINT NOT NULL,
  PropertyName VARCHAR(1020) NOT NULL,
  PropertyValue VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (RolePropertyId),
  UNIQUE (SecurityMemberId, PropertyName)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_RoleProperty') AND name='IWA_RoleProperty_SecurityMemberIdIndex')
  CREATE INDEX IWA_RoleProperty_SecurityMemberIdIndex ON IWA_RoleProperty (SecurityMemberId)
GO

CREATE TABLE IWA_RoleRoleMember
(
  RoleSecurityMemberId VARCHAR(210) NOT NULL,
  RoleMemberSecurityMemberId VARCHAR(210) NOT NULL,
  PRIMARY KEY (RoleSecurityMemberId, RoleMemberSecurityMemberId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_RoleRoleMember') AND name='IWA_RoleRoleMember_RoleSecurityMemberIdIndex')
  CREATE INDEX IWA_RoleRoleMember_RoleSecurityMemberIdIndex ON IWA_RoleRoleMember (RoleSecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_RoleRoleMember') AND name='IWA_RoleRoleMember_RoleMemberSecurityMemberIdIndex')
  CREATE INDEX IWA_RoleRoleMember_RoleMemberSecurityMemberIdIndex ON IWA_RoleRoleMember (RoleMemberSecurityMemberId)
GO

CREATE TABLE IWA_User
(
  UserId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  FullName VARCHAR(800) NULL DEFAULT '',
  UserPassword VARCHAR(800) NOT NULL,
  SecuritySystemId BIGINT NOT NULL,
  ExternalSecurityName VARCHAR(2000) NULL,
  ExternalId VARCHAR(800) NULL,
  EMailAddress VARCHAR(800) NULL,
  "Language" VARCHAR(20) NULL,
  FormattingLanguage VARCHAR(20) NULL,
  "State" INTEGER NOT NULL DEFAULT 0,
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  PRIMARY KEY (SecurityMemberId),
  UNIQUE (UserId),
  UNIQUE (SecuritySystemId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_User') AND name='IWA_User_ExternalIdIndex')
  CREATE INDEX IWA_User_ExternalIdIndex ON IWA_User (SecuritySystemId, ExternalId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_User') AND name='IWA_User_StateIndex')
  CREATE INDEX IWA_User_StateIndex ON IWA_User ("State")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_User') AND name='IWA_User_ExternalSecurityNameIndex')
  CREATE INDEX IWA_User_ExternalSecurityNameIndex ON IWA_User (SecuritySystemId, ExternalSecurityName)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_User') AND name='IWA_User_SecuritySystemIdIndex')
  CREATE INDEX IWA_User_SecuritySystemIdIndex ON IWA_User (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_User') AND name='IWA_User_SecSysSecMemberIndex')
  CREATE INDEX IWA_User_SecSysSecMemberIndex ON IWA_User (SecuritySystemId, SecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_User') AND name='IWA_User_SecSysNameSecMemberIdx')
  CREATE INDEX IWA_User_SecSysNameSecMemberIdx ON IWA_User (SecuritySystemId, Name, SecurityMemberId)
GO

CREATE TABLE IWA_UserRole
(
  RoleSecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  UserSecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (RoleSecurityMemberId, UserSecurityMemberId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserRole') AND name='IWA_UserRole_RoleSecurityMemberIdIndex')
  CREATE INDEX IWA_UserRole_RoleSecurityMemberIdIndex ON IWA_UserRole (RoleSecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserRole') AND name='IWA_UserRole_UserSecurityMemberIdIndex')
  CREATE INDEX IWA_UserRole_UserSecurityMemberIdIndex ON IWA_UserRole (UserSecurityMemberId)
GO

CREATE TABLE IWA_UserProperty
(
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  UserPropertyId BIGINT NOT NULL,
  PropertyName VARCHAR(1020) NOT NULL,
  PropertyValue VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (UserPropertyId),
  UNIQUE (SecurityMemberId, PropertyName)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserProperty') AND name='IWA_UserProperty_SecurityMemberIdIndex')
  CREATE INDEX IWA_UserProperty_SecurityMemberIdIndex ON IWA_UserProperty (SecurityMemberId)
GO

CREATE TABLE IWA_UserAbsence
(
  UserAbsenceId BIGINT NOT NULL,
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  StartTimestamp DATETIME2(3) NOT NULL,
  StopTimestamp DATETIME2(3) NULL,
  Description VARCHAR(800) NOT NULL,
  PRIMARY KEY (UserAbsenceId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserAbsence') AND name='IWA_UserAbsence_SecurityMemberIdIndex')
  CREATE INDEX IWA_UserAbsence_SecurityMemberIdIndex ON IWA_UserAbsence (SecurityMemberId)
GO

CREATE TABLE IWA_UserSubstitute
(
  UserSubstituteId BIGINT NOT NULL,
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  SubstituteUserSecurityMemberId VARCHAR(210) NOT NULL,
  SubstituteRoleSecurityMemberId VARCHAR(210) NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  Description VARCHAR(800) NOT NULL,
  SubstitutionType INTEGER NOT NULL DEFAULT 0,
  PRIMARY KEY (UserSubstituteId),
  UNIQUE (SecurityMemberId, SubstituteUserSecurityMemberId, SubstituteRoleSecurityMemberId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserSubstitute') AND name='IWA_UserSubstitute_SecurityMemberIdIndex')
  CREATE INDEX IWA_UserSubstitute_SecurityMemberIdIndex ON IWA_UserSubstitute (SecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserSubstitute') AND name='IWA_UserSbs_SbsUserScrtMmbrIdIdx')
  CREATE INDEX IWA_UserSbs_SbsUserScrtMmbrIdIdx ON IWA_UserSubstitute (SubstituteUserSecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserSubstitute') AND name='IWA_UserSbs_SbsRoleScrtMmbrIdIdx')
  CREATE INDEX IWA_UserSbs_SbsRoleScrtMmbrIdIdx ON IWA_UserSubstitute (SubstituteRoleSecurityMemberId)
GO

CREATE TABLE IWA_TaskElement
(
  TaskElementId BIGINT NOT NULL,
  ProcessModelVersionId BIGINT NOT NULL,
  ProcessElementId VARCHAR(800) NOT NULL,
  JoinPathes INTEGER NOT NULL,
  Kind INTEGER NOT NULL,
  PRIMARY KEY (TaskElementId),
  UNIQUE (ProcessModelVersionId, ProcessElementId, Kind)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskElement') AND name='IWA_TaskElement_ProcessModelVersionIdIndex')
  CREATE INDEX IWA_TaskElement_ProcessModelVersionIdIndex ON IWA_TaskElement (ProcessModelVersionId)
GO

CREATE TABLE IWA_TaskStart
(
  TaskStartId BIGINT NOT NULL,
  TaskElementId BIGINT NOT NULL,
  StartRequestPath VARCHAR(800) NOT NULL,
  PRIMARY KEY (TaskStartId),
  UNIQUE (TaskElementId, StartRequestPath)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskStart') AND name='IWA_TaskStart_TaskElementIdIndex')
  CREATE INDEX IWA_TaskStart_TaskElementIdIndex ON IWA_TaskStart (TaskElementId)
GO

CREATE TABLE IWA_TaskEnd
(
  TaskEndId BIGINT NOT NULL,
  TaskElementId BIGINT NOT NULL,
  JoinPathId INTEGER NULL,
  PRIMARY KEY (TaskEndId),
  UNIQUE (TaskElementId, JoinPathId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskEnd') AND name='IWA_TaskEnd_TaskElementIdIndex')
  CREATE INDEX IWA_TaskEnd_TaskElementIdIndex ON IWA_TaskEnd (TaskElementId)
GO

CREATE TABLE IWA_TaskSwitchEvent
(
  TaskSwitchEventId BIGINT NOT NULL,
  TaskElementId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL,
  ExecutionTimestamp DATETIME2(3) NOT NULL,
  PRIMARY KEY (TaskSwitchEventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskSwitchEvent') AND name='IWA_TaskSwitchEvent_TaskElementIdIndex')
  CREATE INDEX IWA_TaskSwitchEvent_TaskElementIdIndex ON IWA_TaskSwitchEvent (TaskElementId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskSwitchEvent') AND name='IWA_TaskSwitchEvent_CaseIdIndex')
  CREATE INDEX IWA_TaskSwitchEvent_CaseIdIndex ON IWA_TaskSwitchEvent (CaseId)
GO

CREATE TABLE IWA_Case
(
  CaseId BIGINT NOT NULL,
  UUID VARCHAR(144) NOT NULL,
  BusinessCaseId BIGINT NULL,
  Kind INTEGER NOT NULL DEFAULT 0,
  SecuritySystemId BIGINT NOT NULL,
  ApplicationId BIGINT NOT NULL,
  ProcessModelId BIGINT NOT NULL,
  TaskStartId BIGINT NOT NULL,
  ActivatorId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  CreatorId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  CreatorTaskId BIGINT NULL,
  StartTimestamp DATETIME2(3) NOT NULL,
  EndTimestamp DATETIME2(3) NULL,
  ModifiedTimestamp DATETIME2(3) NOT NULL,
  BusinessCalendar VARCHAR(800) NULL,
  WorkingTime BIGINT NULL,
  BusinessRuntime BIGINT NULL,
  "State" INTEGER NOT NULL,
  BusinessState INTEGER NOT NULL,
  Priority INTEGER NOT NULL,
  Stage VARCHAR(800) NOT NULL DEFAULT '',
  Category VARCHAR(800) NOT NULL DEFAULT '',
  PRIMARY KEY (CaseId),
  UNIQUE (UUID)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_BusinessCaseIdIndex')
  CREATE INDEX IWA_Case_BusinessCaseIdIndex ON IWA_Case (BusinessCaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_SecSystemIdIndex')
  CREATE INDEX IWA_Case_SecSystemIdIndex ON IWA_Case (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_ApplicationIdIndex')
  CREATE INDEX IWA_Case_ApplicationIdIndex ON IWA_Case (ApplicationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_ProcessModelIdIndex')
  CREATE INDEX IWA_Case_ProcessModelIdIndex ON IWA_Case (ProcessModelId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_TaskStartIdIndex')
  CREATE INDEX IWA_Case_TaskStartIdIndex ON IWA_Case (TaskStartId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_ActivatorIdIndex')
  CREATE INDEX IWA_Case_ActivatorIdIndex ON IWA_Case (ActivatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_CreatorTaskIdIndex')
  CREATE INDEX IWA_Case_CreatorTaskIdIndex ON IWA_Case (CreatorTaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_WbppIdCrtTmstmpSttIdx')
  CREATE INDEX IWA_Case_ApplicationIdCreationTimestampStateIndex ON IWA_Case (ApplicationId, StartTimestamp, "State")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_WorkingTime')
  CREATE INDEX IWA_Case_WorkingTime ON IWA_Case (WorkingTime)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_BusinessRuntime')
  CREATE INDEX IWA_Case_BusinessRuntime ON IWA_Case (BusinessRuntime)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_Category')
  CREATE INDEX IWA_Case_Category ON IWA_Case (Category)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_EndTimestamp')
  CREATE INDEX IWA_Case_EndTimestamp ON IWA_Case (EndTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_StartTimestamp')
  CREATE INDEX IWA_Case_StartTimestamp ON IWA_Case (StartTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_CreatorIdIndex')
  CREATE INDEX IWA_Case_CreatorIdIndex ON IWA_Case (CreatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_StateIndex')
  CREATE INDEX IWA_Case_StateIndex ON IWA_Case ("State")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_BusinessStateIndex')
  CREATE INDEX IWA_Case_BusinessStateIndex ON IWA_Case (BusinessState)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Case') AND name='IWA_Case_StateCreatorIdIndex')
  CREATE INDEX IWA_Case_StateCreatorIdIndex ON IWA_Case ("State", CreatorId)
GO

CREATE TABLE IWA_CaseOwner
(
  CaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  OwnerId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (CaseId, OwnerId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseOwner') AND name='IWA_CaseOwner_CaseIdIndex')
  CREATE INDEX IWA_CaseOwner_CaseIdIndex ON IWA_CaseOwner (CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseOwner') AND name='IWA_CaseOwner_OwnerIdIndex')
  CREATE INDEX IWA_CaseOwner_OwnerIdIndex ON IWA_CaseOwner (OwnerId)
GO

CREATE TABLE IWA_CaseLocalized
(
  CaseLocalizedId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  LanguageId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  Description VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (CaseLocalizedId),
  UNIQUE (CaseId, LanguageId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseLocalized') AND name='IWA_CaseLocalized_NameIndex')
  CREATE INDEX IWA_CaseLocalized_NameIndex ON IWA_CaseLocalized (Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseLocalized') AND name='IWA_CaseLocalized_CaseIdLanguageIdNameIndex')
  CREATE INDEX IWA_CaseLocalized_CaseIdLanguageIdNameIndex ON IWA_CaseLocalized (CaseId, LanguageId, Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseLocalized') AND name='IWA_CaseLocalized_LanguageIdNameCaseIdIndex')
  CREATE INDEX IWA_CaseLocalized_LanguageIdNameCaseIdIndex ON IWA_CaseLocalized (LanguageId, Name, CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseLocalized') AND name='IWA_CaseLocalized_CaseIdIndex')
  CREATE INDEX IWA_CaseLocalized_CaseIdIndex ON IWA_CaseLocalized (CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseLocalized') AND name='IWA_CaseLocalized_LanguageIdIndex')
  CREATE INDEX IWA_CaseLocalized_LanguageIdIndex ON IWA_CaseLocalized (LanguageId)
GO

CREATE TABLE IWA_Task
(
  TaskId BIGINT NOT NULL,
  UUID VARCHAR(144) NOT NULL,
  CaseId BIGINT NOT NULL,
  BusinessCaseId BIGINT NOT NULL,
  SecuritySystemId BIGINT NOT NULL,
  ApplicationId BIGINT NOT NULL,
  ProcessModelId BIGINT NOT NULL,
  StartTaskSwitchEventId BIGINT NOT NULL,
  EndTaskSwitchEventId BIGINT NULL,
  TaskStartId BIGINT NOT NULL,
  TaskEndId BIGINT NULL,
  WorkerId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  WorkerSessionId INTEGER NULL,
  ActivatorId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  OriginalActivatorId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  ExpiryActivatorId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  ExpiryPriority INTEGER NOT NULL,
  ExpiryTimestamp DATETIME2(3) NULL,
  ExpiryTaskStartElementPid VARCHAR(100) NULL,
  IsExpired BIT NOT NULL,
  ExpiredCreatorTaskId BIGINT NULL,
  TimeoutedCreatorIntrmdtEventId BIGINT NULL,
  DelayTimestamp DATETIME2(3) NULL,
  "State" INTEGER NOT NULL,
  BusinessState INTEGER NOT NULL,
  RequestPath VARCHAR(800) NOT NULL,
  OriginalPriority INTEGER NOT NULL,
  Priority INTEGER NOT NULL,
  StartTimestamp DATETIME2(3) NOT NULL,
  EndTimestamp DATETIME2(3) NULL,
  ModifiedTimestamp DATETIME2(3) NOT NULL,
  BusinessCalendar VARCHAR(800) NULL,
  WorkingTime BIGINT NULL,
  BusinessRuntime BIGINT NULL,
  FailedTimeoutTimestamp DATETIME2(3) NULL,
  NumberOfFailures INTEGER NOT NULL,
  NumberOfResumes INTEGER NULL,
  Category VARCHAR(800) NOT NULL DEFAULT '',
  IsUpdatedOnStart BIT NOT NULL,
  IsOffline BIT NOT NULL DEFAULT 0,
  PRIMARY KEY (TaskId),
  UNIQUE (UUID)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_CaseIdIndex')
  CREATE INDEX IWA_Task_CaseIdIndex ON IWA_Task (CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_BusinessCaseIdIndex')
  CREATE INDEX IWA_Task_BusinessCaseIdIndex ON IWA_Task (BusinessCaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_ProcessModelIdIndex')
  CREATE INDEX IWA_Task_ProcessModelIdIndex ON IWA_Task (ProcessModelId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_SecSystemIdIndex')
  CREATE INDEX IWA_Task_SecSystemIdIndex ON IWA_Task (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_ApplicationIdIndex')
  CREATE INDEX IWA_Task_ApplicationIdIndex ON IWA_Task (ApplicationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_StateIndex')
  CREATE INDEX IWA_Task_StateIndex ON IWA_Task ("State")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_BusinessStateIndex')
  CREATE INDEX IWA_Task_BusinessStateIndex ON IWA_Task (BusinessState)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_StartTimestamp')
  CREATE INDEX IWA_Task_StartTimestamp ON IWA_Task (StartTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_EndTimestamp')
  CREATE INDEX IWA_Task_EndTimestamp ON IWA_Task (EndTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_WorkingTime')
  CREATE INDEX IWA_Task_WorkingTime ON IWA_Task (WorkingTime)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_BusinessRuntime')
  CREATE INDEX IWA_Task_BusinessRuntime ON IWA_Task (BusinessRuntime)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_NumberOfResumes')
  CREATE INDEX IWA_Task_NumberOfResumes ON IWA_Task (NumberOfResumes)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_CategoryIndex')
  CREATE INDEX IWA_Task_CategoryIndex ON IWA_Task (Category)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_WorkerIdIndex')
  CREATE INDEX IWA_Task_WorkerIdIndex ON IWA_Task (WorkerId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_ActivatorIdIndex')
  CREATE INDEX IWA_Task_ActivatorIdIndex ON IWA_Task (ActivatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_OriginalActivatorIdIndex')
  CREATE INDEX IWA_Task_OriginalActivatorIdIndex ON IWA_Task (OriginalActivatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_ExpiryActivatorIdIndex')
  CREATE INDEX IWA_Task_ExpiryActivatorIdIndex ON IWA_Task (ExpiryActivatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_StateActivatorIdIndex')
  CREATE INDEX IWA_Task_StateActivatorIdIndex ON IWA_Task ("State", ActivatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_StateWorkerIdIndex')
  CREATE INDEX IWA_Task_StateWorkerIdIndex ON IWA_Task ("State", WorkerId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_StartTaskSwitchEventIdIndex')
  CREATE INDEX IWA_Task_StartTaskSwitchEventIdIndex ON IWA_Task (StartTaskSwitchEventId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_EndTaskSwitchEventIdIndex')
  CREATE INDEX IWA_Task_EndTaskSwitchEventIdIndex ON IWA_Task (EndTaskSwitchEventId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_TaskStartIdIndex')
  CREATE INDEX IWA_Task_TaskStartIdIndex ON IWA_Task (TaskStartId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_TaskEndIdIndex')
  CREATE INDEX IWA_Task_TaskEndIdIndex ON IWA_Task (TaskEndId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_ExpiredCreatorTaskIdIndex')
  CREATE INDEX IWA_Task_ExpiredCreatorTaskIdIndex ON IWA_Task (ExpiredCreatorTaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_TimeoutedCreatorIntrmdtEventIdIndex')
  CREATE INDEX IWA_Task_TimeoutedCreatorIntrmdtEventIdIndex ON IWA_Task (TimeoutedCreatorIntrmdtEventId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_TaskIdCaseIdIndex')
  CREATE INDEX IWA_Task_TaskIdCaseIdIndex ON IWA_Task (TaskId, CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_CaseIdTaskIdIndex')
  CREATE INDEX IWA_Task_CaseIdTaskIdIndex ON IWA_Task (CaseId, TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_TaskIdBusinessCaseIdIndex')
  CREATE INDEX IWA_Task_TaskIdBusinessCaseIdIndex ON IWA_Task (TaskId, BusinessCaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Task') AND name='IWA_Task_BusinessCaseIdTaskIdIndex')
  CREATE INDEX IWA_Task_BusinessCaseIdTaskIdIndex ON IWA_Task (BusinessCaseId, TaskId)
GO

CREATE TABLE IWA_TaskLocalized
(
  TaskLocalizedId BIGINT NOT NULL,
  TaskId BIGINT NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  LanguageId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  Description VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (TaskLocalizedId),
  UNIQUE (TaskId, LanguageId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskLocalized') AND name='IWA_TaskLocalized_NameIndex')
  CREATE INDEX IWA_TaskLocalized_NameIndex ON IWA_TaskLocalized (Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskLocalized') AND name='IWA_TaskLocalized_TaskIdLanguageIdNameIndex')
  CREATE INDEX IWA_TaskLocalized_TaskIdLanguageIdNameIndex ON IWA_TaskLocalized (TaskId, LanguageId, Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskLocalized') AND name='IWA_TaskLocalized_LanguageIdNameTaskIdIndex')
  CREATE INDEX IWA_TaskLocalized_LanguageIdNameTaskIdIndex ON IWA_TaskLocalized (LanguageId, Name, TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskLocalized') AND name='IWA_TaskLocalized_TaskIdIndex')
  CREATE INDEX IWA_TaskLocalized_TaskIdIndex ON IWA_TaskLocalized (TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskLocalized') AND name='IWA_TaskLocalized_LanguageIdIndex')
  CREATE INDEX IWA_TaskLocalized_LanguageIdIndex ON IWA_TaskLocalized (LanguageId)
GO

CREATE TABLE IWA_TaskData
(
  TaskId BIGINT NOT NULL,
  TaskData VARBINARY(MAX) NOT NULL,
  PRIMARY KEY (TaskId)
)
GO

CREATE TABLE IWA_StartTaskData
(
  TaskSwitchEventId BIGINT NOT NULL,
  StartTaskData VARBINARY(MAX) NOT NULL,
  PRIMARY KEY (TaskSwitchEventId)
)
GO

CREATE TABLE IWA_WorkflowEvent
(
  WorkflowEventId BIGINT NOT NULL,
  SecuritySystemId BIGINT NOT NULL,
  ApplicationId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL,
  TaskId BIGINT NULL,
  EventTimestamp DATETIME2(3) NOT NULL,
  UserId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  EventKind INTEGER NOT NULL,
  AdditionalInfo1 VARCHAR(800) NULL,
  AdditionalInfo2 VARCHAR(800) NULL,
  AdditionalInfo3 VARCHAR(800) NULL,
  AdditionalInfo4 VARCHAR(800) NULL,
  AdditionalInfo5 VARCHAR(800) NULL,
  CaseState INTEGER NOT NULL,
  TaskState INTEGER NULL,
  PRIMARY KEY (WorkflowEventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WorkflowEvent_SecSystemIdIdx')
  CREATE INDEX IWA_WorkflowEvent_SecSystemIdIdx ON IWA_WorkflowEvent (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WorkflowEvent_AppIdIdx')
  CREATE INDEX IWA_WorkflowEvent_ApplicationIdIndex ON IWA_WorkflowEvent (ApplicationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WorkflowEvent_CaseIdIndex')
  CREATE INDEX IWA_WorkflowEvent_CaseIdIndex ON IWA_WorkflowEvent (CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WorkflowEvent_TaskIdIndex')
  CREATE INDEX IWA_WorkflowEvent_TaskIdIndex ON IWA_WorkflowEvent (TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WrkflwEvnt_EvntTmstmpIdx')
  CREATE INDEX IWA_WorkflowEvent_EventTimestampIndex ON IWA_WorkflowEvent (EventTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WorkflowEvent_UserIdIndex')
  CREATE INDEX IWA_WorkflowEvent_UserIdIndex ON IWA_WorkflowEvent (UserId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_WorkflowEvent') AND name='IWA_WorkflowEvent_EventKindIdx')
  CREATE INDEX IWA_WorkflowEvent_EventKindIndex ON IWA_WorkflowEvent (EventKind)
GO

CREATE TABLE IWA_CaseMapBusinessCase
(
  BusinessCaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  CaseMapId BIGINT NOT NULL REFERENCES IWA_CaseMap(CaseMapId) ON DELETE CASCADE,
  PRIMARY KEY (BusinessCaseId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMapBusinessCase') AND name='IWA_CaseMapBusCase_CsMpIdIdx')
  CREATE INDEX IWA_CaseMapBusCase_CsMpIdIdx ON IWA_CaseMapBusinessCase (CaseMapId)
GO

CREATE TABLE IWA_CaseMapEvent
(
  CaseMapEventId BIGINT NOT NULL,
  BusinessCaseId BIGINT NOT NULL,
  "Timestamp" DATETIME2(3) NOT NULL,
  Kind INTEGER NOT NULL,
  Stage VARCHAR(800) NOT NULL,
  Process VARCHAR(800) NOT NULL,
  ProcessCaseId BIGINT NULL,
  Milestone VARCHAR(800) NOT NULL,
  Reason VARCHAR(800) NOT NULL,
  ProcessingState INTEGER NOT NULL,
  ProcessingErrorMessage VARCHAR(3000) NOT NULL,
  ProcessingErrorCount INTEGER NOT NULL,
  ProcessingRetryTimestamp DATETIME2(3) NULL,
  PRIMARY KEY (CaseMapEventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMapEvent') AND name='IWA_CaseMapEvent_BcId')
  CREATE INDEX IWA_CaseMapEvent_BcId ON IWA_CaseMapEvent (BusinessCaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMapEvent') AND name='IWA_CaseMapEvent_PrcRtryTstmp')
  CREATE INDEX IWA_CaseMapEvent_PrcRtryTstmp ON IWA_CaseMapEvent (ProcessingRetryTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMapEvent') AND name='IWA_CaseMapEvent_PrcState')
  CREATE INDEX IWA_CaseMapEvent_PrcState ON IWA_CaseMapEvent (ProcessingState)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseMapEvent') AND name='IWA_CaseMapEvent_ProcessCaseIdIndex')
  CREATE INDEX IWA_CaseMapEvent_ProcessCaseIdIndex ON IWA_CaseMapEvent (ProcessCaseId)
GO

CREATE TABLE IWA_IntermediateEvent
(
  IntermediateEventId BIGINT NOT NULL,
  TaskStartId BIGINT NOT NULL,
  SecuritySystemId BIGINT NOT NULL,
  ApplicationId BIGINT NOT NULL,
  TaskId BIGINT NULL,
  EventId VARCHAR(200) NOT NULL,
  "State" INTEGER NOT NULL,
  EventTimestamp DATETIME2(3) NULL,
  TimeoutTimestamp DATETIME2(3) NULL,
  TimeoutTaskStartElementId VARCHAR(800) NULL,
  TimeoutAction INTEGER NOT NULL,
  AdditionalInformation VARCHAR(8000) NULL,
  PRIMARY KEY (IntermediateEventId),
  UNIQUE (TaskStartId, EventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntermediateEvent_SecSystemId')
  CREATE INDEX IWA_IntermediateEvent_SecSystemId ON IWA_IntermediateEvent (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntermediateEvent_ApplicationId')
  CREATE INDEX IWA_IntermediateEvent_ApplicationId ON IWA_IntermediateEvent (ApplicationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntermediateEvent_TaskStartId')
  CREATE INDEX IWA_IntrmdtEvnt_TaskStartId ON IWA_IntermediateEvent (TaskStartId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntermediateEvent_TaskId')
  CREATE INDEX IWA_IntermediateEvent_TaskId ON IWA_IntermediateEvent (TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntermediateEvent_EventId')
  CREATE INDEX IWA_IntermediateEvent_EventId ON IWA_IntermediateEvent (EventId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntermediateEvent_State')
  CREATE INDEX IWA_IntermediateEvent_State ON IWA_IntermediateEvent ("State")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_IntermediateEvent') AND name='IWA_IntrmdtEvnt_TimeoutTmstmp')
  CREATE INDEX IWA_IntrmdtEvnt_TimeoutTmstmp ON IWA_IntermediateEvent (TimeoutTimestamp)
GO

CREATE TABLE IWA_IntermediateEventData
(
  IntermediateEventId BIGINT NOT NULL,
  ResultObjectData VARBINARY(MAX) NOT NULL,
  PRIMARY KEY (IntermediateEventId)
)
GO

CREATE TABLE IWA_Note
(
  NoteId BIGINT NOT NULL,
  SecurityMemberId VARCHAR(210) NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE SET NULL,
  UserName VARCHAR(800) NOT NULL,
  "Timestamp" DATETIME2(3) NOT NULL,
  Note VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (NoteId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Note') AND name='IWA_Note_SecurityMemberIdIndex')
  CREATE INDEX IWA_Note_SecurityMemberIdIndex ON IWA_Note (SecurityMemberId)
GO

CREATE TABLE IWA_TaskNote
(
  TaskId BIGINT NOT NULL,
  NoteId BIGINT NOT NULL,
  PRIMARY KEY (TaskId, NoteId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskNote') AND name='IWA_TaskNote_TaskIdIndex')
  CREATE INDEX IWA_TaskNote_TaskIdIndex ON IWA_TaskNote (TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskNote') AND name='IWA_TaskNote_NoteIdIndex')
  CREATE INDEX IWA_TaskNote_NoteIdIndex ON IWA_TaskNote (NoteId)
GO

CREATE TABLE IWA_CaseNote
(
  CaseId BIGINT NOT NULL,
  NoteId BIGINT NOT NULL,
  PRIMARY KEY (CaseId, NoteId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseNote') AND name='IWA_CaseNote_CaseIdIndex')
  CREATE INDEX IWA_CaseNote_CaseIdIndex ON IWA_CaseNote (CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseNote') AND name='IWA_CaseNote_NoteIdIndex')
  CREATE INDEX IWA_CaseNote_NoteIdIndex ON IWA_CaseNote (NoteId)
GO

CREATE TABLE IWA_TaskCustomStringField
(
  TaskCustomStringFieldId BIGINT NOT NULL,
  TaskId BIGINT NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" VARCHAR(8000) NOT NULL,
  PRIMARY KEY (TaskCustomStringFieldId),
  UNIQUE (TaskId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomStringField') AND name='IWA_TaskCstmStringFld_TaskIdNameValueIndex')
  CREATE INDEX IWA_TaskCstmStringFld_TaskIdNameValueIndex ON IWA_TaskCustomStringField (TaskId, Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomStringField') AND name='IWA_TaskCstmStringFld_NameValueTaskIdIndex')
  CREATE INDEX IWA_TaskCstmStringFld_NameValueTaskIdIndex ON IWA_TaskCustomStringField (Name, "Value", TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomStringField') AND name='IWA_TaskCustomStringField_TaskIdIndex')
  CREATE INDEX IWA_TaskCustomStringField_TaskIdIndex ON IWA_TaskCustomStringField (TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomStringField') AND name='IWA_TaskCstmStringFldNmValIdx')
  CREATE INDEX IWA_TaskCstmStringFldNmValIdx ON IWA_TaskCustomStringField (Name, "Value")
GO

CREATE TABLE IWA_TaskCustomTextField
(
  TaskCustomTextFieldId BIGINT NOT NULL,
  TaskId BIGINT NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (TaskCustomTextFieldId),
  UNIQUE (TaskId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomTextField') AND name='IWA_TaskCstmTextFldNameIdx')
  CREATE INDEX IWA_TaskCstmTextFldNameIdx ON IWA_TaskCustomTextField (Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomTextField') AND name='IWA_TaskCustomTextField_TaskIdIndex')
  CREATE INDEX IWA_TaskCustomTextField_TaskIdIndex ON IWA_TaskCustomTextField (TaskId)
GO

CREATE TABLE IWA_TaskCustomNumberField
(
  TaskCustomNumberFieldId BIGINT NOT NULL,
  TaskId BIGINT NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" DECIMAL(30, 10) NOT NULL,
  PRIMARY KEY (TaskCustomNumberFieldId),
  UNIQUE (TaskId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomNumberField') AND name='IWA_TaskCstmNumberFldNmValIdx')
  CREATE INDEX IWA_TaskCstmNumberFldNmValIdx ON IWA_TaskCustomNumberField (Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomNumberField') AND name='IWA_TaskCstmNumberFld_TaskIdNameValueIndex')
  CREATE INDEX IWA_TaskCstmNumberFld_TaskIdNameValueIndex ON IWA_TaskCustomNumberField (TaskId, Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomNumberField') AND name='IWA_TaskCstmNumberFld_NameValueTaskIdIndex')
  CREATE INDEX IWA_TaskCstmNumberFld_NameValueTaskIdIndex ON IWA_TaskCustomNumberField (Name, "Value", TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomNumberField') AND name='IWA_TaskCustomNumberField_TaskIdIndex')
  CREATE INDEX IWA_TaskCustomNumberField_TaskIdIndex ON IWA_TaskCustomNumberField (TaskId)
GO

CREATE TABLE IWA_TaskCustomTimestampField
(
  TaskCustomTimestampFieldId BIGINT NOT NULL,
  TaskId BIGINT NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" DATETIME2(3) NOT NULL,
  PRIMARY KEY (TaskCustomTimestampFieldId),
  UNIQUE (TaskId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomTimestampField') AND name='IWA_TaskCstmTmstmpFldNmValIdx')
  CREATE INDEX IWA_TaskCstmTmstmpFldNmValIdx ON IWA_TaskCustomTimestampField (Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomTimestampField') AND name='IWA_TaskCstmTimestampFld_TaskIdNameValueIndex')
  CREATE INDEX IWA_TaskCstmTimestampFld_TaskIdNameValueIndex ON IWA_TaskCustomTimestampField (TaskId, Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomTimestampField') AND name='IWA_TaskCstmTimestampFld_NameValueTaskIdIndex')
  CREATE INDEX IWA_TaskCstmTimestampFld_NameValueTaskIdIndex ON IWA_TaskCustomTimestampField (Name, "Value", TaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskCustomTimestampField') AND name='IWA_TaskCustomTimestampField_TaskIdIndex')
  CREATE INDEX IWA_TaskCustomTimestampField_TaskIdIndex ON IWA_TaskCustomTimestampField (TaskId)
GO

CREATE TABLE IWA_CaseCustomStringField
(
  CaseCustomStringFieldId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" VARCHAR(8000) NOT NULL,
  PRIMARY KEY (CaseCustomStringFieldId),
  UNIQUE (CaseId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomStringField') AND name='IWA_CaseCstmStringFld_CaseIdIndex')
  CREATE INDEX IWA_CaseCstmStringFld_CaseIdIndex ON IWA_CaseCustomStringField (CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomStringField') AND name='IWA_CaseCstmStringFld_CaseIdNameValueIndex')
  CREATE INDEX IWA_CaseCstmStringFld_CaseIdNameValueIndex ON IWA_CaseCustomStringField (CaseId, Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomStringField') AND name='IWA_CaseCstmStringFld_NameValueCaseIdIndex')
  CREATE INDEX IWA_CaseCstmStringFld_NameValueCaseIdIndex ON IWA_CaseCustomStringField (Name, "Value", CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomStringField') AND name='IWA_CaseCstmStringFldNmValIdx')
  CREATE INDEX IWA_CaseCstmStringFldNmValIdx ON IWA_CaseCustomStringField (Name, "Value")
GO

CREATE TABLE IWA_CaseCustomTextField
(
  CaseCustomTextFieldId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" VARCHAR(MAX) NOT NULL,
  PRIMARY KEY (CaseCustomTextFieldId),
  UNIQUE (CaseId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomTextField') AND name='IWA_CaseCstmTextFldNameIdx')
  CREATE INDEX IWA_CaseCstmTextFldNameIdx ON IWA_CaseCustomTextField (Name)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomTextField') AND name='IWA_CaseCstmTextFld_CaseIdIndex')
  CREATE INDEX IWA_CaseCstmTextFld_CaseIdIndex ON IWA_CaseCustomTextField (CaseId)
GO

CREATE TABLE IWA_CaseCustomNumberField
(
  CaseCustomNumberFieldId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" DECIMAL(30, 10) NOT NULL,
  PRIMARY KEY (CaseCustomNumberFieldId),
  UNIQUE (CaseId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomNumberField') AND name='IWA_CaseCstmNumberFldNmValIdx')
  CREATE INDEX IWA_CaseCstmNumberFldNmValIdx ON IWA_CaseCustomNumberField (Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomNumberField') AND name='IWA_CaseCstmNumberFld_CaseIdNameValueIndex')
  CREATE INDEX IWA_CaseCstmNumberFld_CaseIdNameValueIndex ON IWA_CaseCustomNumberField (CaseId, Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomNumberField') AND name='IWA_CaseCstmNumberFld_NameValueCaseIdIndex')
  CREATE INDEX IWA_CaseCstmNumberFld_NameValueCaseIdIndex ON IWA_CaseCustomNumberField (Name, "Value", CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomNumberField') AND name='IWA_CaseCstmNumberFld_CaseIdIndex')
  CREATE INDEX IWA_CaseCstmNumberFld_CaseIdIndex ON IWA_CaseCustomNumberField (CaseId)
GO

CREATE TABLE IWA_CaseCustomTimestampField
(
  CaseCustomTimestampFieldId BIGINT NOT NULL,
  CaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR(800) NOT NULL,
  "Value" DATETIME2(3) NOT NULL,
  PRIMARY KEY (CaseCustomTimestampFieldId),
  UNIQUE (CaseId, Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomTimestampField') AND name='IWA_CaseCstmTmstmpFldNmValIdx')
  CREATE INDEX IWA_CaseCstmTmstmpFldNmValIdx ON IWA_CaseCustomTimestampField (Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomTimestampField') AND name='IWA_CaseCstmTmstmpFld_CaseIdNameValueIndex')
  CREATE INDEX IWA_CaseCstmTmstmpFld_CaseIdNameValueIndex ON IWA_CaseCustomTimestampField (CaseId, Name, "Value")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomTimestampField') AND name='IWA_CaseCstmTmstmpFld_NameValueCaseIdIndex')
  CREATE INDEX IWA_CaseCstmTmstmpFld_NameValueCaseIdIndex ON IWA_CaseCustomTimestampField (Name, "Value", CaseId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_CaseCustomTimestampField') AND name='IWA_CaseCstmTmstmpFld_CaseIdIndex')
  CREATE INDEX IWA_CaseCstmTmstmpFld_CaseIdIndex ON IWA_CaseCustomTimestampField (CaseId)
GO

CREATE TABLE IWA_UserLocation
(
  UserLocationId BIGINT NOT NULL,
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  "Type" VARCHAR(800) NOT NULL,
  Note VARCHAR(8000) NOT NULL,
  Name VARCHAR(800) NOT NULL,
  Address VARCHAR(800) NOT NULL,
  Latitude DECIMAL(10, 8) NOT NULL,
  Longitude DECIMAL(11, 8) NOT NULL,
  Altitude DECIMAL(8, 3) NOT NULL,
  AccuracyHorizontal DECIMAL(8, 3) NULL,
  AccuracyVertical DECIMAL(8, 3) NULL,
  Speed DECIMAL(8, 3) NULL,
  Bearing DECIMAL(6, 3) NULL,
  LocationTimestamp DATETIME2(3) NULL,
  PRIMARY KEY (UserLocationId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_UserLocation') AND name='IWA_UserLocation_SecurityMemberId')
  CREATE INDEX IWA_UserLocation_SecurityMemberId ON IWA_UserLocation (SecurityMemberId)
GO

CREATE TABLE IWA_TaskLocation
(
  TaskLocationId BIGINT NOT NULL,
  TaskId BIGINT NOT NULL,
  "Type" VARCHAR(800) NOT NULL,
  Note VARCHAR(8000) NOT NULL,
  Name VARCHAR(800) NOT NULL,
  Address VARCHAR(800) NOT NULL,
  Latitude DECIMAL(10, 8) NOT NULL,
  Longitude DECIMAL(11, 8) NOT NULL,
  Altitude DECIMAL(8, 3) NOT NULL,
  AccuracyHorizontal DECIMAL(8, 3) NULL,
  AccuracyVertical DECIMAL(8, 3) NULL,
  Speed DECIMAL(8, 3) NULL,
  Bearing DECIMAL(6, 3) NULL,
  LocationTimestamp DATETIME2(3) NULL,
  PRIMARY KEY (TaskLocationId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskLocation') AND name='IWA_TaskLocation_TaskId')
  CREATE INDEX IWA_TaskLocation_TaskId ON IWA_TaskLocation (TaskId)
GO

CREATE TABLE IWA_TaskSignalEventReceiver
(
  TaskSignalEventId BIGINT NOT NULL,
  WaitingTaskId BIGINT NOT NULL,
  SignalCodePattern VARCHAR(800) NOT NULL,
  SignaledTaskTaskStartId BIGINT NOT NULL REFERENCES IWA_TaskStart(TaskStartId) ON DELETE CASCADE,
  StartedSignaledTaskId BIGINT NULL,
  PRIMARY KEY (TaskSignalEventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskSignalEventReceiver') AND name='IWA_TskSigEvntRcvr_WtingTaskId')
  CREATE INDEX IWA_TskSigEvntRcvr_WtingTaskId ON IWA_TaskSignalEventReceiver (WaitingTaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskSignalEventReceiver') AND name='IWA_TskSigEvntRcvr_SgTskTskId')
  CREATE INDEX IWA_TskSigEvntRcvr_SgTskTskId ON IWA_TaskSignalEventReceiver (SignaledTaskTaskStartId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_TaskSignalEventReceiver') AND name='IWA_TskSigEvntRcvr_StrtSgTskId')
  CREATE INDEX IWA_TskSigEvntRcvr_StrtSgTskId ON IWA_TaskSignalEventReceiver (StartedSignaledTaskId)
GO

CREATE TABLE IWA_SignaledTask
(
  SignaledTaskId BIGINT NOT NULL,
  SignalCodePattern VARCHAR(800) NOT NULL,
  ReceivedSignalEventId BIGINT NULL,
  PRIMARY KEY (SignaledTaskId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignaledTask') AND name='IWA_SigTask_RecvdSignalEventId')
  CREATE INDEX IWA_SigTask_RecvdSignalEventId ON IWA_SignaledTask (ReceivedSignalEventId)
GO

CREATE TABLE IWA_SignalEvent
(
  SignalEventId BIGINT NOT NULL,
  SecuritySystemId BIGINT NOT NULL,
  ApplicationId BIGINT NULL REFERENCES IWA_Application(ApplicationId) ON DELETE CASCADE,
  SignalCode VARCHAR(800) NOT NULL,
  SentTimestamp DATETIME2(3) NOT NULL,
  SentById VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  SentByTaskId BIGINT NULL,
  SentByProcessElementPid VARCHAR(800) NULL,
  PRIMARY KEY (SignalEventId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignalEvent') AND name='IWA_SignalEvent_SecuritySystemId')
  CREATE INDEX IWA_SignalEvent_SecuritySystemId ON IWA_SignalEvent (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignalEvent') AND name='IWA_SignalEvent_ApplicationId')
  CREATE INDEX IWA_SignalEvent_ApplicationId ON IWA_SignalEvent (ApplicationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignalEvent') AND name='IWA_SignalEvent_SignalCode')
  CREATE INDEX IWA_SignalEvent_SignalCode ON IWA_SignalEvent (SignalCode)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignalEvent') AND name='IWA_SignalEvent_SentTimestamp')
  CREATE INDEX IWA_SignalEvent_SentTimestamp ON IWA_SignalEvent (SentTimestamp)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignalEvent') AND name='IWA_SignalEvent_SentByTaskId')
  CREATE INDEX IWA_SignalEvent_SentByTaskId ON IWA_SignalEvent (SentByTaskId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SignalEvent') AND name='IWA_SignalEvent_SentById')
  CREATE INDEX IWA_SignalEvent_SentById ON IWA_SignalEvent (SentById)
GO

CREATE TABLE IWA_SignalEventData
(
  SignalEventId BIGINT NOT NULL,
  SignalData VARBINARY(MAX) NOT NULL,
  PRIMARY KEY (SignalEventId)
)
GO

CREATE TABLE IWA_SecurityDescriptor
(
  SecurityDescriptorId BIGINT NOT NULL,
  SecurityDescriptorTypeId BIGINT NOT NULL,
  PRIMARY KEY (SecurityDescriptorId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityDescriptor') AND name='IWA_SecurityDescriptor_SecurityDescriptorTypeId')
  CREATE INDEX IWA_SecurityDescriptor_SecurityDescriptorTypeId ON IWA_SecurityDescriptor (SecurityDescriptorTypeId)
GO

CREATE TABLE IWA_SecuritySystem
(
  SecuritySystemId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  SecurityDescriptorId BIGINT NOT NULL REFERENCES IWA_SecurityDescriptor(SecurityDescriptorId),
  PRIMARY KEY (SecuritySystemId),
  UNIQUE (Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecuritySystem') AND name='IWA_SecuritySystem_SecurityDescriptorId')
  CREATE INDEX IWA_SecuritySystem_SecurityDescriptorId ON IWA_SecuritySystem (SecurityDescriptorId)
GO

CREATE TABLE IWA_Language
(
  LanguageId BIGINT NOT NULL,
  SecuritySystemId BIGINT NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId),
  IsDefault BIT NOT NULL,
  Locale VARCHAR(100) NOT NULL,
  PRIMARY KEY (LanguageId),
  UNIQUE (SecuritySystemId, Locale)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Language') AND name='IWA_Language_SecuritySystemId')
  CREATE INDEX IWA_Language_SecuritySystemId ON IWA_Language (SecuritySystemId)
GO

CREATE TABLE IWA_PermissionGroup
(
  PermissionGroupId BIGINT NOT NULL,
  ParentPermissionGroupId BIGINT NULL,
  Name VARCHAR(800) NOT NULL,
  PRIMARY KEY (PermissionGroupId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_PermissionGroup') AND name='IWA_PermissionGroup_ParentPermissionGroupId')
  CREATE INDEX IWA_PermissionGroup_ParentPermissionGroupId ON IWA_PermissionGroup (ParentPermissionGroupId)
GO

CREATE TABLE IWA_SecurityDescriptorType
(
  SecurityDescriptorTypeId BIGINT NOT NULL,
  RootPermissionGroupId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  PRIMARY KEY (SecurityDescriptorTypeId),
  UNIQUE (Name)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_SecurityDescriptorType') AND name='IWA_SecurityDescriptorType_RootPermissionGroupId')
  CREATE INDEX IWA_SecurityDescriptorType_RootPermissionGroupId ON IWA_SecurityDescriptorType (RootPermissionGroupId)
GO

CREATE TABLE IWA_AccessControl
(
  AccessControlId BIGINT NOT NULL,
  SecurityDescriptorId BIGINT NOT NULL,
  PermissionId BIGINT NOT NULL,
  GrantDeny BIT NOT NULL,
  SecurityMemberId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (AccessControlId),
  UNIQUE (SecurityDescriptorId, PermissionId, SecurityMemberId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_AccessControl') AND name='IWA_AccessControl_SecDescIdIdx')
  CREATE INDEX IWA_AccessControl_SecurityDescriptorIdIndex ON IWA_AccessControl (SecurityDescriptorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_AccessControl') AND name='IWA_AccessControl_SecMembrIdIdx')
  CREATE INDEX IWA_AccessControl_SecMembrIdIdx ON IWA_AccessControl (SecurityMemberId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_AccessControl') AND name='IWA_AccessControl_PermissionIdIdx')
  CREATE INDEX IWA_AccessControl_PermissionIdIdx ON IWA_AccessControl (PermissionId)
GO

CREATE TABLE IWA_Permission
(
  PermissionId BIGINT NOT NULL,
  Name VARCHAR(800) NOT NULL,
  PRIMARY KEY (PermissionId),
  UNIQUE (Name)
)
GO

CREATE TABLE IWA_PermissionGroupPermission
(
  PermissionGroupId BIGINT NOT NULL,
  PermissionId BIGINT NOT NULL,
  PRIMARY KEY (PermissionGroupId, PermissionId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_PermissionGroupPermission') AND name='IWA_PermissionGroupPermission_PermissionGroupId')
  CREATE INDEX IWA_PermissionGroupPermission_PermissionGroupId ON IWA_PermissionGroupPermission (PermissionGroupId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_PermissionGroupPermission') AND name='IWA_PermissionGroupPermission_PermissionId')
  CREATE INDEX IWA_PermissionGroupPermission_PermissionId ON IWA_PermissionGroupPermission (PermissionId)
GO

CREATE TABLE IWA_Blob
(
  BlobId BIGINT NOT NULL,
  UUID VARCHAR(36) NOT NULL,
  ApplicationId BIGINT NOT NULL REFERENCES IWA_Application(ApplicationId) ON DELETE CASCADE,
  SecuritySystemId BIGINT NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId),
  FileName VARCHAR(1020) NOT NULL,
  FilePath VARCHAR(3000) NOT NULL,
  "Path" VARCHAR(3000) NOT NULL,
  CreatorId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  CreatedAt DATETIME2(3) NOT NULL,
  "Size" BIGINT NOT NULL,
  ModifierId VARCHAR(210) NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  ModifiedAt DATETIME2(3) NOT NULL,
  Description VARCHAR(4096) NULL,
  PRIMARY KEY (UUID),
  UNIQUE (BlobId),
  UNIQUE (SecuritySystemId, "Path"),
  UNIQUE (ApplicationId, FilePath)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_FilePath')
  CREATE INDEX IWA_Blob_FilePath ON IWA_Blob (FilePath)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_Path')
  CREATE INDEX IWA_Blob_Path ON IWA_Blob ("Path")
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_CreatorId')
  CREATE INDEX IWA_Blob_CreatorId ON IWA_Blob (CreatorId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_ModifierId')
  CREATE INDEX IWA_Blob_ModifierId ON IWA_Blob (ModifierId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_CreatedAt')
  CREATE INDEX IWA_Blob_CreatedAt ON IWA_Blob (CreatedAt)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_FileName')
  CREATE INDEX IWA_Blob_FileName ON IWA_Blob (FileName)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_ModifiedAt')
  CREATE INDEX IWA_Blob_ModifiedAt ON IWA_Blob (ModifiedAt)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_SecuritySystemId')
  CREATE INDEX IWA_Blob_SecuritySystemId ON IWA_Blob (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Blob') AND name='IWA_Blob_ApplicationId')
  CREATE INDEX IWA_Blob_ApplicationId ON IWA_Blob (ApplicationId)
GO

CREATE TABLE IWA_BusinessData
(
  BusinessDataId VARCHAR(100) NOT NULL,
  Version BIGINT NOT NULL,
  FormatVersion INTEGER NOT NULL DEFAULT 63000,
  ObjectType VARCHAR(1020) NOT NULL,
  ObjectValue VARCHAR(MAX) NOT NULL,
  SecuritySystemId BIGINT NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId),
  CreatedAt DATETIME2(3) NOT NULL,
  CreatedByUserName VARCHAR(800) NOT NULL,
  CreatedByAppId BIGINT NOT NULL,
  ModifiedAt DATETIME2(3) NOT NULL,
  ModifiedByUserName VARCHAR(800) NOT NULL,
  ModifiedByAppId BIGINT NOT NULL,
  PRIMARY KEY (BusinessDataId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_TypeIdx')
  CREATE INDEX IWA_BusinessData_TypeIdx ON IWA_BusinessData (ObjectType)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_SecSysIdx')
  CREATE INDEX IWA_BusinessData_SecSysIdx ON IWA_BusinessData (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_CrtdAtIdx')
  CREATE INDEX IWA_BusinessData_CrtdAtIdx ON IWA_BusinessData (CreatedAt)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_CrtdByUserIdx')
  CREATE INDEX IWA_BusinessData_CrtdByUserIdx ON IWA_BusinessData (CreatedByUserName)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_CrtdByAppIdx')
  CREATE INDEX IWA_BusinessData_CrtdByAppIdx ON IWA_BusinessData (CreatedByAppId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_ModAtIdx')
  CREATE INDEX IWA_BusinessData_ModAtIdx ON IWA_BusinessData (ModifiedAt)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_ModByUserIdx')
  CREATE INDEX IWA_BusinessData_ModByUserIdx ON IWA_BusinessData (ModifiedByUserName)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_ModByAppIdx')
  CREATE INDEX IWA_BusinessData_ModByAppIdx ON IWA_BusinessData (ModifiedByAppId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessData') AND name='IWA_BusinessData_TypeIdxSecSysIdx')
  CREATE INDEX IWA_BusinessData_TypeIdxSecSysIdx ON IWA_BusinessData (ObjectType, SecuritySystemId)
GO

CREATE TABLE IWA_BusinessCaseData
(
  BusinessDataId VARCHAR(100) NOT NULL,
  ObjectType VARCHAR(1020) NOT NULL,
  BusinessCaseId BIGINT NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  PRIMARY KEY (BusinessDataId),
  UNIQUE (BusinessCaseId, ObjectType)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_BusinessCaseData') AND name='IWA_BusinessCaseData_BusinessCaseId')
  CREATE INDEX IWA_BusinessCaseData_BusinessCaseId ON IWA_BusinessCaseData (BusinessCaseId)
GO

CREATE TABLE IWA_Notification
(
  NotificationId VARCHAR(36) NOT NULL,
  Kind VARCHAR(400) NOT NULL,
  Payload VARCHAR(MAX) NOT NULL,
  SecuritySystemId BIGINT NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId) ON DELETE CASCADE,
  ProcessModelVersionId BIGINT NULL REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE SET NULL,
  Template VARCHAR(1020) NULL,
  CreatedAt DATETIME2(3) NOT NULL,
  IsUshered BIT NOT NULL,
  PRIMARY KEY (NotificationId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Notification') AND name='IWA_Notification_KindIndex')
  CREATE INDEX IWA_Notification_KindIndex ON IWA_Notification (Kind)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Notification') AND name='IWA_Notification_SecuritySystemIdIndex')
  CREATE INDEX IWA_Notification_SecuritySystemIdIndex ON IWA_Notification (SecuritySystemId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Notification') AND name='IWA_Notification_ProcessModelVersionIdIndex')
  CREATE INDEX IWA_Notification_ProcessModelVersionIdIndex ON IWA_Notification (ProcessModelVersionId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_Notification') AND name='IWA_Notification_CreatedAtIndex')
  CREATE INDEX IWA_Notification_CreatedAtIndex ON IWA_Notification (CreatedAt)
GO

CREATE TABLE IWA_NotificationReceiver
(
  NotificationId VARCHAR(36) NOT NULL REFERENCES IWA_Notification(NotificationId) ON DELETE CASCADE,
  ReceiverId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (NotificationId, ReceiverId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationReceiver') AND name='IWA_NotificationReceiver_NotificationIdIndex')
  CREATE INDEX IWA_NotificationReceiver_NotificationIdIndex ON IWA_NotificationReceiver (NotificationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationReceiver') AND name='IWA_NotificationReceiver_ReceiverIdIndex')
  CREATE INDEX IWA_NotificationReceiver_ReceiverIdIndex ON IWA_NotificationReceiver (ReceiverId)
GO

CREATE TABLE IWA_NotificationDelivery
(
  NotificationDeliveryId VARCHAR(36) NOT NULL,
  NotificationId VARCHAR(36) NULL,
  Channel VARCHAR(400) NOT NULL,
  ReceiverId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  DeliveredAt DATETIME2(3) NULL,
  ReadAt DATETIME2(3) NULL,
  Hide BIT NOT NULL,
  DeliveryState INTEGER NOT NULL,
  Error VARCHAR(1020) NULL,
  ErrorTimeoutTimestamp DATETIME2(3) NULL,
  NumberOfErrors INTEGER NOT NULL,
  PRIMARY KEY (NotificationDeliveryId)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_NotificationIdIndex')
  CREATE INDEX IWA_NotificationDelivery_NotificationIdIndex ON IWA_NotificationDelivery (NotificationId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_ChannelIndex')
  CREATE INDEX IWA_NotificationDelivery_ChannelIndex ON IWA_NotificationDelivery (Channel)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_ReceiverIdIndex')
  CREATE INDEX IWA_NotificationDelivery_ReceiverIdIndex ON IWA_NotificationDelivery (ReceiverId)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_DeliveredAtIndex')
  CREATE INDEX IWA_NotificationDelivery_DeliveredAtIndex ON IWA_NotificationDelivery (DeliveredAt)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_ReadAtIndex')
  CREATE INDEX IWA_NotificationDelivery_ReadAtIndex ON IWA_NotificationDelivery (ReadAt)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_HideIndex')
  CREATE INDEX IWA_NotificationDelivery_HideIndex ON IWA_NotificationDelivery (Hide)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationDelivery') AND name='IWA_NotificationDelivery_DeliveryStateIndex')
  CREATE INDEX IWA_NotificationDelivery_DeliveryStateIndex ON IWA_NotificationDelivery (DeliveryState)
GO

CREATE TABLE IWA_NotificationSubscription
(
  NotificationSubscriptionId BIGINT NOT NULL,
  Channel VARCHAR(400) NOT NULL,
  Kind VARCHAR(400) NOT NULL,
  SubscriberId VARCHAR(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  Subscribed BIT NOT NULL,
  PRIMARY KEY (NotificationSubscriptionId),
  UNIQUE (SubscriberId, Kind, Channel)
)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationSubscription') AND name='IWA_NotificationSubscription_ChannelIndex')
  CREATE INDEX IWA_NotificationSubscription_ChannelIndex ON IWA_NotificationSubscription (Channel)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationSubscription') AND name='IWA_NotificationSubscription_KindIndex')
  CREATE INDEX IWA_NotificationSubscription_KindIndex ON IWA_NotificationSubscription (Kind)
GO
IF NOT EXISTS (SELECT * FROM sysindexes WHERE id=object_id('IWA_NotificationSubscription') AND name='IWA_NotificationSubscription_SubscriberIdIndex')
  CREATE INDEX IWA_NotificationSubscription_SubscriberIdIndex ON IWA_NotificationSubscription (SubscriberId)
GO

ALTER TABLE IWA_AsyncProcessCaseData ADD FOREIGN KEY (CaseId) REFERENCES IWA_Case(CaseId) ON DELETE CASCADE
GO
ALTER TABLE IWA_Application ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_SecurityMember ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_Role ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_User ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_Case ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_CaseLocalized ADD FOREIGN KEY (LanguageId) REFERENCES IWA_Language(LanguageId)
GO
ALTER TABLE IWA_Task ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_TaskLocalized ADD FOREIGN KEY (LanguageId) REFERENCES IWA_Language(LanguageId)
GO
ALTER TABLE IWA_WorkflowEvent ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_IntermediateEvent ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_SignalEvent ADD FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
GO
ALTER TABLE IWA_AccessControl ADD FOREIGN KEY (PermissionId) REFERENCES IWA_Permission(PermissionId) ON DELETE CASCADE
GO
CREATE TRIGGER IWA_ApplicationDeleteTrigger
  ON IWA_Application FOR DELETE AS

  DELETE IWA_ProcessModel FROM IWA_ProcessModel, deleted
  WHERE IWA_ProcessModel.ApplicationId = deleted.ApplicationId


GO

CREATE TRIGGER IWA_ProcessModelDeleteTrigger
  ON IWA_ProcessModel FOR DELETE AS

  DELETE IWA_ProcessModelVersion FROM IWA_ProcessModelVersion, deleted
  WHERE IWA_ProcessModelVersion.ProcessModelId = deleted.ProcessModelId

  DELETE IWA_Case FROM IWA_Case, deleted
  WHERE IWA_Case.ProcessModelId = deleted.ProcessModelId


GO

CREATE TRIGGER IWA_ProcessModelVersionDeleteTrigger
  ON IWA_ProcessModelVersion FOR DELETE AS

  DELETE IWA_TaskElement FROM IWA_TaskElement, deleted
  WHERE IWA_TaskElement.ProcessModelVersionId = deleted.ProcessModelVersionId


GO

CREATE TRIGGER IWA_LibraryDeleteTrigger
  ON IWA_Library FOR DELETE AS

  UPDATE IWA_LibrarySpecification  SET IWA_LibrarySpecification.ResolvedLibraryId=NULL
  FROM IWA_LibrarySpecification, deleted
  WHERE IWA_LibrarySpecification.ResolvedLibraryId = deleted.LibraryId


GO

CREATE TRIGGER IWA_RoleDeleteTrigger
  ON IWA_Role FOR DELETE AS
  IF (@@ROWCOUNT > 0)
  BEGIN

    DELETE IWA_Role FROM IWA_Role, deleted
    WHERE IWA_Role.ParentSecurityMemberId = deleted.SecurityMemberId

    DELETE IWA_RoleRoleMember FROM IWA_RoleRoleMember, deleted
    WHERE IWA_RoleRoleMember.RoleSecurityMemberId = deleted.SecurityMemberId

    DELETE IWA_RoleRoleMember FROM IWA_RoleRoleMember, deleted
    WHERE IWA_RoleRoleMember.RoleMemberSecurityMemberId = deleted.SecurityMemberId

    END
GO

CREATE TRIGGER IWA_UserDeleteTrigger
  ON IWA_User FOR DELETE AS

  DELETE IWA_UserSubstitute FROM IWA_UserSubstitute, deleted
  WHERE IWA_UserSubstitute.SubstituteUserSecurityMemberId = deleted.SecurityMemberId


GO

CREATE TRIGGER IWA_TaskElementDeleteTrigger
  ON IWA_TaskElement FOR DELETE AS

  DELETE IWA_TaskSwitchEvent FROM IWA_TaskSwitchEvent, deleted
  WHERE IWA_TaskSwitchEvent.TaskElementId = deleted.TaskElementId

  DELETE IWA_TaskStart FROM IWA_TaskStart, deleted
  WHERE IWA_TaskStart.TaskElementId = deleted.TaskElementId

  DELETE IWA_TaskEnd FROM IWA_TaskEnd, deleted
  WHERE IWA_TaskEnd.TaskElementId = deleted.TaskElementId


GO

CREATE TRIGGER IWA_TaskStartDeleteTrigger
  ON IWA_TaskStart FOR DELETE AS

  DELETE IWA_IntermediateEvent FROM IWA_IntermediateEvent, deleted
  WHERE IWA_IntermediateEvent.TaskStartId = deleted.TaskStartId


GO

CREATE TRIGGER IWA_TaskSwitchDeleteTrigger
  ON IWA_TaskSwitchEvent FOR DELETE AS

  DELETE IWA_StartTaskData FROM IWA_StartTaskData, deleted
  WHERE IWA_StartTaskData.TaskSwitchEventId = deleted.TaskSwitchEventId


GO

CREATE TRIGGER IWA_CaseDeleteTrigger
  ON IWA_Case FOR DELETE AS
  IF (@@ROWCOUNT > 0)
  BEGIN

    UPDATE IWA_Case    SET IWA_Case.BusinessCaseId=NULL
    FROM IWA_Case, deleted
    WHERE IWA_Case.BusinessCaseId = deleted.CaseId

    DELETE IWA_TaskSwitchEvent FROM IWA_TaskSwitchEvent, deleted
    WHERE IWA_TaskSwitchEvent.CaseId = deleted.CaseId

    DELETE IWA_Task FROM IWA_Task, deleted
    WHERE IWA_Task.CaseId = deleted.CaseId

    DELETE IWA_Task FROM IWA_Task, deleted
    WHERE IWA_Task.BusinessCaseId = deleted.CaseId

    DELETE IWA_CaseMapEvent FROM IWA_CaseMapEvent, deleted
    WHERE IWA_CaseMapEvent.ProcessCaseId = deleted.CaseId

    DELETE IWA_CaseNote FROM IWA_CaseNote, deleted
    WHERE IWA_CaseNote.CaseId = deleted.CaseId

    DELETE IWA_WorkflowEvent FROM IWA_WorkflowEvent, deleted
    WHERE IWA_WorkflowEvent.CaseId = deleted.CaseId

    END
GO

CREATE TRIGGER IWA_TaskDeleteTrigger
  ON IWA_Task FOR DELETE AS

  UPDATE IWA_Case  SET IWA_Case.CreatorTaskId=NULL
  FROM IWA_Case, deleted
  WHERE IWA_Case.CreatorTaskId = deleted.TaskId

  UPDATE IWA_SignalEvent  SET IWA_SignalEvent.SentByTaskId=NULL
  FROM IWA_SignalEvent, deleted
  WHERE IWA_SignalEvent.SentByTaskId = deleted.TaskId

  DELETE IWA_IntermediateEvent FROM IWA_IntermediateEvent, deleted
  WHERE IWA_IntermediateEvent.TaskId = deleted.TaskId

  DELETE IWA_SignaledTask FROM IWA_SignaledTask, deleted
  WHERE IWA_SignaledTask.SignaledTaskId = deleted.TaskId

  DELETE IWA_TaskLocation FROM IWA_TaskLocation, deleted
  WHERE IWA_TaskLocation.TaskId = deleted.TaskId

  DELETE IWA_TaskNote FROM IWA_TaskNote, deleted
  WHERE IWA_TaskNote.TaskId = deleted.TaskId

  DELETE IWA_TaskSignalEventReceiver FROM IWA_TaskSignalEventReceiver, deleted
  WHERE IWA_TaskSignalEventReceiver.WaitingTaskId = deleted.TaskId

  DELETE IWA_TaskData FROM IWA_TaskData, deleted
  WHERE IWA_TaskData.TaskId = deleted.TaskId

  DELETE IWA_WorkflowEvent FROM IWA_WorkflowEvent, deleted
  WHERE IWA_WorkflowEvent.TaskId = deleted.TaskId


GO

CREATE TRIGGER IWA_CaseMapBusinessCaseDeleteTrigger
  ON IWA_CaseMapBusinessCase FOR DELETE AS

  DELETE IWA_CaseMapEvent FROM IWA_CaseMapEvent, deleted
  WHERE IWA_CaseMapEvent.BusinessCaseId = deleted.BusinessCaseId


GO

CREATE TRIGGER IWA_IntermediateEventTrigger
  ON IWA_IntermediateEvent FOR DELETE AS

  DELETE IWA_IntermediateEventData FROM IWA_IntermediateEventData, deleted
  WHERE IWA_IntermediateEventData.IntermediateEventId = deleted.IntermediateEventId


GO

CREATE TRIGGER IWA_TaskNoteDeleteTrigger
  ON IWA_TaskNote FOR DELETE AS

  DELETE IWA_Note FROM IWA_Note, deleted
  WHERE IWA_Note.NoteId = deleted.NoteId


GO

CREATE TRIGGER IWA_CaseNoteDeleteTrigger
  ON IWA_CaseNote FOR DELETE AS

  DELETE IWA_Note FROM IWA_Note, deleted
  WHERE IWA_Note.NoteId = deleted.NoteId


GO

CREATE TRIGGER IWA_SignaledTaskDeleteTrigger
  ON IWA_SignaledTask FOR DELETE AS

  UPDATE IWA_TaskSignalEventReceiver  SET IWA_TaskSignalEventReceiver.StartedSignaledTaskId=NULL
  FROM IWA_TaskSignalEventReceiver, deleted
  WHERE IWA_TaskSignalEventReceiver.StartedSignaledTaskId = deleted.SignaledTaskId


GO

CREATE TRIGGER IWA_SignalEventDeleteTrigger
  ON IWA_SignalEvent FOR DELETE AS

  UPDATE IWA_SignaledTask  SET IWA_SignaledTask.ReceivedSignalEventId=NULL
  FROM IWA_SignaledTask, deleted
  WHERE IWA_SignaledTask.ReceivedSignalEventId = deleted.SignalEventId

  DELETE IWA_SignalEventData FROM IWA_SignalEventData, deleted
  WHERE IWA_SignalEventData.SignalEventId = deleted.SignalEventId


GO

CREATE TRIGGER IWA_SecurityDescriptorDeleteTrigger
  ON IWA_SecurityDescriptor FOR DELETE AS

  DELETE IWA_AccessControl FROM IWA_AccessControl, deleted
  WHERE IWA_AccessControl.SecurityDescriptorId = deleted.SecurityDescriptorId


GO

CREATE TRIGGER IWA_PermissionGroupDeleteTrigger
  ON IWA_PermissionGroup FOR DELETE AS
  IF (@@ROWCOUNT > 0)
  BEGIN

    DELETE IWA_PermissionGroupPermission FROM IWA_PermissionGroupPermission, deleted
    WHERE IWA_PermissionGroupPermission.PermissionGroupId = deleted.PermissionGroupId

    DELETE IWA_PermissionGroup FROM IWA_PermissionGroup, deleted
    WHERE IWA_PermissionGroup.ParentPermissionGroupId = deleted.PermissionGroupId

    END
GO

CREATE TRIGGER IWA_PermissionDeleteTrigger
  ON IWA_Permission FOR DELETE AS

  DELETE IWA_PermissionGroupPermission FROM IWA_PermissionGroupPermission, deleted
  WHERE IWA_PermissionGroupPermission.PermissionId = deleted.PermissionId


GO

CREATE TRIGGER IWA_NotificationDeleteTrigger
  ON IWA_Notification FOR DELETE AS

  DELETE IWA_NotificationDelivery FROM IWA_NotificationDelivery, deleted
  WHERE IWA_NotificationDelivery.NotificationId = deleted.NotificationId


GO

INSERT INTO IWA_Version (Version) VALUES (160)
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (0, 'AdministrateWorkflow')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (1, 'ViewOwnCreatedCaseWorkflowHistory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (2, 'ViewOwnWorkTaskWorkflowHistory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (3, 'ViewProcessData')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (4, 'ViewTasksOfCase')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (5, 'DelegateTasks')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (6, 'ViewUserSubstitutes')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (7, 'EditUserSubstitutes')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (8, 'ViewUserAbsences')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (9, 'EditUserAbsences')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (10, 'ViewPageArchive')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (100, 'UserSetPassword')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (101, 'UserSetOwnPassword')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (102, 'UserSetFullName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (103, 'UserSetOwnFullName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (104, 'UserReadFullName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (105, 'UserReadOwnFullName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (106, 'UserReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (107, 'UserReadOwnName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (108, 'UserSetEMailAddress')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (109, 'UserSetOwnEMailAddress')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (110, 'UserReadEMailAddress')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (111, 'UserReadOwnEMailAddress')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (112, 'UserSetEMailLanguage')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (113, 'UserSetOwnEMailLanguage')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (114, 'UserReadEMailLanguage')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (115, 'UserReadOwnEMailLanguage')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (116, 'UserSetEMailNotification')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (117, 'UserSetOwnEMailNotification')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (118, 'UserReadEMailNotification')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (119, 'UserReadOwnEMailNotification')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (120, 'UserSetProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (121, 'UserSetOwnProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (122, 'UserReadProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (123, 'UserReadOwnProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (124, 'UserRemoveProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (125, 'UserRemoveOwnProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (126, 'UserReadPropertyNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (127, 'UserReadOwnPropertyNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (128, 'UserAddRole')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (129, 'UserRemoveRole')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (130, 'UserReadRoles')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (131, 'UserReadOwnRoles')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (132, 'UserCreateAbsence')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (133, 'UserCreateOwnAbsence')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (134, 'UserDeleteAbsence')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (135, 'UserDeleteOwnAbsence')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (136, 'UserReadAbsences')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (137, 'UserReadOwnAbsences')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (138, 'UserCreateSubstitute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (139, 'UserCreateOwnSubstitute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (140, 'UserDeleteSubstitute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (141, 'UserDeleteOwnSubstitute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (142, 'UserReadSubstitutes')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (143, 'UserReadOwnSubstitutes')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (144, 'UserReadSubstitutions')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (145, 'UserReadOwnSubstitutions')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (146, 'UserReadExternalSecurityName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (147, 'UserReadOwnExternalSecurityName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (148, 'RoleReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (149, 'RoleReadDisplayDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (150, 'RoleReadDisplayDescriptionTemplate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (151, 'RoleSetDisplayDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (152, 'RoleTreeNavigation')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (153, 'RoleCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (154, 'RoleDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (155, 'RoleSetExternalSecurityName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (156, 'RoleReadExternalSecurityName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (157, 'RoleReadUsers')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (158, 'RoleMove')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (159, 'RoleReadDisplayName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (160, 'RoleReadDisplayNameTemplate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (161, 'RoleSetDisplayName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (162, 'RoleReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (163, 'UserCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (164, 'UserDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (165, 'UserReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (166, 'SessionReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (167, 'SessionDestroy')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (168, 'SessionCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (169, 'SecurityReadExternalSecuritySystemProvider')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (170, 'SecurityReadConfiguration')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (171, 'SecurityTriggerSynchronization')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (172, 'SessionWriteHttpSessionIdentifier')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (173, 'SecurityDescriptorReadAllPermissions')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (174, 'SecurityDescriptorReadOwner')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (175, 'SecurityDescriptorReadSecurityDescriptorType')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (176, 'SecurityDescriptorReadAccessControl')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (177, 'SecurityDescriptorGrantPermission')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (178, 'SecurityDescriptorUngrantPermission')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (179, 'SecurityDescriptorDenyPermission')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (180, 'SecurityDescriptorUndenyPermission')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (181, 'SecurityDescriptorReadPermissionAccess')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (182, 'SecurityDescriptorReadAllPermissionAccess')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (183, 'SessionReadSessionUserUnknown')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (184, 'SessionReadSessionUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (185, 'SessionAssignRole')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (186, 'SessionWriteOwnAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (187, 'SessionWriteAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (188, 'SessionReadOwnAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (189, 'SessionReadAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (190, 'SessionDeleteOwnAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (191, 'SessionDeleteAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (192, 'SessionReadOwnAttributeNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (193, 'SessionReadAttributeNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (194, 'SessionLogoutSessionUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (195, 'SessionReadAbsent')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (196, 'SessionReadActiveSubstitutions')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (197, 'SessionReadIsMemberThroughActiveSubstitution')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (198, 'SessionReadHttpSessionIdentifier')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (199, 'SessionReadAllMySessions')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (200, 'SessionCanActAsUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (201, 'SessionHasRole')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (202, 'ApplicationCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (203, 'ApplicationDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (204, 'ApplicationRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (205, 'ApplicationReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (206, 'SystemPropertyReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (207, 'SystemPropertyRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (208, 'LanguageCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (209, 'LanguageRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (210, 'LanguageReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (211, 'ProcessModelVersionRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (212, 'ProcessModelVersionReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (213, 'SystemPropertyReadValue')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (214, 'SystemPropertyWriteValue')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (215, 'ProcessModelDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (216, 'ProcessModelRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (217, 'ProcessModelCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (218, 'ApplicationReadActivityOperationState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (219, 'ApplicationReadActivityState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (220, 'ApplicationReadAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (221, 'ApplicationReadAttributeNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (222, 'ApplicationDeleteAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (223, 'ApplicationWriteAttribute')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (224, 'ApplicationReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (225, 'ApplicationReadSecuritySystemName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (226, 'ApplicationReadFileAreaDirectory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (227, 'LibraryReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (228, 'ApplicationReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (229, 'ApplicationReadOwnerName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (230, 'ApplicationWriteDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (231, 'ApplicationWriteDownloadPassword')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (232, 'ApplicationWriteFileDirectory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (233, 'ApplicationWriteOwnerName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (234, 'ApplicationWriteOwnerPassword')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (235, 'ExternalDatabaseConfigurationRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (236, 'ExternalDatabaseConfigurationDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (237, 'ExternalDatabaseConfigurationCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (238, 'ApplicationActivate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (239, 'ApplicationDeactivate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (240, 'ApplicationLock')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (241, 'ExternalDatabaseConfigurationReadAccessFlags')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (242, 'ExternalDatabaseConfigurationWriteAccessFlags')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (243, 'ExternalDatabaseConfigurationReadDatabaseConnectionConfiguration')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (244, 'ExternalDatabaseConfigurationWriteDatabaseConnectionConfiguration')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (245, 'ExternalDatabaseConfigurationReadMaxConnections')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (246, 'ExternalDatabaseConfigurationWriteMaxConnections')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (247, 'ExternalDatabaseConfigurationReadUserFriendlyName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (248, 'ExternalDatabaseConfigurationWriteUserFriendlyName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (249, 'ProcessModelReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (250, 'ProcessModelReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (251, 'ProcessModelWriteDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (252, 'ProcessModelReadProjectDirectory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (253, 'ProcessModelReadFileDirectory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (254, 'ProcessModelVersionCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (257, 'ProcessModelReadActivityState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (258, 'ProcessModelReadInheritedActivityState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (259, 'ProcessModelReadActivityOperationState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (260, 'ProcessModelActivate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (261, 'ProcessModelDeactivate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (262, 'ProcessModelLock')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (263, 'ProcessModelVersionReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (264, 'ProcessModelVersionReadVersionName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (265, 'ProcessModelVersionReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (266, 'ProcessModelVersionReadVersionNumber')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (267, 'ProcessModelVersionReadActivityState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (268, 'ProcessModelVersionReadInheritedActivityState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (269, 'ProcessModelVersionReadActivityOperationState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (270, 'ProcessModelVersionReadReleaseState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (271, 'ProcessModelVersionReadNumberOfElements')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (272, 'ProcessModelVersionReadLastChangeDate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (273, 'ProcessModelVersionReadLastChangeBy')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (274, 'ProcessModelVersionReadLastChangeFromHost')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (275, 'ProcessModelVersionReadReleaseTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (276, 'ProcessModelVersionReadScheduledReleaseTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (277, 'ProcessModelVersionReadProjectDirectory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (278, 'ProjectRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (279, 'ProjectReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (280, 'ProcessModelVersionWriteUpdate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (281, 'ProcessModelVersionActivate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (282, 'ProcessModelVersionDeactivate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (283, 'ProcessModelVersionLock')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (284, 'ProcessModelVersionRelease')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (285, 'ProcessModelVersionDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (286, 'ProcessModelVersionReadAllRunningCasesFinished')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (287, 'LibraryCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (288, 'LibraryDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (289, 'LibraryRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (290, 'LibraryReadId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (291, 'LibraryWriteId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (292, 'LibraryReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (293, 'LibraryWriteName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (294, 'LibraryReadProvider')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (295, 'LibraryWriteProvider')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (296, 'LibraryReadVersion')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (297, 'LibraryWriteVersion')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (298, 'LibraryReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (299, 'LibraryWriteDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (300, 'LibrarySpecificationCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (301, 'LibrarySpecificationDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (302, 'LibrarySpecificationRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (303, 'LibrarySpecificationReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (304, 'LibraryReadDependent')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (305, 'LibraryReadAllDependent')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (306, 'LibraryReadRequired')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (307, 'LibraryReadAllRequired')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (308, 'LibraryReadCircularDependent')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (309, 'LibraryReadResolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (310, 'LibrarySpecificationReadId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (311, 'LibrarySpecificationWriteId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (312, 'LibrarySpecificationReadResolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (313, 'LibraryVersionSpecificationRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (314, 'LibraryVersionSpecificationCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (315, 'LibraryVersionSpecificationDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (320, 'LibrarySpecificationReadResolvedLibraryResolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (321, 'LibraryVersionSpecificationReadVersion')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (322, 'LibraryVersionSpecificationWriteVersion')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (323, 'LibraryVersionSpecificationReadInclusive')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (324, 'LibraryVersionSpecificationWriteInclusive')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (325, 'ProcessModelReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (326, 'ApplicationReadFileDirectory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (327, 'TaskRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (328, 'CaseDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (329, 'CaseReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (330, 'CaseRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (331, 'CaseCategoryReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (332, 'TaskReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (333, 'TaskCategoryReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (334, 'WorkflowEventReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (335, 'IntermediateEventReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (336, 'IntermediateEventFire')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (337, 'IntermediateEventElementReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (338, 'IntermediateEventElementRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (339, 'IntermediateEventElementDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (340, 'IntermediateEventElementCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (341, 'StartEventElementRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (342, 'StartEventElementReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (343, 'StartEventElementDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (344, 'StartEventElementCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (345, 'StartElementRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (346, 'StartElementReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (347, 'StartElementDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (348, 'StartElementCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (349, 'ProcessStartReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (350, 'ProcessStartRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (351, 'StartElementReadActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (352, 'StartElementReadVisible')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (353, 'StartEventElementReadEventBeanClassName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (354, 'StartEventElementReadEventBeanConfiguration')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (355, 'StartEventElementReadEventBeanEnabled')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (356, 'StartEventElementWriteEventBeanEnabled')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (357, 'TaskElementRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (358, 'TaskStartReadUserFriendlyStartRequestPath')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (359, 'TaskStartReadStartRequestPath')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (360, 'TaskEndReadJoinPathId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (361, 'TaskEndReadJoinRequestPath')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (362, 'TaskEndReadFullJoinRequestPath')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (363, 'TaskElementReadJoinPathes')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (364, 'TaskElementReadKind')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (365, 'TaskStartReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (366, 'TaskEndReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (367, 'TaskElementReadProcessElementId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (368, 'TaskElementReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (369, 'TaskElementReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (370, 'TaskSwitchEventReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (371, 'TaskReadOwnCaseTasks')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (372, 'CaseReadOwnCaseOfTask')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (373, 'IntermediateEventWriteTimeoutTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (374, 'IntermediateEventReadTimeoutTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (375, 'IntermediateEventReadTimeoutTaskStartElementId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (376, 'IntermediateEventReadTimeoutAction')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (377, 'IntermediateEventReadState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (378, 'IntermediateEventReadResultObject')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (380, 'IntermediateEventReadEventTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (381, 'IntermediateEventReadEventIdentifier')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (382, 'IntermediateEventReadAdditionalInformation')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (383, 'IntermediateEventElementWriteEventBeanConfiguration')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (384, 'IntermediateEventElementWriteEventBeanClassName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (385, 'IntermediateEventElementWriteEventBeanEnabled')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (386, 'IntermediateEventElementReadEventBeanEnabled')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (387, 'IntermediateEventElementReadEventBeanConfiguration')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (388, 'IntermediateEventElementReadEventBeanClassName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (390, 'TaskReadAllOwnWorking')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (391, 'TaskReadAllOwnLocked')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (392, 'CaseReadAllOwnRoleStarted')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (393, 'CaseReadAllOwnStarted')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (394, 'TaskReadAllOwnWork')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (395, 'TaskReadAllOwnWorkedOn')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (396, 'TaskReadAllOwnRoleWorkedOn')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (397, 'ProcessStartReadAllOwnStartable')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (398, 'TaskParkOwnWorkingTask')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (399, 'TaskResetOwnWorkingTask')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (400, 'CaseCategoriesReadAllOwnStarted')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (401, 'TaskCategoriesReadAllOwnWork')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (402, 'TaskCategoriesReadAllWorkedOn')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (403, 'CaseReadCreatorUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (404, 'CaseDestroy')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (405, 'CaseReadStartTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (406, 'CaseReadEndTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (407, 'CaseReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (408, 'CaseWriteName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (409, 'CaseReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (410, 'CaseWriteDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (411, 'CaseReadState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (412, 'NoteCreate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (413, 'NoteReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (414, 'NoteDelete')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (415, 'CaseWriteAdditionalProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (416, 'CaseReadAdditionalProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (417, 'CaseReadAllAdditionalPropertyNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (418, 'CaseReadBusinessCorrespondentId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (419, 'CaseWriteBusinessCorrespondentId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (420, 'CaseReadBusinessCreatorUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (421, 'CaseWriteBusinessCreatorUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (422, 'CaseReadBusinessMainContactDocumentDatabaseCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (423, 'CaseWriteBusinessMainContactDocumentDatabaseCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (424, 'CaseReadBusinessMainContactFolderId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (425, 'CaseWriteBusinessMainContactFolderId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (426, 'CaseReadBusinessMainContactId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (427, 'CaseWriteBusinessMainContactId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (428, 'CaseReadBusinessMainContactName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (429, 'CaseWriteBusinessMainContactName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (430, 'CaseReadBusinessMainContactType')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (431, 'CaseWriteBusinessMainContactType')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (432, 'CaseReadBusinessMilestoneTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (433, 'CaseWriteBusinessMilestoneTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (434, 'CaseReadBusinessObjectCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (435, 'CaseWriteBusinessObjectCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (436, 'CaseReadBusinessObjectDocumentDatabaseCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (437, 'CaseWriteBusinessObjectDocumentDatabaseCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (438, 'CaseReadBusinessObjectFolderId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (439, 'CaseWriteBusinessObjectFolderId')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (440, 'CaseReadBusinessObjectName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (441, 'CaseWriteBusinessObjectName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (442, 'CaseReadBusinessPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (443, 'CaseWriteBusinessPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (444, 'CaseReadBusinessStartTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (445, 'CaseWriteBusinessStartTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (446, 'CaseReadCreatorUserName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (447, 'CaseReadCustomDecimalField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (448, 'CaseWriteCustomDecimalField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (449, 'CaseReadCustomDecimalField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (450, 'CaseWriteCustomDecimalField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (451, 'CaseReadCustomDecimalField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (452, 'CaseWriteCustomDecimalField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (453, 'CaseReadCustomDecimalField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (454, 'CaseWriteCustomDecimalField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (455, 'CaseReadCustomDecimalField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (456, 'CaseWriteCustomDecimalField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (457, 'CaseReadCustomTimestampField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (458, 'CaseWriteCustomTimestampField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (459, 'CaseReadCustomTimestampField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (460, 'CaseWriteCustomTimestampField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (461, 'CaseReadCustomTimestampField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (462, 'CaseWriteCustomTimestampField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (463, 'CaseReadCustomTimestampField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (464, 'CaseWriteCustomTimestampField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (465, 'CaseReadCustomTimestampField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (466, 'CaseWriteCustomTimestampField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (467, 'CaseReadCustomVarCharField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (468, 'CaseWriteCustomVarCharField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (469, 'CaseReadCustomVarCharField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (470, 'CaseWriteCustomVarCharField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (471, 'CaseReadCustomVarCharField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (472, 'CaseWriteCustomVarCharField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (473, 'CaseReadCustomVarCharField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (474, 'CaseWriteCustomVarCharField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (475, 'CaseReadCustomVarCharField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (476, 'CaseWriteCustomVarCharField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (477, 'CaseReadDisplayDescriptionTemplate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (478, 'CaseReadDisplayNameTemplate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (479, 'CaseReadPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (480, 'CaseWritePriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (481, 'CaseReadProcessCategoryCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (482, 'CaseReadProcessCategoryName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (483, 'CaseWriteProcessCategory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (484, 'CaseReadProcessCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (485, 'CaseReadProcessName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (486, 'CaseWriteProcess')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (487, 'CaseReadTypeCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (488, 'CaseReadTypeName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (489, 'CaseWriteType')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (490, 'CaseReadSubTypeCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (491, 'CaseReadSubTypeName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (492, 'CaseWriteSubType')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (493, 'TaskSwitchEventRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (494, 'IntermediateEventRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (495, 'TaskReadWorkerSession')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (496, 'TaskReadState')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (497, 'TaskReadRequestPath')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (498, 'TaskReadName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (499, 'TaskWriteName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (500, 'TaskReadDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (501, 'TaskWriteDescription')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (502, 'TaskReadPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (503, 'TaskReadExpiryPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (504, 'TaskWriteExpiryPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (505, 'TaskReadOriginalPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (506, 'TaskWriteOriginalPriority')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (507, 'TaskReadActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (508, 'TaskReadActivatorName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (509, 'TaskWriteActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (510, 'TaskReadExpiryActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (511, 'TaskReadExpiryActivatorName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (512, 'TaskWriteExpiryActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (513, 'TaskReadOriginalActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (514, 'TaskReadOriginalActivatorName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (515, 'TaskWriteOriginalActivator')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (516, 'TaskReadDelayTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (517, 'TaskWriteDelayTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (518, 'TaskReadExpiryTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (520, 'TaskReadWorkerUser')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (521, 'TaskReadStartTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (522, 'TaskReadEndTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (523, 'TaskReadBusinessMilestoneTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (524, 'TaskWriteBusinessMilestoneTimestamp')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (525, 'TaskReadDisplayDescriptionTemplate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (526, 'TaskReadExpiryTaskStartElementPid')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (527, 'TaskReadKindCode')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (528, 'TaskReadKindName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (529, 'TaskWriteKind')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (530, 'TaskReadDisplayNameTemplate')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (531, 'TaskReadWorkerUserName')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (532, 'TaskReadCustomDecimalField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (533, 'TaskWriteCustomDecimalField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (534, 'TaskReadCustomDecimalField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (535, 'TaskWriteCustomDecimalField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (536, 'TaskReadCustomDecimalField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (537, 'TaskWriteCustomDecimalField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (538, 'TaskReadCustomDecimalField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (539, 'TaskWriteCustomDecimalField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (540, 'TaskReadCustomDecimalField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (541, 'TaskWriteCustomDecimalField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (542, 'TaskReadCustomTimestampField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (543, 'TaskWriteCustomTimestampField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (544, 'TaskReadCustomTimestampField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (545, 'TaskWriteCustomTimestampField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (546, 'TaskReadCustomTimestampField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (547, 'TaskWriteCustomTimestampField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (548, 'TaskReadCustomTimestampField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (549, 'TaskWriteCustomTimestampField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (550, 'TaskReadCustomTimestampField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (551, 'TaskWriteCustomTimestampField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (552, 'TaskReadCustomVarCharField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (553, 'TaskWriteCustomVarCharField1')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (554, 'TaskReadCustomVarCharField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (555, 'TaskWriteCustomVarCharField2')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (556, 'TaskReadCustomVarCharField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (557, 'TaskWriteCustomVarCharField3')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (558, 'TaskReadCustomVarCharField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (559, 'TaskWriteCustomVarCharField4')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (560, 'TaskReadCustomVarCharField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (561, 'TaskWriteCustomVarCharField5')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (562, 'TaskReadIsExpiry')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (563, 'TaskReset')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (564, 'TaskDestroy')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (565, 'TaskWriteAdditionalProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (566, 'TaskReadAdditionalProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (567, 'TaskReadAllAdditionalPropertyNames')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (568, 'TaskStartRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (569, 'TaskEndRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (570, 'CaseReadAllOwnInvolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (571, 'CaseCategoriesReadAllOwnInvolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (572, 'CaseReadAllOwnRoleInvolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (573, 'CaseCategoriesReadAllOwnRoleInvolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (574, 'ApplicationReadConfigurationProperty')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (575, 'ApplicationReadAllConfigurationProperties')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (576, 'ApplicationConfigurationPropertyReadValue')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (577, 'ApplicationConfigurationPropertyWriteValue')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (578, 'PageArchiveReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (579, 'TaskPageArchiveReadAll')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (580, 'TaskReadProcessData')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (581, 'RolePropertyRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (582, 'RolePropertyWrite')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (583, 'LibrarySpecificationWriteResolved')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (584, 'ApplicationCustomPropertyRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (585, 'ApplicationCustomPropertyWrite')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (586, 'DocumentRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (587, 'DocumentWrite')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (588, 'DocumentOfInvolvedCaseRead')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (589, 'DocumentOfInvolvedCaseWrite')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (590, 'CaseAttachToBusinessCase')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (591, 'CaseReadSubCases')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (592, 'CaseReadCategory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (593, 'CaseWriteCategory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (594, 'TaskReadCategory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (595, 'TaskWriteCategory')
GO
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (596, 'TaskWriteExpiryTimestamp')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (0, NULL, 'ApplicationSpecificPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (1, 0, 'PersonalPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (2, 0, 'ManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (3, 1, 'PersonalSecurityPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (4, 1, 'PersonalWorkflowPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (5, 2, 'SecurityManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (6, 2, 'WorkflowManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (7, 5, 'UserPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (8, 5, 'RolePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (9, 5, 'SecurityDescriptorPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (10, NULL, 'SystemPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (11, 10, 'SystemwideApplicationConfigurationManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (12, 10, 'SystemwideSecurityManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (13, 10, 'SystemwideWorkflowManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (14, 12, 'SystemwideUserPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (15, 12, 'SystemwideRolePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (16, 12, 'SystemwideSecurityDescriptorPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (17, 3, 'PersonalUserAbsencePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (18, 3, 'PersonalUserSubstitutePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (19, 3, 'PersonalUserPropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (20, 7, 'UserAbsencePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (21, 7, 'UserSubstitutePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (22, 7, 'UserPropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (23, 14, 'SystemwideUserAbsencePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (24, 14, 'SystemwideUserSubstitutePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (25, 14, 'SystemwideUserPropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (26, 3, 'PersonalUserRolePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (27, 7, 'UserRolePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (28, 14, 'SystemwideUserRolePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (29, 5, 'SessionPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (30, 12, 'SystemwideSessionPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (31, 11, 'SystemwideApplicationPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (32, 11, 'SystemwideLanguagePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (33, 11, 'SystemwideSystemPropertiesPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (34, 2, 'ApplicationConfigurationManagementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (35, 34, 'ApplicationPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (37, 34, 'ProcessModelPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (38, 34, 'ProcessModelVersionPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (39, 34, 'LibraryPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (40, 34, 'ExternalDatabaseConfigurationPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (41, 11, 'SystemwideProcessModelPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (42, 11, 'SystemwideProcessModelVersionPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (43, 11, 'SystemwideLibraryPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (44, 11, 'SystemwideExternalDatabaseConfigurationPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (45, 6, 'StartElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (46, 13, 'SystemwideStartElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (47, 6, 'StartEventElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (48, 13, 'SystemwideStartEventElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (49, 6, 'ProcessStartPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (50, 13, 'SystemwideProcessStartPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (51, 6, 'TaskStartPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (52, 13, 'SystemwideTaskStartPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (53, 6, 'TaskEndPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (54, 13, 'SystemwideTaskEndPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (55, 6, 'TaskElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (56, 13, 'SystemwideTaskElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (57, 6, 'TaskSwitchEventPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (58, 13, 'SystemwideTaskSwitchEventPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (59, 6, 'TaskPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (60, 13, 'SystemwideTaskPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (61, 6, 'CasePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (62, 13, 'SystemwideCasePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (63, 6, 'NotePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (64, 13, 'SystemwideNotePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (65, 59, 'TaskCustomFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (66, 60, 'SystemwideTaskCustomFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (67, 59, 'TaskBusinessFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (68, 60, 'SystemwideTaskBusinessFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (69, 59, 'TaskSystemFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (70, 60, 'SystemwideTaskSystemFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (71, 59, 'CaseCustomFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (72, 60, 'SystemwideCaseCustomFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (73, 59, 'CaseBusinessFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (74, 60, 'SystemwideCaseBusinessFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (75, 59, 'CaseSystemFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (76, 60, 'SystemwideCaseSystemFieldsPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (77, 6, 'WorkflowEventPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (78, 13, 'SystemwideWorkflowEventPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (79, 6, 'IntermediateEventPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (80, 13, 'SystemwideIntermediateEventPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (81, 6, 'IntermediateEventElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (82, 13, 'SystemwideIntermediateEventElementPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (83, 6, 'PageArchivePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (84, 13, 'SystemwidePageArchivePermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (85, 15, 'SystemwideRolePropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (86, 8, 'RolePropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (87, 35, 'ApplicationPropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (88, 31, 'SystemwideApplicationPropertyPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (89, 6, 'DocumentPermissions')
GO
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (90, 13, 'SystemwideDocumentPermissions')
GO
INSERT INTO IWA_SecurityDescriptorType (SecurityDescriptorTypeId, RootPermissionGroupId, Name) VALUES (0, 10, 'System')
GO
INSERT INTO IWA_SecurityDescriptorType (SecurityDescriptorTypeId, RootPermissionGroupId, Name) VALUES (1, 0, 'Application')
GO
INSERT INTO IWA_SecurityDescriptor (SecurityDescriptorId, SecurityDescriptorTypeId) VALUES (0, 0)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 100)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 100)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 101)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 102)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 102)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 103)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 104)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 104)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 105)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 106)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 106)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 107)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 108)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 108)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 109)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 110)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 110)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 111)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 112)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 112)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 113)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 114)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 114)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 115)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 116)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 116)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 117)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 118)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 118)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 119)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 120)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 120)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 121)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 122)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 122)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 123)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 124)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 124)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 125)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 126)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 126)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 127)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (27, 128)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (28, 128)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (27, 129)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (28, 129)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (27, 130)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (28, 130)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (26, 131)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (20, 132)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (23, 132)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (17, 133)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (20, 134)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (23, 134)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (17, 135)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (20, 136)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (23, 136)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (17, 137)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 138)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 138)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 139)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 140)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 140)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 141)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 142)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 142)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 143)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 144)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 144)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 145)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 146)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 146)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 147)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 148)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 148)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 149)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 149)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 150)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 150)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 151)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 151)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 152)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 152)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 153)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 153)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 154)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 154)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 155)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 155)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 156)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 156)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 157)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 157)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 158)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 158)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 159)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 159)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 160)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 160)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 161)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 161)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 162)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 162)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 163)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 163)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 164)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 164)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 165)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 165)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 166)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 166)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 167)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 167)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 168)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 168)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (5, 169)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (12, 169)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (5, 170)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (12, 170)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (5, 171)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (12, 171)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 172)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 172)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 173)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 173)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 174)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 174)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 175)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 175)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 176)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 176)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 177)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 177)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 178)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 178)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 179)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 179)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 180)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 180)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 181)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 181)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 182)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 182)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 183)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 183)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 184)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 184)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 185)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 185)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 186)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 187)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 187)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 188)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 189)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 189)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 190)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 191)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 191)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 192)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 193)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 193)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 194)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 194)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 195)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 195)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 196)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 196)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 197)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 197)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 198)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 198)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 199)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 199)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 200)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 200)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 201)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 201)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 202)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 203)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 204)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 204)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 205)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 206)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 207)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (32, 208)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (32, 209)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (32, 210)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 211)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 211)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 212)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 212)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 213)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 214)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 215)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 215)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 216)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 216)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 217)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 217)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 218)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 218)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 219)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 219)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 220)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 220)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 221)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 221)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 222)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 222)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 223)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 223)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 224)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 224)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 225)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 225)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 226)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 226)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 227)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 227)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 228)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 228)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 229)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 229)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 230)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 230)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 231)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 231)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 232)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 232)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 233)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 233)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 234)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 234)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 235)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 235)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 236)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 236)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 237)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 237)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 238)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 238)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 239)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 239)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 240)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 240)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 241)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 241)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 242)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 242)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 243)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 243)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 244)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 244)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 245)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 245)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 246)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 246)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 247)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 247)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 248)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 248)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 249)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 249)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 250)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 250)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 251)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 251)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 252)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 252)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 253)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 253)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 254)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 254)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 257)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 257)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 258)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 258)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 259)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 259)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 260)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 260)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 261)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 261)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 262)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 262)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 263)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 263)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 264)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 264)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 265)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 265)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 266)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 266)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 267)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 267)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 268)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 268)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 269)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 269)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 270)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 270)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 271)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 271)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 272)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 272)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 273)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 273)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 274)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 274)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 275)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 275)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 276)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 276)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 277)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 277)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 278)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 278)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 279)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 279)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 280)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 280)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 281)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 281)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 282)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 282)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 283)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 283)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 284)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 284)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 285)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 285)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 286)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 286)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 287)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 287)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 288)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 288)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 289)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 289)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 290)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 290)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 291)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 291)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 292)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 292)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 293)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 293)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 294)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 294)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 295)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 295)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 296)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 296)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 297)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 297)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 298)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 298)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 299)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 299)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 300)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 300)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 301)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 301)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 302)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 302)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 303)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 303)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 304)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 304)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 305)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 305)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 306)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 306)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 307)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 307)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 308)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 308)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 309)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 309)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 310)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 310)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 311)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 311)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 312)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 312)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 313)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 313)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 314)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 314)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 315)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 315)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 320)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 320)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 321)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 321)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 322)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 322)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 323)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 323)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 324)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 324)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 325)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 325)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 326)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 326)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 327)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 327)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 328)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 328)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 329)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 329)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 330)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 330)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 331)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 331)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 332)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 332)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 333)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 333)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (77, 334)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (78, 334)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 335)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 335)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 336)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 336)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 337)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 337)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 338)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 338)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 339)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 339)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 340)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 340)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 341)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 341)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 342)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 342)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 343)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 343)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 344)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 344)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 345)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 345)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 346)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 346)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 347)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 347)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 348)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 348)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (49, 349)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (50, 349)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (49, 350)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (50, 350)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 351)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 351)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 352)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 352)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 353)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 353)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 354)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 354)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 355)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 355)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 356)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 356)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 357)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 357)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 358)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 358)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 359)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 359)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 360)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 360)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 361)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 361)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 362)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 362)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 363)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 363)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 364)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 364)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 365)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 365)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 366)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 366)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 367)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 367)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 368)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 368)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 369)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 369)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (57, 370)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (58, 370)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 371)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 372)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 373)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 373)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 374)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 374)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 375)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 375)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 376)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 376)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 377)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 377)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 378)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 378)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 380)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 380)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 381)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 381)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 382)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 382)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 383)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 383)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 384)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 384)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 385)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 385)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 386)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 386)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 387)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 387)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 388)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 388)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 390)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 391)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 392)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 393)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 394)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 395)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 396)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 397)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 398)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 399)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 400)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 401)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 402)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 403)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 403)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 404)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 404)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 405)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 405)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 406)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 406)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 407)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 407)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 408)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 408)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 409)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 409)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 410)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 410)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 411)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 411)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (63, 412)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (64, 412)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (63, 413)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (64, 413)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (63, 414)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (64, 414)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 415)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 415)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 416)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 416)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 417)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 417)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 418)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 418)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 419)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 419)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 420)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 420)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 421)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 421)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 422)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 422)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 423)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 423)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 424)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 424)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 425)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 425)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 426)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 426)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 427)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 427)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 428)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 428)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 429)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 429)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 430)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 430)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 431)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 431)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 432)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 432)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 433)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 433)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 434)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 434)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 435)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 435)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 436)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 436)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 437)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 437)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 438)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 438)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 439)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 439)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 440)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 440)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 441)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 441)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 442)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 442)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 443)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 443)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 444)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 444)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 445)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 445)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 446)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 446)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 447)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 447)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 448)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 448)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 449)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 449)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 450)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 450)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 451)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 451)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 452)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 452)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 453)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 453)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 454)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 454)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 455)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 455)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 456)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 456)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 457)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 457)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 458)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 458)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 459)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 459)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 460)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 460)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 461)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 461)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 462)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 462)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 463)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 463)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 464)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 464)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 465)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 465)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 466)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 466)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 467)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 467)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 468)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 468)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 469)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 469)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 470)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 470)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 471)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 471)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 472)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 472)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 473)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 473)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 474)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 474)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 475)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 475)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 476)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 476)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 477)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 477)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 478)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 478)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 479)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 479)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 480)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 480)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 481)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 481)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 482)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 482)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 483)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 483)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 484)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 484)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 485)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 485)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 486)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 486)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 487)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 487)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 488)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 488)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 489)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 489)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 490)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 490)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 491)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 491)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 492)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 492)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (57, 493)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (58, 493)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 494)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 494)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 495)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 495)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 496)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 496)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 497)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 497)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 498)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 498)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 499)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 499)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 500)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 500)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 501)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 501)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 502)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 502)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 503)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 503)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 504)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 504)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 505)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 505)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 506)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 506)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 507)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 507)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 508)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 508)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 509)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 509)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 510)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 510)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 511)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 511)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 512)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 512)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 513)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 513)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 514)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 514)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 515)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 515)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 516)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 516)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 517)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 517)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 518)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 518)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 520)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 520)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 521)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 521)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 522)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 522)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (67, 523)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (68, 523)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (67, 524)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (68, 524)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 525)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 525)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 526)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 526)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 527)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 527)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 528)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 528)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 529)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 529)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 530)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 530)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 531)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 531)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 532)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 532)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 533)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 533)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 534)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 534)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 535)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 535)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 536)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 536)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 537)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 537)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 538)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 538)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 539)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 539)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 540)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 540)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 541)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 541)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 542)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 542)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 543)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 543)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 544)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 544)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 545)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 545)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 546)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 546)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 547)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 547)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 548)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 548)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 549)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 549)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 550)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 550)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 551)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 551)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 552)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 552)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 553)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 553)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 554)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 554)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 555)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 555)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 556)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 556)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 557)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 557)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 558)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 558)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 559)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 559)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 560)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 560)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 561)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 561)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 562)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 562)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 563)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 563)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 564)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 564)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 565)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 565)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 566)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 566)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 567)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 567)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 568)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 568)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 569)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 569)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 570)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 571)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 572)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 573)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 574)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 574)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 575)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 575)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 576)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 576)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 577)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 577)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (83, 578)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (84, 578)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (83, 579)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (84, 579)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 580)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 580)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (85, 581)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (86, 581)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (85, 582)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (86, 582)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 583)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 583)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 584)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 584)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 585)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 585)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 586)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 587)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 588)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 589)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 586)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 587)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 588)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 589)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 590)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 591)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 590)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 591)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 592)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 593)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 592)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 593)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 594)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 595)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 594)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 595)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 596)
GO
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 596)
GO
