-- SQL script to create database for Oracle

CREATE TABLE IWA_Version
(
  Version NUMBER(10) NOT NULL
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_Identifier
(
  IdentifierName VARCHAR2(200) NOT NULL,
  IdentifierValue NUMBER(20) NOT NULL,
  PRIMARY KEY (IdentifierName)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_SystemProperty
(
  PropertyName VARCHAR2(200) NOT NULL,
  PropertyValue CLOB NOT NULL,
  PRIMARY KEY (PropertyName)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_AsyncProcessCaseData
(
  CaseId NUMBER(20) NOT NULL,
  EventId VARCHAR2(100) NOT NULL,
  CaseData BLOB NOT NULL,
  PRIMARY KEY (CaseId, EventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_AsyncProcessCaseData_CaseIdIndex ON IWA_AsyncProcessCaseData (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Application
(
  ApplicationId NUMBER(20) NOT NULL,
  Name VARCHAR2(40),
  State NUMBER(10) NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL,
  PRIMARY KEY (ApplicationId),
  UNIQUE (Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Application_SecuritySystemIdIndex ON IWA_Application (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_ProcessModel
(
  ProcessModelId NUMBER(20) NOT NULL,
  Name VARCHAR2(40),
  State NUMBER(10) NOT NULL,
  ApplicationId NUMBER(20) NOT NULL,
  PRIMARY KEY (ProcessModelId),
  UNIQUE (ApplicationId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_ProcessModel_ApplicationIdIndex ON IWA_ProcessModel (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_ProcessModelVersion
(
  ProcessModelVersionId NUMBER(20) NOT NULL,
  ProcessModelId NUMBER(20) NOT NULL REFERENCES IWA_ProcessModel(ProcessModelId) ON DELETE CASCADE,
  VersionNumber NUMBER(10) NOT NULL,
  State NUMBER(10) NOT NULL,
  ReleaseState NUMBER(10) NOT NULL,
  ReleaseTimestamp TIMESTAMP,
  ProjectDirectory VARCHAR2(500),
  ProjectName VARCHAR2(200) NOT NULL,
  ProjectHash VARCHAR2(32),
  Changed TIMESTAMP NOT NULL,
  PRIMARY KEY (ProcessModelVersionId),
  UNIQUE (ProcessModelId, VersionNumber)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_ProcessModelVersion_ProcessModelIdIndex ON IWA_ProcessModelVersion (ProcessModelId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Library
(
  LibraryId NUMBER(20) NOT NULL,
  ProcessModelVersionId NUMBER(20) NOT NULL REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE CASCADE,
  ApplicationId NUMBER(20) NOT NULL REFERENCES IWA_Application(ApplicationId),
  Id VARCHAR2(200) NOT NULL,
  Version VARCHAR2(50) DEFAULT '' NOT NULL,
  Provider VARCHAR2(200),
  Name VARCHAR2(200),
  Description CLOB,
  PRIMARY KEY (LibraryId),
  UNIQUE (ApplicationId, Id, Version),
  UNIQUE (ProcessModelVersionId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Library_ApplicationIdIndex ON IWA_Library (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_LibrarySpecification
(
  LibrarySpecificationId NUMBER(20) NOT NULL,
  LibraryId NUMBER(20) NOT NULL REFERENCES IWA_Library(LibraryId) ON DELETE CASCADE,
  Id VARCHAR2(200) NOT NULL,
  ResolvedLibraryId NUMBER(20) REFERENCES IWA_Library(LibraryId) ON DELETE SET NULL,
  "POSITION" NUMBER(10) NOT NULL,
  PRIMARY KEY (LibrarySpecificationId),
  UNIQUE (LibraryId, Id)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_LibrarySpecification_LibraryIdIndex ON IWA_LibrarySpecification (LibraryId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX LibSpec_ResLibraryId ON IWA_LibrarySpecification (ResolvedLibraryId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_LibraryVersionSpec
(
  LibraryVersionSpecId NUMBER(20) NOT NULL,
  LibrarySpecificationId NUMBER(20) NOT NULL REFERENCES IWA_LibrarySpecification(LibrarySpecificationId) ON DELETE CASCADE,
  Version VARCHAR2(50) DEFAULT '' NOT NULL,
  Inclusive NUMBER(1) NOT NULL,
  Minimum NUMBER(1) NOT NULL,
  PRIMARY KEY (LibraryVersionSpecId),
  UNIQUE (LibrarySpecificationId, Minimum)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_LibraryVersionSpec_LibrarySpecificationIdIndex ON IWA_LibraryVersionSpec (LibrarySpecificationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseMap
(
  CaseMapId NUMBER(20) NOT NULL,
  ProcessModelVersionId NUMBER(20) NOT NULL REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE CASCADE,
  ApplicationId NUMBER(20) NOT NULL REFERENCES IWA_Application(ApplicationId),
  UUID VARCHAR2(36) NOT NULL,
  Name VARCHAR2(200) NOT NULL,
  Model CLOB NOT NULL,
  PRIMARY KEY (CaseMapId),
  UNIQUE (ProcessModelVersionId, UUID)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMap_ProcessModelVersionIdIndex ON IWA_CaseMap (ProcessModelVersionId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMap_ApplicationIdIndex ON IWA_CaseMap (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_SecurityMember
(
  SecurityMemberId VARCHAR2(210) NOT NULL,
  Name VARCHAR2(200) NOT NULL,
  MemberName VARCHAR2(201) NOT NULL,
  DisplayName VARCHAR2(200),
  SecuritySystemId NUMBER(20) NOT NULL,
  Enabled NUMBER(1) DEFAULT 0 NOT NULL,
  "TYPE" NUMBER(10) NOT NULL,
  PRIMARY KEY (SecurityMemberId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityMemberNameIdx ON IWA_SecurityMember (Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityMemberMemberNameIdx ON IWA_SecurityMember (MemberName) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityMemberDisplayNameIdx ON IWA_SecurityMember (DisplayName) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityMemberEnabledIdx ON IWA_SecurityMember (Enabled) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityMemberTypeIdx ON IWA_SecurityMember ("TYPE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityMember_SecuritySystemIdIndex ON IWA_SecurityMember (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Role
(
  RoleId NUMBER(20) NOT NULL,
  Name VARCHAR2(200),
  DisplayNameTemplate VARCHAR2(200),
  DisplayDescriptionTemplate VARCHAR2(200) DEFAULT '',
  ParentSecurityMemberId VARCHAR2(210),
  SecuritySystemId NUMBER(20) NOT NULL,
  IsDynamic NUMBER(1) NOT NULL,
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  PRIMARY KEY (SecurityMemberId),
  UNIQUE (RoleId),
  UNIQUE (SecuritySystemId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Role_ParentSecurityMemberIdIndex ON IWA_Role (ParentSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Role_SecuritySystemIdIndex ON IWA_Role (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_RoleProperty
(
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  RolePropertyId NUMBER(20) NOT NULL,
  PropertyName VARCHAR2(255),
  PropertyValue CLOB NOT NULL,
  PRIMARY KEY (RolePropertyId),
  UNIQUE (SecurityMemberId, PropertyName)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_RoleProperty_SecurityMemberIdIndex ON IWA_RoleProperty (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_RoleRoleMember
(
  RoleSecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  RoleMemberSecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (RoleSecurityMemberId, RoleMemberSecurityMemberId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_RoleRoleMember_RoleSecurityMemberIdIndex ON IWA_RoleRoleMember (RoleSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_RoleRoleMember_RoleMemberSecurityMemberIdIndex ON IWA_RoleRoleMember (RoleMemberSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_User
(
  UserId NUMBER(20) NOT NULL,
  Name VARCHAR2(200),
  FullName VARCHAR2(200) DEFAULT '',
  UserPassword VARCHAR2(200),
  SecuritySystemId NUMBER(20) NOT NULL,
  ExternalSecurityName VARCHAR2(500),
  ExternalId VARCHAR2(200),
  EMailAddress VARCHAR2(200),
  "LANGUAGE" VARCHAR2(5),
  FormattingLanguage VARCHAR2(5),
  State NUMBER(10) DEFAULT 0 NOT NULL,
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId),
  PRIMARY KEY (SecurityMemberId),
  UNIQUE (UserId),
  UNIQUE (SecuritySystemId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_ExternalIdIndex ON IWA_User (SecuritySystemId, ExternalId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_StateIndex ON IWA_User (State) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_ExternalSecNameIdx ON IWA_User (SecuritySystemId, ExternalSecurityName) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_SecuritySystemIdIndex ON IWA_User (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_SecSysSecMemberIndex ON IWA_User (SecuritySystemId, SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_User_SecSysNameSecMemberIdx ON IWA_User (SecuritySystemId, Name, SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_UserRole
(
  RoleSecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  UserSecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (RoleSecurityMemberId, UserSecurityMemberId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserRole_RoleSecurityMemberIdIndex ON IWA_UserRole (RoleSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserRole_UserSecurityMemberIdIndex ON IWA_UserRole (UserSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_UserProperty
(
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  UserPropertyId NUMBER(20) NOT NULL,
  PropertyName VARCHAR2(255),
  PropertyValue CLOB NOT NULL,
  PRIMARY KEY (UserPropertyId),
  UNIQUE (SecurityMemberId, PropertyName)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserProperty_SecurityMemberIdIndex ON IWA_UserProperty (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_UserAbsence
(
  UserAbsenceId NUMBER(20) NOT NULL,
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  StartTimestamp TIMESTAMP NOT NULL,
  StopTimestamp TIMESTAMP,
  Description VARCHAR2(200),
  PRIMARY KEY (UserAbsenceId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserAbsence_SecurityMemberIdIndex ON IWA_UserAbsence (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_UserSubstitute
(
  UserSubstituteId NUMBER(20) NOT NULL,
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  SubstituteUserSecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  SubstituteRoleSecurityMemberId VARCHAR2(210) REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE,
  Description VARCHAR2(200),
  SubstitutionType NUMBER(10) DEFAULT 0 NOT NULL,
  PRIMARY KEY (UserSubstituteId),
  UNIQUE (SecurityMemberId, SubstituteUserSecurityMemberId, SubstituteRoleSecurityMemberId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserSubstitute_SecurityMemberIdIndex ON IWA_UserSubstitute (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserSbs_SbsUserScrtMmbrIdIdx ON IWA_UserSubstitute (SubstituteUserSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserSbs_SbsRoleScrtMmbrIdIdx ON IWA_UserSubstitute (SubstituteRoleSecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskElement
(
  TaskElementId NUMBER(20) NOT NULL,
  ProcessModelVersionId NUMBER(20) NOT NULL REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE CASCADE,
  ProcessElementId VARCHAR2(200) NOT NULL,
  JoinPathes NUMBER(10) NOT NULL,
  Kind NUMBER(10) NOT NULL,
  PRIMARY KEY (TaskElementId),
  UNIQUE (ProcessModelVersionId, ProcessElementId, Kind)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskElement_ProcessModelVersionIdIndex ON IWA_TaskElement (ProcessModelVersionId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskStart
(
  TaskStartId NUMBER(20) NOT NULL,
  TaskElementId NUMBER(20) NOT NULL REFERENCES IWA_TaskElement(TaskElementId) ON DELETE CASCADE,
  StartRequestPath VARCHAR2(200) NOT NULL,
  PRIMARY KEY (TaskStartId),
  UNIQUE (TaskElementId, StartRequestPath)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskStart_TaskElementIdIndex ON IWA_TaskStart (TaskElementId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskEnd
(
  TaskEndId NUMBER(20) NOT NULL,
  TaskElementId NUMBER(20) NOT NULL REFERENCES IWA_TaskElement(TaskElementId) ON DELETE CASCADE,
  JoinPathId NUMBER(10),
  PRIMARY KEY (TaskEndId),
  UNIQUE (TaskElementId, JoinPathId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskEnd_TaskElementIdIndex ON IWA_TaskEnd (TaskElementId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskSwitchEvent
(
  TaskSwitchEventId NUMBER(20) NOT NULL,
  TaskElementId NUMBER(20) NOT NULL REFERENCES IWA_TaskElement(TaskElementId) ON DELETE CASCADE,
  CaseId NUMBER(20) NOT NULL,
  ExecutionTimestamp TIMESTAMP NOT NULL,
  PRIMARY KEY (TaskSwitchEventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskSwitchEvent_TaskElementIdIndex ON IWA_TaskSwitchEvent (TaskElementId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskSwitchEvent_CaseIdIndex ON IWA_TaskSwitchEvent (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Case
(
  CaseId NUMBER(20) NOT NULL,
  UUID VARCHAR2(36) NOT NULL,
  BusinessCaseId NUMBER(20),
  Kind NUMBER(10) DEFAULT 0 NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL,
  ApplicationId NUMBER(20) NOT NULL REFERENCES IWA_Application(ApplicationId),
  ProcessModelId NUMBER(20) NOT NULL REFERENCES IWA_ProcessModel(ProcessModelId) ON DELETE CASCADE,
  TaskStartId NUMBER(20) NOT NULL REFERENCES IWA_TaskStart(TaskStartId),
  ActivatorId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  CreatorId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  CreatorTaskId NUMBER(20),
  StartTimestamp TIMESTAMP NOT NULL,
  EndTimestamp TIMESTAMP,
  ModifiedTimestamp TIMESTAMP NOT NULL,
  BusinessCalendar VARCHAR2(200),
  WorkingTime NUMBER(20),
  BusinessRuntime NUMBER(20),
  State NUMBER(10) NOT NULL,
  BusinessState NUMBER(10) NOT NULL,
  Priority NUMBER(10) NOT NULL,
  Stage VARCHAR2(200) DEFAULT '' NOT NULL,
  Category VARCHAR2(200) DEFAULT '' NOT NULL,
  PRIMARY KEY (CaseId),
  UNIQUE (UUID)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_BusinessCaseIdIndex ON IWA_Case (BusinessCaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_SecSystemIdIndex ON IWA_Case (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_ApplicationIdIndex ON IWA_Case (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_ProcessModelIdIndex ON IWA_Case (ProcessModelId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_TaskStartIdIndex ON IWA_Case (TaskStartId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_ActivatorIdIndex ON IWA_Case (ActivatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_CreatorTaskIdIndex ON IWA_Case (CreatorTaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_WbppIdCrtTmstmpSttIdx ON IWA_Case (ApplicationId, StartTimestamp, State) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_WorkingTime ON IWA_Case (WorkingTime) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_BusinessRuntime ON IWA_Case (BusinessRuntime) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_Category ON IWA_Case (Category) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_EndTimestamp ON IWA_Case (EndTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_StartTimestamp ON IWA_Case (StartTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_CreatorIdIndex ON IWA_Case (CreatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_StateIndex ON IWA_Case (State) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_BusinessStateIndex ON IWA_Case (BusinessState) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Case_StateCreatorIdIndex ON IWA_Case (State, CreatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseOwner
(
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  OwnerId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (CaseId, OwnerId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseOwner_CaseIdIndex ON IWA_CaseOwner (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseOwner_OwnerIdIndex ON IWA_CaseOwner (OwnerId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseLocalized
(
  CaseLocalizedId NUMBER(20) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  LanguageId NUMBER(20) NOT NULL,
  Name VARCHAR2(200),
  Description CLOB NOT NULL,
  PRIMARY KEY (CaseLocalizedId),
  UNIQUE (CaseId, LanguageId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_NameIndex ON IWA_CaseLocalized (Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_CaseIdLanguageIdNameIndex ON IWA_CaseLocalized (CaseId, LanguageId, Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_CaseIdLanguageIdLowerNameIndex ON IWA_CaseLocalized (CaseId, LanguageId, lower(Name)) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_LanguageIdNameCaseIdIndex ON IWA_CaseLocalized (LanguageId, Name, CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_LanguageIdLowerNameCaseIdIndex ON IWA_CaseLocalized (LanguageId, lower(Name), CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_CaseIdIndex ON IWA_CaseLocalized (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseLocalized_LanguageIdIndex ON IWA_CaseLocalized (LanguageId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Task
(
  TaskId NUMBER(20) NOT NULL,
  UUID VARCHAR2(36) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  BusinessCaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  SecuritySystemId NUMBER(20) NOT NULL,
  ApplicationId NUMBER(20) NOT NULL REFERENCES IWA_Application(ApplicationId),
  ProcessModelId NUMBER(20) NOT NULL REFERENCES IWA_ProcessModel(ProcessModelId),
  StartTaskSwitchEventId NUMBER(20) NOT NULL REFERENCES IWA_TaskSwitchEvent(TaskSwitchEventId),
  EndTaskSwitchEventId NUMBER(20) REFERENCES IWA_TaskSwitchEvent(TaskSwitchEventId),
  TaskStartId NUMBER(20) NOT NULL REFERENCES IWA_TaskStart(TaskStartId),
  TaskEndId NUMBER(20) REFERENCES IWA_TaskEnd(TaskEndId),
  WorkerId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  WorkerSessionId NUMBER(10),
  ActivatorId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  OriginalActivatorId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  ExpiryActivatorId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  ExpiryPriority NUMBER(10) NOT NULL,
  ExpiryTimestamp TIMESTAMP,
  ExpiryTaskStartElementPid VARCHAR2(200),
  IsExpired NUMBER(1) NOT NULL,
  ExpiredCreatorTaskId NUMBER(20),
  TimeoutedCreatorIntrmdtEventId NUMBER(20),
  DelayTimestamp TIMESTAMP,
  State NUMBER(10) NOT NULL,
  BusinessState NUMBER(10) NOT NULL,
  RequestPath VARCHAR2(200),
  OriginalPriority NUMBER(10) NOT NULL,
  Priority NUMBER(10) NOT NULL,
  StartTimestamp TIMESTAMP NOT NULL,
  EndTimestamp TIMESTAMP,
  ModifiedTimestamp TIMESTAMP NOT NULL,
  BusinessCalendar VARCHAR2(200),
  WorkingTime NUMBER(20),
  BusinessRuntime NUMBER(20),
  FailedTimeoutTimestamp TIMESTAMP,
  NumberOfFailures NUMBER(10) NOT NULL,
  NumberOfResumes NUMBER(10),
  Category VARCHAR2(200) DEFAULT '' NOT NULL,
  IsUpdatedOnStart NUMBER(1) NOT NULL,
  IsOffline NUMBER(1) DEFAULT 0 NOT NULL,
  PRIMARY KEY (TaskId),
  UNIQUE (UUID)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_CaseIdIndex ON IWA_Task (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_BusinessCaseIdIndex ON IWA_Task (BusinessCaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_ProcessModelIdIndex ON IWA_Task (ProcessModelId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_SecSystemIdIndex ON IWA_Task (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_ApplicationIdIndex ON IWA_Task (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_StateIndex ON IWA_Task (State) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_BusinessStateIndex ON IWA_Task (BusinessState) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_StartTimestamp ON IWA_Task (StartTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_EndTimestamp ON IWA_Task (EndTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_WorkingTime ON IWA_Task (WorkingTime) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_BusinessRuntime ON IWA_Task (BusinessRuntime) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_NumberOfResumes ON IWA_Task (NumberOfResumes) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_CategoryIndex ON IWA_Task (Category) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_WorkerIdIndex ON IWA_Task (WorkerId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_ActivatorIdIndex ON IWA_Task (ActivatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_OriginalActivatorIdIndex ON IWA_Task (OriginalActivatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_ExpiryActivatorIdIndex ON IWA_Task (ExpiryActivatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_StateActivatorIdIndex ON IWA_Task (State, ActivatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_StateWorkerIdIndex ON IWA_Task (State, WorkerId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_StartTaskSwitchEventIdIndex ON IWA_Task (StartTaskSwitchEventId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_EndTaskSwitchEventIdIndex ON IWA_Task (EndTaskSwitchEventId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_TaskStartIdIndex ON IWA_Task (TaskStartId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_TaskEndIdIndex ON IWA_Task (TaskEndId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_ExpiredCreatorTaskIdIndex ON IWA_Task (ExpiredCreatorTaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_TimeoutedCreatorIntrmdtEventIdIndex ON IWA_Task (TimeoutedCreatorIntrmdtEventId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_TaskIdCaseIdIndex ON IWA_Task (TaskId, CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_CaseIdTaskIdIndex ON IWA_Task (CaseId, TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_TaskIdBusinessCaseIdIndex ON IWA_Task (TaskId, BusinessCaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Task_BusinessCaseIdTaskIdIndex ON IWA_Task (BusinessCaseId, TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskLocalized
(
  TaskLocalizedId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  LanguageId NUMBER(20) NOT NULL,
  Name VARCHAR2(200),
  Description CLOB NOT NULL,
  PRIMARY KEY (TaskLocalizedId),
  UNIQUE (TaskId, LanguageId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_NameIndex ON IWA_TaskLocalized (Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_TaskIdLanguageIdNameIndex ON IWA_TaskLocalized (TaskId, LanguageId, Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_TaskIdLanguageIdLowerNameIndex ON IWA_TaskLocalized (TaskId, LanguageId, lower(Name)) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_LanguageIdNameTaskIdIndex ON IWA_TaskLocalized (LanguageId, Name, TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_LanguageIdLowerNameTaskIdIndex ON IWA_TaskLocalized (LanguageId, lower(Name), TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_TaskIdIndex ON IWA_TaskLocalized (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocalized_LanguageIdIndex ON IWA_TaskLocalized (LanguageId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskData
(
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  TaskData BLOB NOT NULL,
  PRIMARY KEY (TaskId)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_StartTaskData
(
  TaskSwitchEventId NUMBER(20) NOT NULL REFERENCES IWA_TaskSwitchEvent(TaskSwitchEventId) ON DELETE CASCADE,
  StartTaskData BLOB NOT NULL,
  PRIMARY KEY (TaskSwitchEventId)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_WorkflowEvent
(
  WorkflowEventId NUMBER(20) NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL,
  ApplicationId NUMBER(20) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  TaskId NUMBER(20) REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  EventTimestamp TIMESTAMP NOT NULL,
  UserId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  EventKind NUMBER(10) NOT NULL,
  AdditionalInfo1 VARCHAR2(200),
  AdditionalInfo2 VARCHAR2(200),
  AdditionalInfo3 VARCHAR2(200),
  AdditionalInfo4 VARCHAR2(200),
  AdditionalInfo5 VARCHAR2(200),
  CaseState NUMBER(10) NOT NULL,
  TaskState NUMBER(10),
  PRIMARY KEY (WorkflowEventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WorkflowEvent_SecSystemIdIdx ON IWA_WorkflowEvent (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WorkflowEvent_AppIdIdx ON IWA_WorkflowEvent (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WorkflowEvent_CaseIdIndex ON IWA_WorkflowEvent (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WorkflowEvent_TaskIdIndex ON IWA_WorkflowEvent (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WrkflwEvnt_EvntTmstmpIdx ON IWA_WorkflowEvent (EventTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WorkflowEvent_UserIdIndex ON IWA_WorkflowEvent (UserId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_WorkflowEvent_EventKindIdx ON IWA_WorkflowEvent (EventKind) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseMapBusinessCase
(
  BusinessCaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  CaseMapId NUMBER(20) NOT NULL REFERENCES IWA_CaseMap(CaseMapId) ON DELETE CASCADE,
  PRIMARY KEY (BusinessCaseId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMapBusCase_CsMpIdIdx ON IWA_CaseMapBusinessCase (CaseMapId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseMapEvent
(
  CaseMapEventId NUMBER(20) NOT NULL,
  BusinessCaseId NUMBER(20) NOT NULL REFERENCES IWA_CaseMapBusinessCase(BusinessCaseId) ON DELETE CASCADE,
  "TIMESTAMP" TIMESTAMP NOT NULL,
  Kind NUMBER(10) NOT NULL,
  Stage VARCHAR2(200) NOT NULL,
  Process VARCHAR2(200) NOT NULL,
  ProcessCaseId NUMBER(20) REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Milestone VARCHAR2(200) NOT NULL,
  Reason VARCHAR2(200) NOT NULL,
  ProcessingState NUMBER(10) NOT NULL,
  ProcessingErrorMessage VARCHAR2(750) NOT NULL,
  ProcessingErrorCount NUMBER(10) NOT NULL,
  ProcessingRetryTimestamp TIMESTAMP,
  PRIMARY KEY (CaseMapEventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMapEvent_BcId ON IWA_CaseMapEvent (BusinessCaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMapEvent_PrcRtryTstmp ON IWA_CaseMapEvent (ProcessingRetryTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMapEvent_PrcState ON IWA_CaseMapEvent (ProcessingState) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseMapEvent_ProcessCaseIdIndex ON IWA_CaseMapEvent (ProcessCaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_IntermediateEvent
(
  IntermediateEventId NUMBER(20) NOT NULL,
  TaskStartId NUMBER(20) NOT NULL REFERENCES IWA_TaskStart(TaskStartId) ON DELETE CASCADE,
  SecuritySystemId NUMBER(20) NOT NULL,
  ApplicationId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  EventId VARCHAR2(200) NOT NULL,
  State NUMBER(10) NOT NULL,
  EventTimestamp TIMESTAMP,
  TimeoutTimestamp TIMESTAMP,
  TimeoutTaskStartElementId VARCHAR2(200),
  TimeoutAction NUMBER(10) NOT NULL,
  AdditionalInformation VARCHAR2(2000),
  PRIMARY KEY (IntermediateEventId),
  UNIQUE (TaskStartId, EventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntermediateEvent_SecSystemId ON IWA_IntermediateEvent (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntermediateEvent_ApplicationId ON IWA_IntermediateEvent (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntrmdtEvnt_TaskStartId ON IWA_IntermediateEvent (TaskStartId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntermediateEvent_TaskId ON IWA_IntermediateEvent (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntermediateEvent_EventId ON IWA_IntermediateEvent (EventId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntermediateEvent_State ON IWA_IntermediateEvent (State) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_IntrmdtEvnt_TimeoutTmstmp ON IWA_IntermediateEvent (TimeoutTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_IntermediateEventData
(
  IntermediateEventId NUMBER(20) NOT NULL REFERENCES IWA_IntermediateEvent(IntermediateEventId) ON DELETE CASCADE,
  ResultObjectData BLOB NOT NULL,
  PRIMARY KEY (IntermediateEventId)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_Note
(
  NoteId NUMBER(20) NOT NULL,
  SecurityMemberId VARCHAR2(210) REFERENCES IWA_User(SecurityMemberId) ON DELETE SET NULL,
  UserName VARCHAR2(200) NOT NULL,
  "TIMESTAMP" TIMESTAMP NOT NULL,
  Note CLOB NOT NULL,
  PRIMARY KEY (NoteId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Note_SecurityMemberIdIndex ON IWA_Note (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskNote
(
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  NoteId NUMBER(20) NOT NULL,
  PRIMARY KEY (TaskId, NoteId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskNote_TaskIdIndex ON IWA_TaskNote (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskNote_NoteIdIndex ON IWA_TaskNote (NoteId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseNote
(
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  NoteId NUMBER(20) NOT NULL,
  PRIMARY KEY (CaseId, NoteId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseNote_CaseIdIndex ON IWA_CaseNote (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseNote_NoteIdIndex ON IWA_CaseNote (NoteId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskCustomStringField
(
  TaskCustomStringFieldId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" VARCHAR2(2000) NOT NULL,
  PRIMARY KEY (TaskCustomStringFieldId),
  UNIQUE (TaskId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmStringFld_TaskIdNameValueIndex ON IWA_TaskCustomStringField (TaskId, Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmStringFld_TaskIdNameLowerValueIndex ON IWA_TaskCustomStringField (TaskId, Name, lower("VALUE")) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmStringFld_NameValueTaskIdIndex ON IWA_TaskCustomStringField (Name, "VALUE", TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmStringFld_NameLowerValueTaskIdIndex ON IWA_TaskCustomStringField (Name, lower("VALUE"), TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCustomStringField_TaskIdIndex ON IWA_TaskCustomStringField (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmStringFldNmValIdx ON IWA_TaskCustomStringField (Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskCustomTextField
(
  TaskCustomTextFieldId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" CLOB NOT NULL,
  PRIMARY KEY (TaskCustomTextFieldId),
  UNIQUE (TaskId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmTextFldNameIdx ON IWA_TaskCustomTextField (Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCustomTextField_TaskIdIndex ON IWA_TaskCustomTextField (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskCustomNumberField
(
  TaskCustomNumberFieldId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" DECIMAL(30, 10) NOT NULL,
  PRIMARY KEY (TaskCustomNumberFieldId),
  UNIQUE (TaskId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmNumberFldNmValIdx ON IWA_TaskCustomNumberField (Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmNumberFld_TaskIdNameValueIndex ON IWA_TaskCustomNumberField (TaskId, Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmNumberFld_NameValueTaskIdIndex ON IWA_TaskCustomNumberField (Name, "VALUE", TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCustomNumberField_TaskIdIndex ON IWA_TaskCustomNumberField (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskCustomTimestampField
(
  TaskCustomTimestampFieldId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" TIMESTAMP NOT NULL,
  PRIMARY KEY (TaskCustomTimestampFieldId),
  UNIQUE (TaskId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmTmstmpFldNmValIdx ON IWA_TaskCustomTimestampField (Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmTimestampFld_TaskIdNameValueIndex ON IWA_TaskCustomTimestampField (TaskId, Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCstmTimestampFld_NameValueTaskIdIndex ON IWA_TaskCustomTimestampField (Name, "VALUE", TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskCustomTimestampField_TaskIdIndex ON IWA_TaskCustomTimestampField (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseCustomStringField
(
  CaseCustomStringFieldId NUMBER(20) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" VARCHAR2(2000) NOT NULL,
  PRIMARY KEY (CaseCustomStringFieldId),
  UNIQUE (CaseId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmStringFld_CaseIdIndex ON IWA_CaseCustomStringField (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmStringFld_CaseIdNameValueIndex ON IWA_CaseCustomStringField (CaseId, Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmStringFld_CaseIdNameLowerValueIndex ON IWA_CaseCustomStringField (CaseId, Name, lower("VALUE")) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmStringFld_NameValueCaseIdIndex ON IWA_CaseCustomStringField (Name, "VALUE", CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmStringFld_NameLowerValueCaseIdIndex ON IWA_CaseCustomStringField (Name, lower("VALUE"), CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmStringFldNmValIdx ON IWA_CaseCustomStringField (Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseCustomTextField
(
  CaseCustomTextFieldId NUMBER(20) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" CLOB NOT NULL,
  PRIMARY KEY (CaseCustomTextFieldId),
  UNIQUE (CaseId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmTextFldNameIdx ON IWA_CaseCustomTextField (Name) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmTextFld_CaseIdIndex ON IWA_CaseCustomTextField (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseCustomNumberField
(
  CaseCustomNumberFieldId NUMBER(20) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" DECIMAL(30, 10) NOT NULL,
  PRIMARY KEY (CaseCustomNumberFieldId),
  UNIQUE (CaseId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmNumberFldNmValIdx ON IWA_CaseCustomNumberField (Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmNumberFld_CaseIdNameValueIndex ON IWA_CaseCustomNumberField (CaseId, Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmNumberFld_NameValueCaseIdIndex ON IWA_CaseCustomNumberField (Name, "VALUE", CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmNumberFld_CaseIdIndex ON IWA_CaseCustomNumberField (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_CaseCustomTimestampField
(
  CaseCustomTimestampFieldId NUMBER(20) NOT NULL,
  CaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  Name VARCHAR2(200) NOT NULL,
  "VALUE" TIMESTAMP NOT NULL,
  PRIMARY KEY (CaseCustomTimestampFieldId),
  UNIQUE (CaseId, Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmTmstmpFldNmValIdx ON IWA_CaseCustomTimestampField (Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmTmstmpFld_CaseIdNameValueIndex ON IWA_CaseCustomTimestampField (CaseId, Name, "VALUE") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmTmstmpFld_NameValueCaseIdIndex ON IWA_CaseCustomTimestampField (Name, "VALUE", CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_CaseCstmTmstmpFld_CaseIdIndex ON IWA_CaseCustomTimestampField (CaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_UserLocation
(
  UserLocationId NUMBER(20) NOT NULL,
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_User(SecurityMemberId) ON DELETE CASCADE,
  "TYPE" VARCHAR2(200) NOT NULL,
  Note VARCHAR2(2000) NOT NULL,
  Name VARCHAR2(200) NOT NULL,
  Address VARCHAR2(200) NOT NULL,
  Latitude DECIMAL(10, 8) NOT NULL,
  Longitude DECIMAL(11, 8) NOT NULL,
  Altitude DECIMAL(8, 3) NOT NULL,
  AccuracyHorizontal DECIMAL(8, 3),
  AccuracyVertical DECIMAL(8, 3),
  Speed DECIMAL(8, 3),
  Bearing DECIMAL(6, 3),
  LocationTimestamp TIMESTAMP,
  PRIMARY KEY (UserLocationId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_UserLocation_SecurityMemberId ON IWA_UserLocation (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskLocation
(
  TaskLocationId NUMBER(20) NOT NULL,
  TaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  "TYPE" VARCHAR2(200) NOT NULL,
  Note VARCHAR2(2000) NOT NULL,
  Name VARCHAR2(200) NOT NULL,
  Address VARCHAR2(200) NOT NULL,
  Latitude DECIMAL(10, 8) NOT NULL,
  Longitude DECIMAL(11, 8) NOT NULL,
  Altitude DECIMAL(8, 3) NOT NULL,
  AccuracyHorizontal DECIMAL(8, 3),
  AccuracyVertical DECIMAL(8, 3),
  Speed DECIMAL(8, 3),
  Bearing DECIMAL(6, 3),
  LocationTimestamp TIMESTAMP,
  PRIMARY KEY (TaskLocationId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TaskLocation_TaskId ON IWA_TaskLocation (TaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_TaskSignalEventReceiver
(
  TaskSignalEventId NUMBER(20) NOT NULL,
  WaitingTaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  SignalCodePattern VARCHAR2(200),
  SignaledTaskTaskStartId NUMBER(20) NOT NULL REFERENCES IWA_TaskStart(TaskStartId) ON DELETE CASCADE,
  StartedSignaledTaskId NUMBER(20),
  PRIMARY KEY (TaskSignalEventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TskSigEvntRcvr_WtingTaskId ON IWA_TaskSignalEventReceiver (WaitingTaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TskSigEvntRcvr_SgTskTskId ON IWA_TaskSignalEventReceiver (SignaledTaskTaskStartId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_TskSigEvntRcvr_StrtSgTskId ON IWA_TaskSignalEventReceiver (StartedSignaledTaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_SignaledTask
(
  SignaledTaskId NUMBER(20) NOT NULL REFERENCES IWA_Task(TaskId) ON DELETE CASCADE,
  SignalCodePattern VARCHAR2(200),
  ReceivedSignalEventId NUMBER(20),
  PRIMARY KEY (SignaledTaskId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SigTask_RecvdSignalEventId ON IWA_SignaledTask (ReceivedSignalEventId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_SignalEvent
(
  SignalEventId NUMBER(20) NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL,
  ApplicationId NUMBER(20),
  SignalCode VARCHAR2(200) NOT NULL,
  SentTimestamp TIMESTAMP NOT NULL,
  SentById VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  SentByTaskId NUMBER(20) REFERENCES IWA_Task(TaskId) ON DELETE SET NULL,
  SentByProcessElementPid VARCHAR2(200),
  PRIMARY KEY (SignalEventId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SignalEvent_SecuritySystemId ON IWA_SignalEvent (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SignalEvent_ApplicationId ON IWA_SignalEvent (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SignalEvent_SignalCode ON IWA_SignalEvent (SignalCode) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SignalEvent_SentTimestamp ON IWA_SignalEvent (SentTimestamp) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SignalEvent_SentByTaskId ON IWA_SignalEvent (SentByTaskId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SignalEvent_SentById ON IWA_SignalEvent (SentById) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_SignalEventData
(
  SignalEventId NUMBER(20) NOT NULL REFERENCES IWA_SignalEvent(SignalEventId) ON DELETE CASCADE,
  SignalData BLOB NOT NULL,
  PRIMARY KEY (SignalEventId)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_SecurityDescriptor
(
  SecurityDescriptorId NUMBER(20) NOT NULL,
  SecurityDescriptorTypeId NUMBER(20) NOT NULL,
  PRIMARY KEY (SecurityDescriptorId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityDescriptor_SecurityDescriptorTypeId ON IWA_SecurityDescriptor (SecurityDescriptorTypeId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_SecuritySystem
(
  SecuritySystemId NUMBER(20) NOT NULL,
  Name VARCHAR2(200) NOT NULL,
  SecurityDescriptorId NUMBER(20) NOT NULL REFERENCES IWA_SecurityDescriptor(SecurityDescriptorId),
  PRIMARY KEY (SecuritySystemId),
  UNIQUE (Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecuritySystem_SecurityDescriptorId ON IWA_SecuritySystem (SecurityDescriptorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Language
(
  LanguageId NUMBER(20) NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId),
  IsDefault NUMBER(1) NOT NULL,
  Locale VARCHAR2(25) NOT NULL,
  PRIMARY KEY (LanguageId),
  UNIQUE (SecuritySystemId, Locale)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Language_SecuritySystemId ON IWA_Language (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_PermissionGroup
(
  PermissionGroupId NUMBER(20) NOT NULL,
  ParentPermissionGroupId NUMBER(20),
  Name VARCHAR2(200) NOT NULL,
  PRIMARY KEY (PermissionGroupId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_PermissionGroup_ParentPermissionGroupId ON IWA_PermissionGroup (ParentPermissionGroupId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_SecurityDescriptorType
(
  SecurityDescriptorTypeId NUMBER(20) NOT NULL,
  RootPermissionGroupId NUMBER(20) NOT NULL REFERENCES IWA_PermissionGroup(PermissionGroupId),
  Name VARCHAR2(200) NOT NULL,
  PRIMARY KEY (SecurityDescriptorTypeId),
  UNIQUE (Name)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_SecurityDescriptorType_RootPermissionGroupId ON IWA_SecurityDescriptorType (RootPermissionGroupId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_AccessControl
(
  AccessControlId NUMBER(20) NOT NULL,
  SecurityDescriptorId NUMBER(20) NOT NULL REFERENCES IWA_SecurityDescriptor(SecurityDescriptorId) ON DELETE CASCADE,
  PermissionId NUMBER(20) NOT NULL,
  GrantDeny NUMBER(1) NOT NULL,
  SecurityMemberId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (AccessControlId),
  UNIQUE (SecurityDescriptorId, PermissionId, SecurityMemberId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_AccessControl_SecDescIdIdx ON IWA_AccessControl (SecurityDescriptorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_AccessControl_SecMembrIdIdx ON IWA_AccessControl (SecurityMemberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_AccessControl_PermissionIdIdx ON IWA_AccessControl (PermissionId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Permission
(
  PermissionId NUMBER(20) NOT NULL,
  Name VARCHAR2(200) NOT NULL,
  PRIMARY KEY (PermissionId),
  UNIQUE (Name)
)
TABLESPACE ${tablespaceName};

CREATE TABLE IWA_PermissionGroupPermission
(
  PermissionGroupId NUMBER(20) NOT NULL REFERENCES IWA_PermissionGroup(PermissionGroupId) ON DELETE CASCADE,
  PermissionId NUMBER(20) NOT NULL REFERENCES IWA_Permission(PermissionId) ON DELETE CASCADE,
  PRIMARY KEY (PermissionGroupId, PermissionId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_PermissionGroupPermission_PermissionGroupId ON IWA_PermissionGroupPermission (PermissionGroupId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_PermissionGroupPermission_PermissionId ON IWA_PermissionGroupPermission (PermissionId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Blob
(
  BlobId NUMBER(20) NOT NULL,
  UUID VARCHAR2(36) NOT NULL,
  ApplicationId NUMBER(20) NOT NULL REFERENCES IWA_Application(ApplicationId) ON DELETE CASCADE,
  SecuritySystemId NUMBER(20) NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId),
  FileName VARCHAR2(255) NOT NULL,
  FilePath VARCHAR2(750) NOT NULL,
  "PATH" VARCHAR2(750) NOT NULL,
  CreatorId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  CreatedAt TIMESTAMP NOT NULL,
  "SIZE" NUMBER(20) NOT NULL,
  ModifierId VARCHAR2(210) REFERENCES IWA_SecurityMember(SecurityMemberId),
  ModifiedAt TIMESTAMP NOT NULL,
  Description VARCHAR2(1024),
  PRIMARY KEY (UUID),
  UNIQUE (BlobId),
  UNIQUE (SecuritySystemId, "PATH"),
  UNIQUE (ApplicationId, FilePath)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_FilePath ON IWA_Blob (FilePath) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_Path ON IWA_Blob ("PATH") TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_CreatorId ON IWA_Blob (CreatorId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_ModifierId ON IWA_Blob (ModifierId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_CreatedAt ON IWA_Blob (CreatedAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_FileName ON IWA_Blob (FileName) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_ModifiedAt ON IWA_Blob (ModifiedAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_SecuritySystemId ON IWA_Blob (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Blob_ApplicationId ON IWA_Blob (ApplicationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_BusinessData
(
  BusinessDataId VARCHAR2(100) NOT NULL,
  Version NUMBER(20) NOT NULL,
  FormatVersion NUMBER(10) DEFAULT 63000 NOT NULL,
  ObjectType VARCHAR2(255) NOT NULL,
  ObjectValue CLOB NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId),
  CreatedAt TIMESTAMP NOT NULL,
  CreatedByUserName VARCHAR2(200) NOT NULL,
  CreatedByAppId NUMBER(20) NOT NULL,
  ModifiedAt TIMESTAMP NOT NULL,
  ModifiedByUserName VARCHAR2(200) NOT NULL,
  ModifiedByAppId NUMBER(20) NOT NULL,
  PRIMARY KEY (BusinessDataId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_TypeIdx ON IWA_BusinessData (ObjectType) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_SecSysIdx ON IWA_BusinessData (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_CrtdAtIdx ON IWA_BusinessData (CreatedAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_CrtdByUserIdx ON IWA_BusinessData (CreatedByUserName) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_CrtdByAppIdx ON IWA_BusinessData (CreatedByAppId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_ModAtIdx ON IWA_BusinessData (ModifiedAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_ModByUserIdx ON IWA_BusinessData (ModifiedByUserName) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_ModByAppIdx ON IWA_BusinessData (ModifiedByAppId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessData_TypeIdxSecSysIdx ON IWA_BusinessData (ObjectType, SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_BusinessCaseData
(
  BusinessDataId VARCHAR2(100) NOT NULL,
  ObjectType VARCHAR2(255) NOT NULL,
  BusinessCaseId NUMBER(20) NOT NULL REFERENCES IWA_Case(CaseId) ON DELETE CASCADE,
  PRIMARY KEY (BusinessDataId),
  UNIQUE (BusinessCaseId, ObjectType)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_BusinessCaseData_BusinessCaseId ON IWA_BusinessCaseData (BusinessCaseId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_Notification
(
  NotificationId VARCHAR2(36) NOT NULL,
  Kind VARCHAR2(100) NOT NULL,
  Payload CLOB NOT NULL,
  SecuritySystemId NUMBER(20) NOT NULL REFERENCES IWA_SecuritySystem(SecuritySystemId) ON DELETE CASCADE,
  ProcessModelVersionId NUMBER(20) REFERENCES IWA_ProcessModelVersion(ProcessModelVersionId) ON DELETE SET NULL,
  Template VARCHAR2(255),
  CreatedAt TIMESTAMP NOT NULL,
  IsUshered NUMBER(1) NOT NULL,
  PRIMARY KEY (NotificationId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Notification_KindIndex ON IWA_Notification (Kind) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Notification_SecuritySystemIdIndex ON IWA_Notification (SecuritySystemId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Notification_ProcessModelVersionIdIndex ON IWA_Notification (ProcessModelVersionId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_Notification_CreatedAtIndex ON IWA_Notification (CreatedAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_NotificationReceiver
(
  NotificationId VARCHAR2(36) NOT NULL REFERENCES IWA_Notification(NotificationId) ON DELETE CASCADE,
  ReceiverId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  PRIMARY KEY (NotificationId, ReceiverId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationReceiver_NotificationIdIndex ON IWA_NotificationReceiver (NotificationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationReceiver_ReceiverIdIndex ON IWA_NotificationReceiver (ReceiverId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_NotificationDelivery
(
  NotificationDeliveryId VARCHAR2(36) NOT NULL,
  NotificationId VARCHAR2(36) REFERENCES IWA_Notification(NotificationId) ON DELETE CASCADE,
  Channel VARCHAR2(100) NOT NULL,
  ReceiverId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  DeliveredAt TIMESTAMP,
  ReadAt TIMESTAMP,
  Hide NUMBER(1) NOT NULL,
  DeliveryState NUMBER(10) NOT NULL,
  Error VARCHAR2(255),
  ErrorTimeoutTimestamp TIMESTAMP,
  NumberOfErrors NUMBER(10) NOT NULL,
  PRIMARY KEY (NotificationDeliveryId)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_NotificationIdIndex ON IWA_NotificationDelivery (NotificationId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_ChannelIndex ON IWA_NotificationDelivery (Channel) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_ReceiverIdIndex ON IWA_NotificationDelivery (ReceiverId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_DeliveredAtIndex ON IWA_NotificationDelivery (DeliveredAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_ReadAtIndex ON IWA_NotificationDelivery (ReadAt) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_HideIndex ON IWA_NotificationDelivery (Hide) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationDelivery_DeliveryStateIndex ON IWA_NotificationDelivery (DeliveryState) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


CREATE TABLE IWA_NotificationSubscription
(
  NotificationSubscriptionId NUMBER(20) NOT NULL,
  Channel VARCHAR2(100) NOT NULL,
  Kind VARCHAR2(100) NOT NULL,
  SubscriberId VARCHAR2(210) NOT NULL REFERENCES IWA_SecurityMember(SecurityMemberId) ON DELETE CASCADE,
  Subscribed NUMBER(1) NOT NULL,
  PRIMARY KEY (NotificationSubscriptionId),
  UNIQUE (SubscriberId, Kind, Channel)
)
TABLESPACE ${tablespaceName};
DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationSubscription_ChannelIndex ON IWA_NotificationSubscription (Channel) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationSubscription_KindIndex ON IWA_NotificationSubscription (Kind) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;

DECLARE
  ALREADY_EXISTS EXCEPTION;
  COLUMNS_INDEXED EXCEPTION;
  PRAGMA EXCEPTION_INIT(ALREADY_EXISTS, -955);
  PRAGMA EXCEPTION_INIT(COLUMNS_INDEXED, -1408);
BEGIN
  EXECUTE IMMEDIATE 'CREATE INDEX IWA_NotificationSubscription_SubscriberIdIndex ON IWA_NotificationSubscription (SubscriberId) TABLESPACE ${tablespaceName}';
EXCEPTION
  WHEN ALREADY_EXISTS OR COLUMNS_INDEXED THEN
  NULL;
END;
;


ALTER TABLE IWA_AsyncProcessCaseData ADD
(
 FOREIGN KEY (CaseId) REFERENCES IWA_Case(CaseId) ON DELETE CASCADE
);

ALTER TABLE IWA_Application ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_SecurityMember ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_Role ADD
(
 FOREIGN KEY (ParentSecurityMemberId) REFERENCES IWA_Role(SecurityMemberId) ON DELETE CASCADE
);

ALTER TABLE IWA_Role ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_User ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_TaskSwitchEvent ADD
(
 FOREIGN KEY (CaseId) REFERENCES IWA_Case(CaseId) ON DELETE CASCADE
);

ALTER TABLE IWA_Case ADD
(
 FOREIGN KEY (BusinessCaseId) REFERENCES IWA_Case(CaseId) ON DELETE SET NULL
);

ALTER TABLE IWA_Case ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_Case ADD
(
 FOREIGN KEY (CreatorTaskId) REFERENCES IWA_Task(TaskId) ON DELETE SET NULL
);

ALTER TABLE IWA_CaseLocalized ADD
(
 FOREIGN KEY (LanguageId) REFERENCES IWA_Language(LanguageId)
);

ALTER TABLE IWA_Task ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_Task ADD
(
 FOREIGN KEY (ExpiredCreatorTaskId) REFERENCES IWA_Task(TaskId)
);

ALTER TABLE IWA_Task ADD
(
 FOREIGN KEY (TimeoutedCreatorIntrmdtEventId) REFERENCES IWA_IntermediateEvent(IntermediateEventId)
);

ALTER TABLE IWA_TaskLocalized ADD
(
 FOREIGN KEY (LanguageId) REFERENCES IWA_Language(LanguageId)
);

ALTER TABLE IWA_WorkflowEvent ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_IntermediateEvent ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_TaskSignalEventReceiver ADD
(
 FOREIGN KEY (StartedSignaledTaskId) REFERENCES IWA_SignaledTask(SignaledTaskId) ON DELETE SET NULL
);

ALTER TABLE IWA_SignaledTask ADD
(
 FOREIGN KEY (ReceivedSignalEventId) REFERENCES IWA_SignalEvent(SignalEventId) ON DELETE SET NULL
);

ALTER TABLE IWA_SignalEvent ADD
(
 FOREIGN KEY (SecuritySystemId) REFERENCES IWA_SecuritySystem(SecuritySystemId)
);

ALTER TABLE IWA_PermissionGroup ADD
(
 FOREIGN KEY (ParentPermissionGroupId) REFERENCES IWA_PermissionGroup(PermissionGroupId) ON DELETE CASCADE
);

ALTER TABLE IWA_AccessControl ADD
(
 FOREIGN KEY (PermissionId) REFERENCES IWA_Permission(PermissionId) ON DELETE CASCADE
);

CREATE TRIGGER IWA_ApplicationDeleteTrg
AFTER DELETE ON IWA_Application
FOR EACH ROW
BEGIN
  DELETE IWA_SignalEvent
  WHERE IWA_SignalEvent.ApplicationId = :old.ApplicationId;

  DELETE IWA_Library
  WHERE IWA_Library.ApplicationId = :old.ApplicationId;

  DELETE IWA_ProcessModel
  WHERE IWA_ProcessModel.ApplicationId = :old.ApplicationId;

END;
;


CREATE TRIGGER IWA_TaskNoteDeleteTrigger
AFTER DELETE ON IWA_TaskNote
FOR EACH ROW
BEGIN
  DELETE IWA_Note
  WHERE IWA_Note.NoteId = :old.NoteId;

END;
;


CREATE TRIGGER IWA_CaseNoteDeleteTrigger
AFTER DELETE ON IWA_CaseNote
FOR EACH ROW
BEGIN
  DELETE IWA_Note
  WHERE IWA_Note.NoteId = :old.NoteId;

END;
;


INSERT INTO IWA_Version (Version) VALUES (160);
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (0, 'AdministrateWorkflow');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (1, 'ViewOwnCreatedCaseWorkflowHistory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (2, 'ViewOwnWorkTaskWorkflowHistory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (3, 'ViewProcessData');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (4, 'ViewTasksOfCase');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (5, 'DelegateTasks');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (6, 'ViewUserSubstitutes');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (7, 'EditUserSubstitutes');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (8, 'ViewUserAbsences');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (9, 'EditUserAbsences');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (10, 'ViewPageArchive');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (100, 'UserSetPassword');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (101, 'UserSetOwnPassword');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (102, 'UserSetFullName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (103, 'UserSetOwnFullName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (104, 'UserReadFullName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (105, 'UserReadOwnFullName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (106, 'UserReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (107, 'UserReadOwnName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (108, 'UserSetEMailAddress');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (109, 'UserSetOwnEMailAddress');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (110, 'UserReadEMailAddress');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (111, 'UserReadOwnEMailAddress');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (112, 'UserSetEMailLanguage');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (113, 'UserSetOwnEMailLanguage');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (114, 'UserReadEMailLanguage');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (115, 'UserReadOwnEMailLanguage');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (116, 'UserSetEMailNotification');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (117, 'UserSetOwnEMailNotification');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (118, 'UserReadEMailNotification');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (119, 'UserReadOwnEMailNotification');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (120, 'UserSetProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (121, 'UserSetOwnProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (122, 'UserReadProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (123, 'UserReadOwnProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (124, 'UserRemoveProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (125, 'UserRemoveOwnProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (126, 'UserReadPropertyNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (127, 'UserReadOwnPropertyNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (128, 'UserAddRole');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (129, 'UserRemoveRole');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (130, 'UserReadRoles');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (131, 'UserReadOwnRoles');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (132, 'UserCreateAbsence');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (133, 'UserCreateOwnAbsence');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (134, 'UserDeleteAbsence');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (135, 'UserDeleteOwnAbsence');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (136, 'UserReadAbsences');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (137, 'UserReadOwnAbsences');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (138, 'UserCreateSubstitute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (139, 'UserCreateOwnSubstitute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (140, 'UserDeleteSubstitute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (141, 'UserDeleteOwnSubstitute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (142, 'UserReadSubstitutes');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (143, 'UserReadOwnSubstitutes');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (144, 'UserReadSubstitutions');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (145, 'UserReadOwnSubstitutions');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (146, 'UserReadExternalSecurityName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (147, 'UserReadOwnExternalSecurityName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (148, 'RoleReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (149, 'RoleReadDisplayDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (150, 'RoleReadDisplayDescriptionTemplate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (151, 'RoleSetDisplayDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (152, 'RoleTreeNavigation');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (153, 'RoleCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (154, 'RoleDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (155, 'RoleSetExternalSecurityName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (156, 'RoleReadExternalSecurityName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (157, 'RoleReadUsers');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (158, 'RoleMove');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (159, 'RoleReadDisplayName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (160, 'RoleReadDisplayNameTemplate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (161, 'RoleSetDisplayName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (162, 'RoleReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (163, 'UserCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (164, 'UserDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (165, 'UserReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (166, 'SessionReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (167, 'SessionDestroy');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (168, 'SessionCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (169, 'SecurityReadExternalSecuritySystemProvider');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (170, 'SecurityReadConfiguration');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (171, 'SecurityTriggerSynchronization');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (172, 'SessionWriteHttpSessionIdentifier');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (173, 'SecurityDescriptorReadAllPermissions');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (174, 'SecurityDescriptorReadOwner');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (175, 'SecurityDescriptorReadSecurityDescriptorType');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (176, 'SecurityDescriptorReadAccessControl');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (177, 'SecurityDescriptorGrantPermission');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (178, 'SecurityDescriptorUngrantPermission');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (179, 'SecurityDescriptorDenyPermission');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (180, 'SecurityDescriptorUndenyPermission');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (181, 'SecurityDescriptorReadPermissionAccess');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (182, 'SecurityDescriptorReadAllPermissionAccess');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (183, 'SessionReadSessionUserUnknown');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (184, 'SessionReadSessionUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (185, 'SessionAssignRole');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (186, 'SessionWriteOwnAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (187, 'SessionWriteAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (188, 'SessionReadOwnAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (189, 'SessionReadAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (190, 'SessionDeleteOwnAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (191, 'SessionDeleteAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (192, 'SessionReadOwnAttributeNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (193, 'SessionReadAttributeNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (194, 'SessionLogoutSessionUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (195, 'SessionReadAbsent');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (196, 'SessionReadActiveSubstitutions');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (197, 'SessionReadIsMemberThroughActiveSubstitution');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (198, 'SessionReadHttpSessionIdentifier');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (199, 'SessionReadAllMySessions');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (200, 'SessionCanActAsUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (201, 'SessionHasRole');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (202, 'ApplicationCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (203, 'ApplicationDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (204, 'ApplicationRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (205, 'ApplicationReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (206, 'SystemPropertyReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (207, 'SystemPropertyRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (208, 'LanguageCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (209, 'LanguageRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (210, 'LanguageReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (211, 'ProcessModelVersionRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (212, 'ProcessModelVersionReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (213, 'SystemPropertyReadValue');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (214, 'SystemPropertyWriteValue');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (215, 'ProcessModelDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (216, 'ProcessModelRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (217, 'ProcessModelCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (218, 'ApplicationReadActivityOperationState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (219, 'ApplicationReadActivityState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (220, 'ApplicationReadAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (221, 'ApplicationReadAttributeNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (222, 'ApplicationDeleteAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (223, 'ApplicationWriteAttribute');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (224, 'ApplicationReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (225, 'ApplicationReadSecuritySystemName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (226, 'ApplicationReadFileAreaDirectory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (227, 'LibraryReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (228, 'ApplicationReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (229, 'ApplicationReadOwnerName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (230, 'ApplicationWriteDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (231, 'ApplicationWriteDownloadPassword');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (232, 'ApplicationWriteFileDirectory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (233, 'ApplicationWriteOwnerName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (234, 'ApplicationWriteOwnerPassword');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (235, 'ExternalDatabaseConfigurationRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (236, 'ExternalDatabaseConfigurationDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (237, 'ExternalDatabaseConfigurationCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (238, 'ApplicationActivate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (239, 'ApplicationDeactivate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (240, 'ApplicationLock');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (241, 'ExternalDatabaseConfigurationReadAccessFlags');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (242, 'ExternalDatabaseConfigurationWriteAccessFlags');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (243, 'ExternalDatabaseConfigurationReadDatabaseConnectionConfiguration');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (244, 'ExternalDatabaseConfigurationWriteDatabaseConnectionConfiguration');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (245, 'ExternalDatabaseConfigurationReadMaxConnections');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (246, 'ExternalDatabaseConfigurationWriteMaxConnections');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (247, 'ExternalDatabaseConfigurationReadUserFriendlyName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (248, 'ExternalDatabaseConfigurationWriteUserFriendlyName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (249, 'ProcessModelReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (250, 'ProcessModelReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (251, 'ProcessModelWriteDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (252, 'ProcessModelReadProjectDirectory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (253, 'ProcessModelReadFileDirectory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (254, 'ProcessModelVersionCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (257, 'ProcessModelReadActivityState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (258, 'ProcessModelReadInheritedActivityState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (259, 'ProcessModelReadActivityOperationState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (260, 'ProcessModelActivate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (261, 'ProcessModelDeactivate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (262, 'ProcessModelLock');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (263, 'ProcessModelVersionReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (264, 'ProcessModelVersionReadVersionName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (265, 'ProcessModelVersionReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (266, 'ProcessModelVersionReadVersionNumber');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (267, 'ProcessModelVersionReadActivityState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (268, 'ProcessModelVersionReadInheritedActivityState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (269, 'ProcessModelVersionReadActivityOperationState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (270, 'ProcessModelVersionReadReleaseState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (271, 'ProcessModelVersionReadNumberOfElements');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (272, 'ProcessModelVersionReadLastChangeDate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (273, 'ProcessModelVersionReadLastChangeBy');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (274, 'ProcessModelVersionReadLastChangeFromHost');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (275, 'ProcessModelVersionReadReleaseTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (276, 'ProcessModelVersionReadScheduledReleaseTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (277, 'ProcessModelVersionReadProjectDirectory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (278, 'ProjectRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (279, 'ProjectReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (280, 'ProcessModelVersionWriteUpdate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (281, 'ProcessModelVersionActivate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (282, 'ProcessModelVersionDeactivate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (283, 'ProcessModelVersionLock');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (284, 'ProcessModelVersionRelease');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (285, 'ProcessModelVersionDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (286, 'ProcessModelVersionReadAllRunningCasesFinished');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (287, 'LibraryCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (288, 'LibraryDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (289, 'LibraryRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (290, 'LibraryReadId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (291, 'LibraryWriteId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (292, 'LibraryReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (293, 'LibraryWriteName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (294, 'LibraryReadProvider');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (295, 'LibraryWriteProvider');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (296, 'LibraryReadVersion');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (297, 'LibraryWriteVersion');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (298, 'LibraryReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (299, 'LibraryWriteDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (300, 'LibrarySpecificationCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (301, 'LibrarySpecificationDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (302, 'LibrarySpecificationRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (303, 'LibrarySpecificationReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (304, 'LibraryReadDependent');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (305, 'LibraryReadAllDependent');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (306, 'LibraryReadRequired');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (307, 'LibraryReadAllRequired');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (308, 'LibraryReadCircularDependent');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (309, 'LibraryReadResolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (310, 'LibrarySpecificationReadId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (311, 'LibrarySpecificationWriteId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (312, 'LibrarySpecificationReadResolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (313, 'LibraryVersionSpecificationRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (314, 'LibraryVersionSpecificationCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (315, 'LibraryVersionSpecificationDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (320, 'LibrarySpecificationReadResolvedLibraryResolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (321, 'LibraryVersionSpecificationReadVersion');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (322, 'LibraryVersionSpecificationWriteVersion');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (323, 'LibraryVersionSpecificationReadInclusive');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (324, 'LibraryVersionSpecificationWriteInclusive');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (325, 'ProcessModelReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (326, 'ApplicationReadFileDirectory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (327, 'TaskRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (328, 'CaseDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (329, 'CaseReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (330, 'CaseRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (331, 'CaseCategoryReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (332, 'TaskReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (333, 'TaskCategoryReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (334, 'WorkflowEventReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (335, 'IntermediateEventReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (336, 'IntermediateEventFire');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (337, 'IntermediateEventElementReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (338, 'IntermediateEventElementRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (339, 'IntermediateEventElementDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (340, 'IntermediateEventElementCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (341, 'StartEventElementRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (342, 'StartEventElementReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (343, 'StartEventElementDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (344, 'StartEventElementCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (345, 'StartElementRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (346, 'StartElementReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (347, 'StartElementDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (348, 'StartElementCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (349, 'ProcessStartReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (350, 'ProcessStartRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (351, 'StartElementReadActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (352, 'StartElementReadVisible');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (353, 'StartEventElementReadEventBeanClassName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (354, 'StartEventElementReadEventBeanConfiguration');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (355, 'StartEventElementReadEventBeanEnabled');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (356, 'StartEventElementWriteEventBeanEnabled');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (357, 'TaskElementRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (358, 'TaskStartReadUserFriendlyStartRequestPath');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (359, 'TaskStartReadStartRequestPath');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (360, 'TaskEndReadJoinPathId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (361, 'TaskEndReadJoinRequestPath');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (362, 'TaskEndReadFullJoinRequestPath');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (363, 'TaskElementReadJoinPathes');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (364, 'TaskElementReadKind');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (365, 'TaskStartReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (366, 'TaskEndReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (367, 'TaskElementReadProcessElementId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (368, 'TaskElementReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (369, 'TaskElementReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (370, 'TaskSwitchEventReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (371, 'TaskReadOwnCaseTasks');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (372, 'CaseReadOwnCaseOfTask');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (373, 'IntermediateEventWriteTimeoutTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (374, 'IntermediateEventReadTimeoutTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (375, 'IntermediateEventReadTimeoutTaskStartElementId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (376, 'IntermediateEventReadTimeoutAction');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (377, 'IntermediateEventReadState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (378, 'IntermediateEventReadResultObject');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (380, 'IntermediateEventReadEventTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (381, 'IntermediateEventReadEventIdentifier');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (382, 'IntermediateEventReadAdditionalInformation');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (383, 'IntermediateEventElementWriteEventBeanConfiguration');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (384, 'IntermediateEventElementWriteEventBeanClassName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (385, 'IntermediateEventElementWriteEventBeanEnabled');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (386, 'IntermediateEventElementReadEventBeanEnabled');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (387, 'IntermediateEventElementReadEventBeanConfiguration');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (388, 'IntermediateEventElementReadEventBeanClassName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (390, 'TaskReadAllOwnWorking');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (391, 'TaskReadAllOwnLocked');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (392, 'CaseReadAllOwnRoleStarted');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (393, 'CaseReadAllOwnStarted');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (394, 'TaskReadAllOwnWork');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (395, 'TaskReadAllOwnWorkedOn');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (396, 'TaskReadAllOwnRoleWorkedOn');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (397, 'ProcessStartReadAllOwnStartable');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (398, 'TaskParkOwnWorkingTask');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (399, 'TaskResetOwnWorkingTask');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (400, 'CaseCategoriesReadAllOwnStarted');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (401, 'TaskCategoriesReadAllOwnWork');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (402, 'TaskCategoriesReadAllWorkedOn');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (403, 'CaseReadCreatorUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (404, 'CaseDestroy');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (405, 'CaseReadStartTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (406, 'CaseReadEndTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (407, 'CaseReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (408, 'CaseWriteName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (409, 'CaseReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (410, 'CaseWriteDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (411, 'CaseReadState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (412, 'NoteCreate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (413, 'NoteReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (414, 'NoteDelete');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (415, 'CaseWriteAdditionalProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (416, 'CaseReadAdditionalProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (417, 'CaseReadAllAdditionalPropertyNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (418, 'CaseReadBusinessCorrespondentId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (419, 'CaseWriteBusinessCorrespondentId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (420, 'CaseReadBusinessCreatorUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (421, 'CaseWriteBusinessCreatorUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (422, 'CaseReadBusinessMainContactDocumentDatabaseCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (423, 'CaseWriteBusinessMainContactDocumentDatabaseCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (424, 'CaseReadBusinessMainContactFolderId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (425, 'CaseWriteBusinessMainContactFolderId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (426, 'CaseReadBusinessMainContactId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (427, 'CaseWriteBusinessMainContactId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (428, 'CaseReadBusinessMainContactName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (429, 'CaseWriteBusinessMainContactName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (430, 'CaseReadBusinessMainContactType');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (431, 'CaseWriteBusinessMainContactType');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (432, 'CaseReadBusinessMilestoneTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (433, 'CaseWriteBusinessMilestoneTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (434, 'CaseReadBusinessObjectCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (435, 'CaseWriteBusinessObjectCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (436, 'CaseReadBusinessObjectDocumentDatabaseCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (437, 'CaseWriteBusinessObjectDocumentDatabaseCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (438, 'CaseReadBusinessObjectFolderId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (439, 'CaseWriteBusinessObjectFolderId');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (440, 'CaseReadBusinessObjectName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (441, 'CaseWriteBusinessObjectName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (442, 'CaseReadBusinessPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (443, 'CaseWriteBusinessPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (444, 'CaseReadBusinessStartTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (445, 'CaseWriteBusinessStartTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (446, 'CaseReadCreatorUserName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (447, 'CaseReadCustomDecimalField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (448, 'CaseWriteCustomDecimalField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (449, 'CaseReadCustomDecimalField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (450, 'CaseWriteCustomDecimalField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (451, 'CaseReadCustomDecimalField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (452, 'CaseWriteCustomDecimalField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (453, 'CaseReadCustomDecimalField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (454, 'CaseWriteCustomDecimalField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (455, 'CaseReadCustomDecimalField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (456, 'CaseWriteCustomDecimalField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (457, 'CaseReadCustomTimestampField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (458, 'CaseWriteCustomTimestampField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (459, 'CaseReadCustomTimestampField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (460, 'CaseWriteCustomTimestampField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (461, 'CaseReadCustomTimestampField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (462, 'CaseWriteCustomTimestampField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (463, 'CaseReadCustomTimestampField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (464, 'CaseWriteCustomTimestampField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (465, 'CaseReadCustomTimestampField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (466, 'CaseWriteCustomTimestampField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (467, 'CaseReadCustomVarCharField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (468, 'CaseWriteCustomVarCharField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (469, 'CaseReadCustomVarCharField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (470, 'CaseWriteCustomVarCharField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (471, 'CaseReadCustomVarCharField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (472, 'CaseWriteCustomVarCharField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (473, 'CaseReadCustomVarCharField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (474, 'CaseWriteCustomVarCharField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (475, 'CaseReadCustomVarCharField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (476, 'CaseWriteCustomVarCharField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (477, 'CaseReadDisplayDescriptionTemplate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (478, 'CaseReadDisplayNameTemplate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (479, 'CaseReadPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (480, 'CaseWritePriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (481, 'CaseReadProcessCategoryCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (482, 'CaseReadProcessCategoryName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (483, 'CaseWriteProcessCategory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (484, 'CaseReadProcessCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (485, 'CaseReadProcessName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (486, 'CaseWriteProcess');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (487, 'CaseReadTypeCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (488, 'CaseReadTypeName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (489, 'CaseWriteType');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (490, 'CaseReadSubTypeCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (491, 'CaseReadSubTypeName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (492, 'CaseWriteSubType');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (493, 'TaskSwitchEventRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (494, 'IntermediateEventRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (495, 'TaskReadWorkerSession');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (496, 'TaskReadState');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (497, 'TaskReadRequestPath');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (498, 'TaskReadName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (499, 'TaskWriteName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (500, 'TaskReadDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (501, 'TaskWriteDescription');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (502, 'TaskReadPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (503, 'TaskReadExpiryPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (504, 'TaskWriteExpiryPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (505, 'TaskReadOriginalPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (506, 'TaskWriteOriginalPriority');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (507, 'TaskReadActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (508, 'TaskReadActivatorName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (509, 'TaskWriteActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (510, 'TaskReadExpiryActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (511, 'TaskReadExpiryActivatorName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (512, 'TaskWriteExpiryActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (513, 'TaskReadOriginalActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (514, 'TaskReadOriginalActivatorName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (515, 'TaskWriteOriginalActivator');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (516, 'TaskReadDelayTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (517, 'TaskWriteDelayTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (518, 'TaskReadExpiryTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (520, 'TaskReadWorkerUser');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (521, 'TaskReadStartTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (522, 'TaskReadEndTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (523, 'TaskReadBusinessMilestoneTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (524, 'TaskWriteBusinessMilestoneTimestamp');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (525, 'TaskReadDisplayDescriptionTemplate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (526, 'TaskReadExpiryTaskStartElementPid');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (527, 'TaskReadKindCode');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (528, 'TaskReadKindName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (529, 'TaskWriteKind');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (530, 'TaskReadDisplayNameTemplate');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (531, 'TaskReadWorkerUserName');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (532, 'TaskReadCustomDecimalField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (533, 'TaskWriteCustomDecimalField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (534, 'TaskReadCustomDecimalField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (535, 'TaskWriteCustomDecimalField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (536, 'TaskReadCustomDecimalField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (537, 'TaskWriteCustomDecimalField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (538, 'TaskReadCustomDecimalField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (539, 'TaskWriteCustomDecimalField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (540, 'TaskReadCustomDecimalField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (541, 'TaskWriteCustomDecimalField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (542, 'TaskReadCustomTimestampField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (543, 'TaskWriteCustomTimestampField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (544, 'TaskReadCustomTimestampField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (545, 'TaskWriteCustomTimestampField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (546, 'TaskReadCustomTimestampField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (547, 'TaskWriteCustomTimestampField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (548, 'TaskReadCustomTimestampField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (549, 'TaskWriteCustomTimestampField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (550, 'TaskReadCustomTimestampField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (551, 'TaskWriteCustomTimestampField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (552, 'TaskReadCustomVarCharField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (553, 'TaskWriteCustomVarCharField1');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (554, 'TaskReadCustomVarCharField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (555, 'TaskWriteCustomVarCharField2');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (556, 'TaskReadCustomVarCharField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (557, 'TaskWriteCustomVarCharField3');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (558, 'TaskReadCustomVarCharField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (559, 'TaskWriteCustomVarCharField4');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (560, 'TaskReadCustomVarCharField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (561, 'TaskWriteCustomVarCharField5');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (562, 'TaskReadIsExpiry');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (563, 'TaskReset');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (564, 'TaskDestroy');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (565, 'TaskWriteAdditionalProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (566, 'TaskReadAdditionalProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (567, 'TaskReadAllAdditionalPropertyNames');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (568, 'TaskStartRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (569, 'TaskEndRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (570, 'CaseReadAllOwnInvolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (571, 'CaseCategoriesReadAllOwnInvolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (572, 'CaseReadAllOwnRoleInvolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (573, 'CaseCategoriesReadAllOwnRoleInvolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (574, 'ApplicationReadConfigurationProperty');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (575, 'ApplicationReadAllConfigurationProperties');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (576, 'ApplicationConfigurationPropertyReadValue');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (577, 'ApplicationConfigurationPropertyWriteValue');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (578, 'PageArchiveReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (579, 'TaskPageArchiveReadAll');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (580, 'TaskReadProcessData');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (581, 'RolePropertyRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (582, 'RolePropertyWrite');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (583, 'LibrarySpecificationWriteResolved');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (584, 'ApplicationCustomPropertyRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (585, 'ApplicationCustomPropertyWrite');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (586, 'DocumentRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (587, 'DocumentWrite');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (588, 'DocumentOfInvolvedCaseRead');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (589, 'DocumentOfInvolvedCaseWrite');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (590, 'CaseAttachToBusinessCase');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (591, 'CaseReadSubCases');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (592, 'CaseReadCategory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (593, 'CaseWriteCategory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (594, 'TaskReadCategory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (595, 'TaskWriteCategory');
INSERT INTO IWA_Permission (PermissionId, Name) VALUES (596, 'TaskWriteExpiryTimestamp');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (0, NULL, 'ApplicationSpecificPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (1, 0, 'PersonalPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (2, 0, 'ManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (3, 1, 'PersonalSecurityPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (4, 1, 'PersonalWorkflowPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (5, 2, 'SecurityManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (6, 2, 'WorkflowManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (7, 5, 'UserPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (8, 5, 'RolePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (9, 5, 'SecurityDescriptorPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (10, NULL, 'SystemPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (11, 10, 'SystemwideApplicationConfigurationManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (12, 10, 'SystemwideSecurityManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (13, 10, 'SystemwideWorkflowManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (14, 12, 'SystemwideUserPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (15, 12, 'SystemwideRolePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (16, 12, 'SystemwideSecurityDescriptorPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (17, 3, 'PersonalUserAbsencePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (18, 3, 'PersonalUserSubstitutePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (19, 3, 'PersonalUserPropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (20, 7, 'UserAbsencePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (21, 7, 'UserSubstitutePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (22, 7, 'UserPropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (23, 14, 'SystemwideUserAbsencePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (24, 14, 'SystemwideUserSubstitutePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (25, 14, 'SystemwideUserPropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (26, 3, 'PersonalUserRolePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (27, 7, 'UserRolePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (28, 14, 'SystemwideUserRolePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (29, 5, 'SessionPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (30, 12, 'SystemwideSessionPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (31, 11, 'SystemwideApplicationPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (32, 11, 'SystemwideLanguagePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (33, 11, 'SystemwideSystemPropertiesPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (34, 2, 'ApplicationConfigurationManagementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (35, 34, 'ApplicationPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (37, 34, 'ProcessModelPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (38, 34, 'ProcessModelVersionPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (39, 34, 'LibraryPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (40, 34, 'ExternalDatabaseConfigurationPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (41, 11, 'SystemwideProcessModelPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (42, 11, 'SystemwideProcessModelVersionPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (43, 11, 'SystemwideLibraryPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (44, 11, 'SystemwideExternalDatabaseConfigurationPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (45, 6, 'StartElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (46, 13, 'SystemwideStartElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (47, 6, 'StartEventElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (48, 13, 'SystemwideStartEventElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (49, 6, 'ProcessStartPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (50, 13, 'SystemwideProcessStartPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (51, 6, 'TaskStartPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (52, 13, 'SystemwideTaskStartPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (53, 6, 'TaskEndPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (54, 13, 'SystemwideTaskEndPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (55, 6, 'TaskElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (56, 13, 'SystemwideTaskElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (57, 6, 'TaskSwitchEventPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (58, 13, 'SystemwideTaskSwitchEventPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (59, 6, 'TaskPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (60, 13, 'SystemwideTaskPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (61, 6, 'CasePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (62, 13, 'SystemwideCasePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (63, 6, 'NotePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (64, 13, 'SystemwideNotePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (65, 59, 'TaskCustomFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (66, 60, 'SystemwideTaskCustomFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (67, 59, 'TaskBusinessFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (68, 60, 'SystemwideTaskBusinessFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (69, 59, 'TaskSystemFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (70, 60, 'SystemwideTaskSystemFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (71, 59, 'CaseCustomFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (72, 60, 'SystemwideCaseCustomFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (73, 59, 'CaseBusinessFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (74, 60, 'SystemwideCaseBusinessFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (75, 59, 'CaseSystemFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (76, 60, 'SystemwideCaseSystemFieldsPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (77, 6, 'WorkflowEventPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (78, 13, 'SystemwideWorkflowEventPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (79, 6, 'IntermediateEventPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (80, 13, 'SystemwideIntermediateEventPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (81, 6, 'IntermediateEventElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (82, 13, 'SystemwideIntermediateEventElementPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (83, 6, 'PageArchivePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (84, 13, 'SystemwidePageArchivePermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (85, 15, 'SystemwideRolePropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (86, 8, 'RolePropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (87, 35, 'ApplicationPropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (88, 31, 'SystemwideApplicationPropertyPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (89, 6, 'DocumentPermissions');
INSERT INTO IWA_PermissionGroup (PermissionGroupId, ParentPermissionGroupId, Name) VALUES (90, 13, 'SystemwideDocumentPermissions');
INSERT INTO IWA_SecurityDescriptorType (SecurityDescriptorTypeId, RootPermissionGroupId, Name) VALUES (0, 10, 'System');
INSERT INTO IWA_SecurityDescriptorType (SecurityDescriptorTypeId, RootPermissionGroupId, Name) VALUES (1, 0, 'Application');
INSERT INTO IWA_SecurityDescriptor (SecurityDescriptorId, SecurityDescriptorTypeId) VALUES (0, 0);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 100);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 100);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 101);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 102);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 102);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 103);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 104);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 104);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 105);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 106);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 106);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 107);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 108);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 108);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 109);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 110);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 110);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 111);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 112);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 112);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 113);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 114);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 114);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 115);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 116);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 116);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 117);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 118);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 118);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 119);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 120);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 120);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 121);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 122);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 122);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 123);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 124);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 124);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 125);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (22, 126);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (25, 126);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (19, 127);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (27, 128);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (28, 128);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (27, 129);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (28, 129);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (27, 130);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (28, 130);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (26, 131);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (20, 132);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (23, 132);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (17, 133);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (20, 134);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (23, 134);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (17, 135);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (20, 136);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (23, 136);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (17, 137);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 138);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 138);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 139);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 140);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 140);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 141);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 142);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 142);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 143);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (21, 144);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (24, 144);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (18, 145);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 146);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 146);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 147);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 148);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 148);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 149);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 149);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 150);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 150);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 151);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 151);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 152);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 152);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 153);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 153);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 154);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 154);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 155);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 155);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 156);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 156);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 157);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 157);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 158);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 158);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 159);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 159);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 160);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 160);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 161);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 161);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (8, 162);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (15, 162);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 163);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 163);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 164);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 164);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (7, 165);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (14, 165);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 166);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 166);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 167);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 167);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 168);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 168);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (5, 169);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (12, 169);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (5, 170);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (12, 170);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (5, 171);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (12, 171);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 172);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 172);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 173);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 173);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 174);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 174);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 175);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 175);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 176);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 176);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 177);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 177);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 178);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 178);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 179);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 179);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 180);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 180);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 181);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 181);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (9, 182);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (16, 182);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 183);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 183);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 184);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 184);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 185);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 185);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 186);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 187);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 187);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 188);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 189);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 189);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 190);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 191);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 191);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (3, 192);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 193);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 193);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 194);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 194);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 195);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 195);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 196);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 196);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 197);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 197);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 198);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 198);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 199);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 199);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 200);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 200);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (29, 201);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (30, 201);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 202);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 203);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 204);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 204);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 205);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 206);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 207);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (32, 208);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (32, 209);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (32, 210);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 211);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 211);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 212);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 212);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 213);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (33, 214);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 215);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 215);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 216);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 216);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 217);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 217);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 218);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 218);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 219);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 219);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 220);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 220);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 221);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 221);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 222);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 222);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 223);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 223);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 224);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 224);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 225);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 225);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 226);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 226);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 227);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 227);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 228);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 228);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 229);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 229);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 230);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 230);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 231);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 231);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 232);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 232);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 233);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 233);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 234);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 234);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 235);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 235);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 236);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 236);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 237);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 237);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 238);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 238);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 239);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 239);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 240);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 240);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 241);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 241);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 242);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 242);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 243);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 243);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 244);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 244);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 245);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 245);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 246);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 246);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 247);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 247);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (40, 248);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (44, 248);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 249);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 249);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 250);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 250);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 251);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 251);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 252);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 252);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 253);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 253);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 254);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 254);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 257);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 257);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 258);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 258);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 259);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 259);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 260);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 260);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 261);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 261);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 262);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 262);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 263);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 263);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 264);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 264);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 265);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 265);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 266);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 266);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 267);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 267);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 268);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 268);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 269);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 269);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 270);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 270);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 271);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 271);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 272);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 272);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 273);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 273);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 274);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 274);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 275);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 275);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 276);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 276);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 277);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 277);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 278);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 278);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 279);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 279);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 280);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 280);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 281);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 281);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 282);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 282);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 283);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 283);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 284);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 284);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 285);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 285);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (38, 286);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (42, 286);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 287);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 287);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 288);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 288);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 289);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 289);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 290);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 290);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 291);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 291);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 292);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 292);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 293);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 293);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 294);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 294);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 295);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 295);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 296);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 296);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 297);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 297);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 298);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 298);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 299);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 299);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 300);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 300);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 301);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 301);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 302);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 302);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 303);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 303);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 304);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 304);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 305);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 305);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 306);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 306);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 307);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 307);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 308);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 308);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 309);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 309);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 310);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 310);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 311);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 311);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 312);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 312);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 313);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 313);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 314);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 314);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 315);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 315);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 320);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 320);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 321);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 321);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 322);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 322);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 323);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 323);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 324);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 324);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (37, 325);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (41, 325);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (35, 326);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (31, 326);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 327);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 327);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 328);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 328);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 329);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 329);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 330);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 330);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 331);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 331);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 332);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 332);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 333);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 333);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (77, 334);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (78, 334);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 335);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 335);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 336);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 336);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 337);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 337);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 338);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 338);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 339);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 339);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 340);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 340);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 341);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 341);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 342);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 342);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 343);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 343);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 344);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 344);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 345);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 345);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 346);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 346);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 347);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 347);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 348);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 348);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (49, 349);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (50, 349);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (49, 350);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (50, 350);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 351);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 351);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (45, 352);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (46, 352);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 353);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 353);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 354);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 354);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 355);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 355);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (47, 356);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (48, 356);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 357);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 357);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 358);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 358);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 359);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 359);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 360);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 360);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 361);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 361);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 362);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 362);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 363);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 363);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 364);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 364);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 365);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 365);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 366);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 366);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 367);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 367);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 368);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 368);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (55, 369);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (56, 369);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (57, 370);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (58, 370);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 371);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 372);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 373);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 373);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 374);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 374);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 375);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 375);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 376);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 376);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 377);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 377);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 378);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 378);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 380);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 380);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 381);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 381);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 382);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 382);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 383);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 383);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 384);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 384);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 385);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 385);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 386);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 386);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 387);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 387);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (81, 388);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (82, 388);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 390);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 391);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 392);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 393);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 394);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 395);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 396);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 397);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 398);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 399);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 400);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 401);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 402);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 403);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 403);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 404);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 404);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 405);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 405);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 406);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 406);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 407);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 407);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 408);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 408);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 409);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 409);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 410);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 410);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 411);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 411);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (63, 412);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (64, 412);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (63, 413);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (64, 413);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (63, 414);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (64, 414);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 415);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 415);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 416);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 416);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 417);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 417);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 418);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 418);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 419);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 419);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 420);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 420);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 421);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 421);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 422);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 422);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 423);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 423);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 424);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 424);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 425);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 425);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 426);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 426);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 427);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 427);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 428);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 428);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 429);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 429);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 430);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 430);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 431);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 431);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 432);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 432);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 433);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 433);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 434);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 434);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 435);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 435);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 436);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 436);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 437);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 437);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 438);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 438);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 439);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 439);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 440);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 440);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 441);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 441);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 442);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 442);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 443);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 443);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 444);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 444);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (73, 445);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (74, 445);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 446);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 446);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 447);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 447);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 448);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 448);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 449);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 449);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 450);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 450);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 451);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 451);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 452);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 452);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 453);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 453);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 454);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 454);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 455);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 455);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 456);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 456);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 457);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 457);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 458);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 458);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 459);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 459);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 460);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 460);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 461);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 461);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 462);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 462);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 463);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 463);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 464);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 464);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 465);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 465);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 466);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 466);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 467);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 467);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 468);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 468);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 469);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 469);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 470);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 470);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 471);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 471);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 472);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 472);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 473);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 473);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 474);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 474);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 475);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 475);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (71, 476);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (72, 476);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 477);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 477);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 478);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 478);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 479);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 479);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 480);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 480);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 481);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 481);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 482);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 482);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 483);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 483);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 484);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 484);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 485);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 485);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 486);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 486);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 487);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 487);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 488);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 488);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 489);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 489);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 490);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 490);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 491);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 491);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 492);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 492);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (57, 493);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (58, 493);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 494);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 494);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (79, 495);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (80, 495);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 496);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 496);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 497);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 497);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 498);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 498);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 499);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 499);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 500);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 500);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 501);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 501);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 502);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 502);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 503);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 503);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 504);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 504);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 505);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 505);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 506);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 506);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 507);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 507);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 508);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 508);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 509);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 509);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 510);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 510);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 511);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 511);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 512);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 512);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 513);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 513);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 514);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 514);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 515);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 515);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 516);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 516);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 517);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 517);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 518);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 518);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 520);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 520);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 521);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 521);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 522);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 522);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (67, 523);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (68, 523);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (67, 524);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (68, 524);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 525);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 525);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 526);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 526);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 527);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 527);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 528);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 528);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 529);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 529);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 530);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 530);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 531);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 531);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 532);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 532);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 533);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 533);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 534);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 534);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 535);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 535);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 536);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 536);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 537);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 537);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 538);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 538);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 539);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 539);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 540);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 540);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 541);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 541);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 542);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 542);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 543);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 543);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 544);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 544);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 545);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 545);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 546);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 546);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 547);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 547);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 548);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 548);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 549);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 549);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 550);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 550);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 551);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 551);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 552);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 552);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 553);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 553);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 554);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 554);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 555);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 555);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 556);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 556);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 557);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 557);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 558);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 558);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 559);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 559);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 560);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 560);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 561);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 561);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 562);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 562);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 563);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 563);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (59, 564);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (60, 564);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 565);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 565);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 566);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 566);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (65, 567);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (66, 567);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (51, 568);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (52, 568);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (53, 569);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (54, 569);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 570);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 571);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 572);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (4, 573);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 574);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 574);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 575);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 575);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 576);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 576);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 577);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 577);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (83, 578);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (84, 578);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (83, 579);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (84, 579);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 580);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 580);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (85, 581);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (86, 581);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (85, 582);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (86, 582);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (39, 583);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (43, 583);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 584);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 584);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (87, 585);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (88, 585);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 586);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 587);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 588);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (89, 589);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 586);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 587);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 588);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (90, 589);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 590);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (61, 591);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 590);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (62, 591);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 592);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (75, 593);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 592);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (76, 593);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 594);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 595);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 594);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 595);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (69, 596);
INSERT INTO IWA_PermissionGroupPermission (PermissionGroupId, PermissionId) VALUES (70, 596);
